@@ -1,6 +1,6 @@
 /** @file
 *
-*  Copyright (c) 2011-2021, Arm Limited. All rights reserved.<BR>
+*  Copyright (c) 2011-2023, Arm Limited. All rights reserved.<BR>
 *
 *  SPDX-License-Identifier: BSD-2-Clause-Patent
 *
@@ -9,13 +9,58 @@
 #ifndef ARMGIC_H_
 #define ARMGIC_H_
 
-#include <Library/ArmGicArchLib.h>
+//
+// GIC SPI and extended SPI ranges
+//
+#define ARM_GIC_ARCH_SPI_MIN      32
+#define ARM_GIC_ARCH_SPI_MAX      1019
+#define ARM_GIC_ARCH_EXT_SPI_MIN  4096
+#define ARM_GIC_ARCH_EXT_SPI_MAX  5119
 
 // GIC Distributor
 #define ARM_GIC_ICDDCR   0x000        // Distributor Control Register
 #define ARM_GIC_ICDICTR  0x004        // Interrupt Controller Type Register
 #define ARM_GIC_ICDIIDR  0x008        // Implementer Identification Register
 
+// ICDICTR is also called GICD_TYPER.
+
+// Intids per LSB for EXT_SPI_RANGE and ITLINES.
+#define ARM_GIC_ICDICTR_INTID_RANGE_RESOLUTION  (32)
+
+// Converts an register range of IntIds to the maximum IntId using Base as an
+// offset.
+#define ARM_GIC_ICDICTR_INTID_RANGE_TO_MAX_INTID(Range, Base) \
+  (ARM_GIC_ICDICTR_INTID_RANGE_RESOLUTION * ((Range) + 1) - 1 + (Base))
+
+#define ARM_GIC_ICDICTR_ITLINES_MASK   (0x1F)
+#define ARM_GIC_ICDICTR_ITLINES_SHIFT  (0)
+
+// Gets the range for SPI IntIds from TypeReg.
+#define ARM_GIC_ICDICTR_GET_SPI_RANGE(TypeReg) \
+  (((TypeReg) >> ARM_GIC_ICDICTR_ITLINES_SHIFT) & ARM_GIC_ICDICTR_ITLINES_MASK)
+
+// Converts a range of SPI IntIds to the maximum SPI IntId.
+#define ARM_GIC_ICDICTR_SPI_RANGE_TO_MAX_INTID(SpiRange) \
+  (((SpiRange) == ARM_GIC_ICDICTR_ITLINES_MASK)          \
+       ? ARM_GIC_ARCH_SPI_MAX                   \
+       : ARM_GIC_ICDICTR_INTID_RANGE_TO_MAX_INTID(SpiRange, 0))
+
+// Extracts the maximum SPI IntId from TypeReg.
+#define ARM_GIC_ICDICTR_GET_SPI_MAX_INTID(TypeReg) \
+  ARM_GIC_ICDICTR_SPI_RANGE_TO_MAX_INTID(ARM_GIC_ICDICTR_GET_SPI_RANGE(TypeReg))
+
+#define ARM_GIC_ICDICTR_EXT_SPI_ENABLED      (1 << 8) // Extended SPI enabled bit.
+#define ARM_GIC_ICDICTR_EXT_SPI_RANGE_SHIFT  (27)     // Extended SPI range position.
+#define ARM_GIC_ICDICTR_EXT_SPI_RANGE_MASK   (0x1F)   // Extended SPI range mask.
+#define ARM_GIC_ICDICTR_GET_EXT_SPI_RANGE(TypeReg)      \
+  (((TypeReg) >> ARM_GIC_ICDICTR_EXT_SPI_RANGE_SHIFT) & \
+   ARM_GIC_ICDICTR_EXT_SPI_RANGE_MASK)
+
+// Extracts the maximum EXT SPI IntId from TypeReg.
+#define ARM_GIC_ICDICTR_GET_EXT_SPI_MAX_INTID(TypeReg) \
+  ARM_GIC_ICDICTR_INTID_RANGE_TO_MAX_INTID(            \
+      ARM_GIC_ICDICTR_GET_EXT_SPI_RANGE(TypeReg), ARM_GIC_ARCH_EXT_SPI_MIN)
+
 // Each reg base below repeats for Number of interrupts / 4 (see GIC spec)
 #define ARM_GIC_ICDISR   0x080        // Interrupt Security Registers
 #define ARM_GIC_ICDISER  0x100        // Interrupt Set-Enable Registers
@@ -37,7 +82,8 @@
 #define ARM_GIC_ICDSGIR  0xF00        // Software Generated Interrupt Register
 
 // GICv3 specific registers
-#define ARM_GICD_IROUTER  0x6100       // Interrupt Routing Registers
+#define ARM_GICD_IROUTER    0x6100    // Interrupt Routing Registers
+#define ARM_GICD_IROUTER_E  0x8000    // Interrupt Routing Registers
 
 // GICD_CTLR bits
 #define ARM_GIC_ICDDCR_ARE  (1 << 4)     // Affinity Routing Enable (ARE)
@@ -52,6 +98,16 @@
 #define ARM_GIC_ICDICFR_LEVEL_TRIGGERED  0x0  // Level triggered interrupt
 #define ARM_GIC_ICDICFR_EDGE_TRIGGERED   0x1  // Edge triggered interrupt
 
+// GICD ESPI registers
+//  These registers follow the same bit pattern as the SPI registers.
+#define ARM_GIC_ICDISR_E   0x1000   // Interrupt Security Registers
+#define ARM_GIC_ICDISER_E  0x1200   // Interrupt Set-Enable for ESPI
+#define ARM_GIC_ICDICER_E  0x1400   // Interrupt Clear-Enable Registers
+#define ARM_GIC_ICDSPR_E   0x1600   // Interrupt Set-Pending Registers
+#define ARM_GIC_ICDICPR_E  0x1800   // Interrupt Clear-Pending Registers
+#define ARM_GIC_ICDIPR_E   0x2000   // Interrupt Priority Registers
+#define ARM_GIC_ICDICFR_E  0x3000   // Interrupt Configuration Registers
+
 // GIC Redistributor
 #define ARM_GICR_CTLR_FRAME_SIZE          SIZE_64KB
 #define ARM_GICR_SGI_PPI_FRAME_SIZE       SIZE_64KB
@@ -110,226 +166,24 @@
 // Bit Mask for
 #define ARM_GIC_ICCIAR_ACKINTID  0x3FF
 
-UINTN
-EFIAPI
-ArmGicGetInterfaceIdentification (
-  IN  INTN  GicInterruptInterfaceBase
-  );
-
-// GIC Secure interfaces
-VOID
-EFIAPI
-ArmGicSetupNonSecure (
-  IN  UINTN  MpId,
-  IN  INTN   GicDistributorBase,
-  IN  INTN   GicInterruptInterfaceBase
-  );
-
-VOID
-EFIAPI
-ArmGicSetSecureInterrupts (
-  IN  UINTN  GicDistributorBase,
-  IN  UINTN  *GicSecureInterruptMask,
-  IN  UINTN  GicSecureInterruptMaskSize
-  );
-
-VOID
-EFIAPI
-ArmGicEnableInterruptInterface (
-  IN  INTN  GicInterruptInterfaceBase
-  );
-
-VOID
-EFIAPI
-ArmGicDisableInterruptInterface (
-  IN  INTN  GicInterruptInterfaceBase
-  );
-
-VOID
-EFIAPI
-ArmGicEnableDistributor (
-  IN  INTN  GicDistributorBase
-  );
-
-VOID
-EFIAPI
-ArmGicDisableDistributor (
-  IN  INTN  GicDistributorBase
-  );
-
-UINTN
-EFIAPI
-ArmGicGetMaxNumInterrupts (
-  IN  INTN  GicDistributorBase
-  );
-
-VOID
-EFIAPI
-ArmGicSendSgiTo (
-  IN  INTN  GicDistributorBase,
-  IN  INTN  TargetListFilter,
-  IN  INTN  CPUTargetList,
-  IN  INTN  SgiId
-  );
-
-/*
- * Acknowledge and return the value of the Interrupt Acknowledge Register
- *
- * InterruptId is returned separately from the register value because in
- * the GICv2 the register value contains the CpuId and InterruptId while
- * in the GICv3 the register value is only the InterruptId.
- *
- * @param GicInterruptInterfaceBase   Base Address of the GIC CPU Interface
- * @param InterruptId                 InterruptId read from the Interrupt
- *                                    Acknowledge Register
- *
- * @retval value returned by the Interrupt Acknowledge Register
- *
- */
-UINTN
-EFIAPI
-ArmGicAcknowledgeInterrupt (
-  IN  UINTN  GicInterruptInterfaceBase,
-  OUT UINTN  *InterruptId
-  );
-
-VOID
-EFIAPI
-ArmGicEndOfInterrupt (
-  IN  UINTN  GicInterruptInterfaceBase,
-  IN UINTN   Source
-  );
-
-UINTN
-EFIAPI
-ArmGicSetPriorityMask (
-  IN  INTN  GicInterruptInterfaceBase,
-  IN  INTN  PriorityMask
-  );
-
-VOID
-EFIAPI
-ArmGicSetInterruptPriority (
-  IN UINTN  GicDistributorBase,
-  IN UINTN  GicRedistributorBase,
-  IN UINTN  Source,
-  IN UINTN  Priority
-  );
-
-VOID
-EFIAPI
-ArmGicEnableInterrupt (
-  IN UINTN  GicDistributorBase,
-  IN UINTN  GicRedistributorBase,
-  IN UINTN  Source
-  );
-
-VOID
-EFIAPI
-ArmGicDisableInterrupt (
-  IN UINTN  GicDistributorBase,
-  IN UINTN  GicRedistributorBase,
-  IN UINTN  Source
-  );
-
-BOOLEAN
-EFIAPI
-ArmGicIsInterruptEnabled (
-  IN UINTN  GicDistributorBase,
-  IN UINTN  GicRedistributorBase,
-  IN UINTN  Source
-  );
-
-// GIC revision 2 specific declarations
-
-// Interrupts from 1020 to 1023 are considered as special interrupts
-// (eg: spurious interrupts)
-#define ARM_GIC_IS_SPECIAL_INTERRUPTS(Interrupt) \
-          (((Interrupt) >= 1020) && ((Interrupt) <= 1023))
-
-VOID
-EFIAPI
-ArmGicV2SetupNonSecure (
-  IN  UINTN  MpId,
-  IN  INTN   GicDistributorBase,
-  IN  INTN   GicInterruptInterfaceBase
-  );
-
-VOID
-EFIAPI
-ArmGicV2EnableInterruptInterface (
-  IN  INTN  GicInterruptInterfaceBase
-  );
-
-VOID
-EFIAPI
-ArmGicV2DisableInterruptInterface (
-  IN  INTN  GicInterruptInterfaceBase
-  );
-
-UINTN
-EFIAPI
-ArmGicV2AcknowledgeInterrupt (
-  IN  UINTN  GicInterruptInterfaceBase
-  );
-
-VOID
-EFIAPI
-ArmGicV2EndOfInterrupt (
-  IN UINTN  GicInterruptInterfaceBase,
-  IN UINTN  Source
-  );
+//
+// GIC SPI and extended SPI ranges
+//
+#define ARM_GIC_ARCH_SPI_MIN      32
+#define ARM_GIC_ARCH_SPI_MAX      1019
+#define ARM_GIC_ARCH_EXT_SPI_MIN  4096
+#define ARM_GIC_ARCH_EXT_SPI_MAX  5119
 
 // GIC revision 3 specific declarations
 
-#define ICC_SRE_EL2_SRE  (1 << 0)
+#define ICC_SRE_EL2_SRE   (1 << 0)
+#define ICC_CTLR_EOImode  (1 << 1)
 
 #define ARM_GICD_IROUTER_IRM  BIT31
 
-UINT32
-EFIAPI
-ArmGicV3GetControlSystemRegisterEnable (
-  VOID
-  );
+// GIC revision 5 specific declarations
 
-VOID
-EFIAPI
-ArmGicV3SetControlSystemRegisterEnable (
-  IN UINT32  ControlSystemRegisterEnable
-  );
-
-VOID
-EFIAPI
-ArmGicV3EnableInterruptInterface (
-  VOID
-  );
-
-VOID
-EFIAPI
-ArmGicV3DisableInterruptInterface (
-  VOID
-  );
-
-UINTN
-EFIAPI
-ArmGicV3AcknowledgeInterrupt (
-  VOID
-  );
-
-VOID
-EFIAPI
-ArmGicV3EndOfInterrupt (
-  IN UINTN  Source
-  );
-
-VOID
-ArmGicV3SetBinaryPointer (
-  IN UINTN  BinaryPoint
-  );
-
-VOID
-ArmGicV3SetPriorityMask (
-  IN UINTN  Priority
-  );
+#define ARM_GICV5_ARCH_SPI_MIN  0x60000000
+#define ARM_GICV5_ARCH_SPI_MAX  0x60ffffff
 
 #endif // ARMGIC_H_
