@@ -443,6 +443,8 @@ GetDeviceIdMappingArray (
   @param  [in]  Context       A pointer to the caller's context provided in
                               HwInfoParserInit ().
   @param  [in]  CmObjDesc     CM_OBJ_DESCRIPTOR containing the CmObj(s) to add.
+  @param  [in]  NewToken      Token for this object. If CM_NULL_TOKEN, then
+                              a new token is generated.
   @param  [out] Token         If provided and success, contain the token
                               generated for the CmObj.
 
@@ -456,6 +458,7 @@ HwInfoAdd (
   IN        HW_INFO_PARSER_HANDLE  ParserHandle,
   IN        VOID                   *Context,
   IN  CONST CM_OBJ_DESCRIPTOR      *CmObjDesc,
+  IN  CONST CM_OBJECT_TOKEN        NewToken,
   OUT       CM_OBJECT_TOKEN        *Token OPTIONAL
   )
 {
@@ -484,6 +487,7 @@ HwInfoAdd (
   Status = DynPlatRepoAddObject (
              PlatformRepo->DynamicPlatformRepo,
              CmObjDesc,
+             NewToken,
              Token
              );
   if (EFI_ERROR (Status)) {
