@@ -2,13 +2,7 @@
 # This file is used to parse and evaluate range expression in Pcd declaration.
 #
 # Copyright (c) 2015 - 2018, Intel Corporation. All rights reserved.<BR>
-# This program and the accompanying materials
-# are licensed and made available under the terms and conditions of the BSD License
-# which accompanies this distribution.    The full text of the license may be found at
-# http://opensource.org/licenses/bsd-license.php
-#
-# THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-# WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+# SPDX-License-Identifier: BSD-2-Clause-Patent
 
 # # Import Modules
 #
@@ -19,6 +13,7 @@ from CommonDataClass.Exceptions import WrnExpression
 import uuid
 from Common.Expression import PcdPattern, BaseExpression
 from Common.DataType import *
+from re import compile
 
 ERR_STRING_EXPR = 'This operator cannot be used in string expression: [%s].'
 ERR_SNYTAX = 'Syntax error, the rest of expression cannot be evaluated: [%s].'
@@ -202,7 +197,7 @@ class RangeExpression(BaseExpression):
 
     NonLetterOpLst = ['+', '-', '&', '|', '^', '!', '=', '>', '<']
 
-    RangePattern = re.compile(r'[0-9]+ - [0-9]+')
+    RangePattern = compile(r'[0-9]+ - [0-9]+')
 
     def preProcessRangeExpr(self, expr):
         # convert hex to int
@@ -289,7 +284,7 @@ class RangeExpression(BaseExpression):
         return rangeid
 
 
-    def NegtiveRange(self, Oprand1):
+    def NegativeRange(self, Oprand1):
         rangeContainer1 = self.operanddict[Oprand1]
 
 
@@ -331,7 +326,7 @@ class RangeExpression(BaseExpression):
         if Operator in ["!", "NOT", "not"]:
             if not gGuidPattern.match(Oprand1.strip()):
                 raise BadExpression(ERR_STRING_EXPR % Operator)
-            return self.NegtiveRange(Oprand1)
+            return self.NegativeRange(Oprand1)
         else:
             if Operator in ["==", ">=", "<=", ">", "<", '^']:
                 return self.EvalRange(Operator, Oprand1)
@@ -347,7 +342,9 @@ class RangeExpression(BaseExpression):
                 raise BadExpression(ERR_STRING_EXPR % Operator)
 
 
-    def __init__(self, Expression, PcdDataType, SymbolTable = {}):
+    def __init__(self, Expression, PcdDataType, SymbolTable = None):
+        if SymbolTable is None:
+            SymbolTable = {}
         super(RangeExpression, self).__init__(self, Expression, PcdDataType, SymbolTable)
         self._NoProcess = False
         if not isinstance(Expression, type('')):
