@@ -3,13 +3,7 @@
 #
 #  Copyright (c) 2007 - 2018, Intel Corporation. All rights reserved.<BR>
 #
-#  This program and the accompanying materials
-#  are licensed and made available under the terms and conditions of the BSD License
-#  which accompanies this distribution.  The full text of the license may be found at
-#  http://opensource.org/licenses/bsd-license.php
-#
-#  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+#  SPDX-License-Identifier: BSD-2-Clause-Patent
 #
 
 ##
@@ -21,10 +15,16 @@ from __future__ import absolute_import
 import re
 import Common.LongFilePathOs as os
 import sys
+if sys.version_info.major == 3:
+    import antlr4 as antlr
+    from Ecc.CParser4.CLexer import CLexer
+    from Ecc.CParser4.CParser import CParser
+else:
+    import antlr3 as antlr
+    antlr.InputStream = antlr.StringStream
+    from Ecc.CParser3.CLexer import CLexer
+    from Ecc.CParser3.CParser import CParser
 
-import antlr3
-from Ecc.CLexer import CLexer
-from Ecc.CParser import CParser
 
 from Ecc import FileProfile
 from Ecc.CodeFragment import Comment
@@ -73,9 +73,7 @@ class CodeFragmentCollector:
         self.FileName = FileName
         self.CurrentLineNumber = 1
         self.CurrentOffsetWithinLine = 0
-
-        self.__Token = ""
-        self.__SkippedChars = ""
+        self.TokenReleaceList = []
 
     ## __EndOfFile() method
     #
@@ -98,21 +96,6 @@ class CodeFragmentCollector:
         else:
             return False
 
-    ## __EndOfLine() method
-    #
-    #   Judge current buffer pos is at line end
-    #
-    #   @param  self        The object pointer
-    #   @retval True        Current File buffer position is at line end
-    #   @retval False       Current File buffer position is NOT at line end
-    #
-    def __EndOfLine(self):
-        SizeOfCurrentLine = len(self.Profile.FileLinesList[self.CurrentLineNumber - 1])
-        if self.CurrentOffsetWithinLine >= SizeOfCurrentLine - 1:
-            return True
-        else:
-            return False
-
     ## Rewind() method
     #
     #   Reset file data buffer to the initial state
@@ -123,25 +106,6 @@ class CodeFragmentCollector:
         self.CurrentLineNumber = 1
         self.CurrentOffsetWithinLine = 0
 
-    ## __UndoOneChar() method
-    #
-    #   Go back one char in the file buffer
-    #
-    #   @param  self        The object pointer
-    #   @retval True        Successfully go back one char
-    #   @retval False       Not able to go back one char as file beginning reached
-    #
-    def __UndoOneChar(self):
-
-        if self.CurrentLineNumber == 1 and self.CurrentOffsetWithinLine == 0:
-            return False
-        elif self.CurrentOffsetWithinLine == 0:
-            self.CurrentLineNumber -= 1
-            self.CurrentOffsetWithinLine = len(self.__CurrentLine()) - 1
-        else:
-            self.CurrentOffsetWithinLine -= 1
-        return True
-
     ## __GetOneChar() method
     #
     #   Move forward one char in the file buffer
@@ -211,32 +175,6 @@ class CodeFragmentCollector:
     def __CurrentLine(self):
         return self.Profile.FileLinesList[self.CurrentLineNumber - 1]
 
-    ## __InsertComma() method
-    #
-    #   Insert ',' to replace PP
-    #
-    #   @param  self        The object pointer
-    #   @retval List        current line contents
-    #
-    def __InsertComma(self, Line):
-
-
-        if self.Profile.FileLinesList[Line - 1][0] != T_CHAR_HASH:
-            BeforeHashPart = str(self.Profile.FileLinesList[Line - 1]).split(T_CHAR_HASH)[0]
-            if BeforeHashPart.rstrip().endswith(T_CHAR_COMMA) or BeforeHashPart.rstrip().endswith(';'):
-                return
-
-        if Line - 2 >= 0 and str(self.Profile.FileLinesList[Line - 2]).rstrip().endswith(','):
-            return
-
-        if Line - 2 >= 0 and str(self.Profile.FileLinesList[Line - 2]).rstrip().endswith(';'):
-            return
-
-        if str(self.Profile.FileLinesList[Line]).lstrip().startswith(',') or str(self.Profile.FileLinesList[Line]).lstrip().startswith(';'):
-            return
-
-        self.Profile.FileLinesList[Line - 1].insert(self.CurrentOffsetWithinLine, ',')
-
     ## PreprocessFile() method
     #
     #   Preprocess file contents, replace comments with spaces.
@@ -503,9 +441,12 @@ class CodeFragmentCollector:
         FileStringContents = ''
         for fileLine in self.Profile.FileLinesList:
             FileStringContents += fileLine
-        cStream = antlr3.StringStream(FileStringContents)
+        for Token in self.TokenReleaceList:
+            if Token in FileStringContents:
+                FileStringContents = FileStringContents.replace(Token, 'TOKENSTRING')
+        cStream = antlr.InputStream(FileStringContents)
         lexer = CLexer(cStream)
-        tStream = antlr3.CommonTokenStream(lexer)
+        tStream = antlr.CommonTokenStream(lexer)
         parser = CParser(tStream)
         parser.translation_unit()
 
@@ -516,9 +457,9 @@ class CodeFragmentCollector:
         FileStringContents = ''
         for fileLine in self.Profile.FileLinesList:
             FileStringContents += fileLine
-        cStream = antlr3.StringStream(FileStringContents)
+        cStream = antlr.InputStream(FileStringContents)
         lexer = CLexer(cStream)
-        tStream = antlr3.CommonTokenStream(lexer)
+        tStream = antlr.CommonTokenStream(lexer)
         parser = CParser(tStream)
         parser.translation_unit()
 
