@@ -3,13 +3,7 @@
 # standard python so that no extra python packages are required to use it.
 #
 # Copyright (c) 2007 - 2018, Intel Corporation. All rights reserved.<BR>
-# This program and the accompanying materials
-# are licensed and made available under the terms and conditions of the BSD License
-# which accompanies this distribution.  The full text of the license may be found at
-# http://opensource.org/licenses/bsd-license.php
-#
-# THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-# WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+# SPDX-License-Identifier: BSD-2-Clause-Patent
 #
 
 ##
@@ -17,6 +11,7 @@
 #
 from __future__ import print_function
 import xml.dom.minidom
+import codecs
 from Common.LongFilePathSupport import OpenLongFilePath as open
 
 ## Create a element of XML
@@ -137,37 +132,6 @@ def XmlElement(Dom, String):
     except:
         return ""
 
-
-## Get a single XML element of the current node.
-#
-# Return a single XML element specified by the current root Dom.
-# If the input Dom is not valid, then an empty string is returned.
-#
-# @param  Dom                The root XML DOM object.
-#
-# @revel  Element            An XML element in current root Dom.
-#
-def XmlElementData(Dom):
-    try:
-        return Dom.firstChild.data.strip()
-    except:
-        return ""
-
-
-## Get a list of XML elements using XPath style syntax.
-#
-# Return a list of XML elements from the root Dom specified by XPath String.
-# If the input Dom or String is not valid, then an empty list is returned.
-#
-# @param  Dom                The root XML DOM object.
-# @param  String             A XPath style path.
-#
-# @revel  Elements           A list of XML elements matching XPath style Sting.
-#
-def XmlElementList(Dom, String):
-    return map(XmlElementData, XmlList(Dom, String))
-
-
 ## Get the XML attribute of the current node.
 #
 # Return a single XML attribute named Attribute from the current root Dom.
@@ -184,22 +148,6 @@ def XmlAttribute(Dom, Attribute):
     except:
         return ''
 
-
-## Get the XML node name of the current node.
-#
-# Return a single XML node name from the current root Dom.
-# If the input Dom is not valid, then an empty string is returned.
-#
-# @param  Dom                The root XML DOM object.
-#
-# @revel  Element            A single XML element matching XPath style Sting.
-#
-def XmlNodeName(Dom):
-    try:
-        return Dom.nodeName.strip()
-    except:
-        return ''
-
 ## Parse an XML file.
 #
 # Parse the input XML file named FileName and return a XML DOM it stands for.
@@ -211,7 +159,7 @@ def XmlNodeName(Dom):
 #
 def XmlParseFile(FileName):
     try:
-        XmlFile = open(FileName)
+        XmlFile = codecs.open(FileName,encoding='utf_8_sig')
         Dom = xml.dom.minidom.parse(XmlFile)
         XmlFile.close()
         return Dom
