@@ -73,6 +73,7 @@ typedef enum ArchCommonObjectID {
   EArchCommonObjSpcrInfo,                       ///< 45 - Serial Terminal and Interrupt Info
   EArchCommonObjTpm2DeviceInfo,                 ///< 46 - TPM2 Device Info
   EArchCommonObjMcfgPciConfigSpaceInfo,         ///< 47 - MCFG PCI Configuration Space Info
+  EArchCommonObjPciRootPortInfo,                ///< 48 - PCI root port configuration Info
   EArchCommonObjMax
 } EARCH_COMMON_OBJECT_ID;
 
@@ -184,6 +185,10 @@ typedef struct CmArchCommonPciConfigSpaceInfo {
   /// Optional field: Reference Token for interrupt mapping.
   /// Token identifying a CM_ARCH_COMMON_OBJ_REF structure.
   CM_OBJECT_TOKEN    InterruptMapToken;
+
+  /// Optional field: Reference Token for PCI root bridge information.
+  /// Token identifying a CM_ARCH_COMMON_PCI_ROOT_PORT_INFO structure.
+  CM_OBJECT_TOKEN    RootPortInfoToken;
 } CM_ARCH_COMMON_PCI_CONFIG_SPACE_INFO;
 
 /** A structure that describes a PCI Address Map.
@@ -200,6 +205,11 @@ typedef struct CmArchCommonPciAddressMapInfo {
    - 1: I/O Space
    - 2: 32-bit-address Memory Space
    - 3: 64-bit-address Memory Space
+
+  Custom values:
+   - 4: Word I/O Space
+   - 5: 32-bit-address uncache Memory Space
+   - 6: 64-bit-address uncache Memory Space
   */
   UINT8     SpaceCode;
 
@@ -265,6 +275,27 @@ typedef struct CmArchCommonPciInterruptMapInfo {
   CM_ARCH_COMMON_GENERIC_INTERRUPT    IntcInterrupt;
 } CM_ARCH_COMMON_PCI_INTERRUPT_MAP_INFO;
 
+/** A structure that describes PCI root port information.
+  Contains the interrupt map and Slot user name.
+
+  ID: EArchCommonObjPciRootPortInfo
+*/
+typedef struct CmArchCommonObjPciRootPortInfo {
+  /// Address of root port
+  /// 6.1.1 _ADR (Address)
+  /// High word-Device #, Low word-Function #. (for example, device 3, function
+  /// 2 is 0x00030002). To refer to all the functions on a device #, use a function
+  /// number of FFFF).
+  UINT32             RootPortAddress;
+
+  /// Token for an array of CM_ARCH_COMMON_PCI_INTERRUPT_MAP_INFO objects.
+  CM_OBJECT_TOKEN    RootPortPrtToken;
+
+  /// 6.1.11 _SUN (Slot User Number)
+  /// integer value, 0xFFFFFFFF means no slot user number
+  UINT32             Sun;
+} CM_ARCH_COMMON_PCI_ROOT_PORT_INFO;
+
 /** A structure that describes the Memory Affinity Structure (Type 1) in SRAT
 
     ID: EArchCommonObjMemoryAffinityInfo
@@ -408,6 +439,8 @@ typedef struct CmArchCommonLpiInfo {
   CHAR8                                     StateName[16];
 } CM_ARCH_COMMON_LPI_INFO;
 
+#define SMBIOS_MAX_STRING_SIZE  (1024)
+
 /** A structure that describes the Processor Hierarchy Node (Type 0) in PPTT
 
     ID: EArchCommonObjProcHierarchyInfo
@@ -447,6 +480,24 @@ typedef struct CmArchCommonProcHierarchyInfo {
   /// If OverrideNameUidEnabled is TRUE then this value will be used for
   /// the UID of processor containers.
   UINT32             OverrideUid;
+  /// SMBIOS: Processor ID. See SMBIOS "Processor ID field format" for format details.
+  UINT64             ProcessorId;
+  /// SMBIOS: Designation of this CM_ARCH_COMMON_PROC_HIERARCHY_INFO instance.
+  /// This string (and all that follow) are intended only for instances with
+  /// EFI_ACPI_6_3_PPTT_PACKAGE_PHYSICAL set, ie describing physical sockets.
+  CHAR8              SocketDesignation[SMBIOS_MAX_STRING_SIZE];
+  /// SMBIOS: String stating processor manufacturer.
+  CHAR8              ProcessorManufacturer[SMBIOS_MAX_STRING_SIZE];
+  /// SMBIOS: String stating processor version / device name.
+  CHAR8              ProcessorVersion[SMBIOS_MAX_STRING_SIZE];
+  /// SMBIOS: String stating processor serial number.
+  CHAR8              SerialNumber[SMBIOS_MAX_STRING_SIZE];
+  /// SMBIOS: String stating processor asset tag.
+  CHAR8              AssetTag[SMBIOS_MAX_STRING_SIZE];
+  /// SMBIOS: String stating processor part number.
+  CHAR8              PartNumber[SMBIOS_MAX_STRING_SIZE];
+  /// SMBIOS: String stating processor socket type.
+  CHAR8              SocketType[SMBIOS_MAX_STRING_SIZE];
 } CM_ARCH_COMMON_PROC_HIERARCHY_INFO;
 
 /** A structure that describes the Cache Type Structure (Type 1) in PPTT
@@ -477,6 +528,11 @@ typedef struct CmArchCommonCacheInfo {
   UINT16             LineSize;
   /// Unique ID for the cache
   UINT32             CacheId;
+  /// SMBIOS: Level of cache within the processor hierarchy
+  /// 0-2 = cache level 1-3
+  UINT32             Level;
+  /// SMBIOS: Designation of this cache on this socket
+  CHAR8              SocketDesignation[SMBIOS_MAX_STRING_SIZE];
 } CM_ARCH_COMMON_CACHE_INFO;
 
 /** A structure that describes the Cpc information.
