@@ -31,7 +31,7 @@ EFIAPI
 CheckFmpDependency (
   IN  EFI_GUID                ImageTypeId,
   IN  UINT32                  Version,
-  IN  EFI_FIRMWARE_IMAGE_DEP  *Dependencies,    OPTIONAL
+  IN  EFI_FIRMWARE_IMAGE_DEP  *Dependencies     OPTIONAL,
   IN  UINT32                  DependenciesSize,
   OUT UINT32                  *LastAttemptStatus OPTIONAL
   )
