@@ -51,6 +51,7 @@ PopEfikeyBufHead (
     CopyMem (KeyData, &Queue->Buffer[Queue->Head], sizeof (EFI_KEY_DATA));
   }
 
+  ZeroMem (&Queue->Buffer[Queue->Head], sizeof (EFI_KEY_DATA));
   Queue->Head = (Queue->Head + 1) % KEYBOARD_EFI_KEY_MAX_COUNT;
   return EFI_SUCCESS;
 }
@@ -258,7 +259,8 @@ KeyboardEfiReset (
   @param This    Pointer to instance of EFI_SIMPLE_TEXT_INPUT_PROTOCOL
   @param Key     The output buffer for key value
 
-  @retval EFI_SUCCESS success to read key stroke
+  @retval EFI_SUCCESS      success to read key stroke
+  @retval EFI_UNSUPPORTED  The device does not support the ability to read keystroke data.
 **/
 EFI_STATUS
 EFIAPI
@@ -433,6 +435,7 @@ KeyboardEfiResetEx (
     @retval EFI_DEVICE_ERROR      The keystroke information was not returned due to
                                   hardware errors.
     @retval EFI_INVALID_PARAMETER KeyData is NULL.
+    @retval EFI_UNSUPPORTED       The device does not support the ability to read keystroke data.
 
 **/
 EFI_STATUS
