@@ -1,6 +1,7 @@
 /** @file
 The module to produce Usb Bus PPI.
 
+Copyright (C) 2025 Advanced Micro Devices, Inc. All rights reserved.<BR>
 Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
 
 SPDX-License-Identifier: BSD-2-Clause-Patent
@@ -32,7 +33,6 @@ EFI_PEI_PPI_DESCRIPTOR  mUsbIoPpiList = {
   The enumeration routine to detect device change.
 
   @param  PeiServices            Describes the list of possible PEI Services.
-  @param  UsbHcPpi               The pointer of PEI_USB_HOST_CONTROLLER_PPI instance.
   @param  Usb2HcPpi              The pointer of PEI_USB2_HOST_CONTROLLER_PPI instance.
 
   @retval EFI_SUCCESS            The usb is enumerated successfully.
@@ -43,7 +43,6 @@ EFI_PEI_PPI_DESCRIPTOR  mUsbIoPpiList = {
 EFI_STATUS
 PeiUsbEnumeration (
   IN EFI_PEI_SERVICES              **PeiServices,
-  IN PEI_USB_HOST_CONTROLLER_PPI   *UsbHcPpi,
   IN PEI_USB2_HOST_CONTROLLER_PPI  *Usb2HcPpi
   );
 
@@ -127,27 +126,19 @@ PeimInitializeUsb (
 {
   EFI_STATUS                    Status;
   UINTN                         Index;
-  PEI_USB_HOST_CONTROLLER_PPI   *UsbHcPpi;
   PEI_USB2_HOST_CONTROLLER_PPI  *Usb2HcPpi;
 
   if (!EFI_ERROR (PeiServicesRegisterForShadow (FileHandle))) {
     return EFI_SUCCESS;
   }
 
-  //
-  // gPeiUsbHostControllerPpiGuid and gPeiUsb2HostControllerPpiGuid should not
-  // be produced at the same time
-  //
   Index = 0;
   while (TRUE) {
-    //
-    // Get UsbHcPpi at first.
-    //
     Status = PeiServicesLocatePpi (
-               &gPeiUsbHostControllerPpiGuid,
+               &gPeiUsb2HostControllerPpiGuid,
                Index,
                NULL,
-               (VOID **)&UsbHcPpi
+               (VOID **)&Usb2HcPpi
                );
     if (EFI_ERROR (Status)) {
       //
@@ -156,33 +147,10 @@ PeimInitializeUsb (
       break;
     }
 
-    PeiUsbEnumeration ((EFI_PEI_SERVICES **)PeiServices, UsbHcPpi, NULL);
+    PeiUsbEnumeration ((EFI_PEI_SERVICES **)PeiServices, Usb2HcPpi);
     Index++;
   }
 
-  if (Index == 0) {
-    //
-    // Then try to get Usb2HcPpi.
-    //
-    while (TRUE) {
-      Status = PeiServicesLocatePpi (
-                 &gPeiUsb2HostControllerPpiGuid,
-                 Index,
-                 NULL,
-                 (VOID **)&Usb2HcPpi
-                 );
-      if (EFI_ERROR (Status)) {
-        //
-        // No more host controller, break out
-        //
-        break;
-      }
-
-      PeiUsbEnumeration ((EFI_PEI_SERVICES **)PeiServices, NULL, Usb2HcPpi);
-      Index++;
-    }
-  }
-
   if (Index == 0) {
     return EFI_UNSUPPORTED;
   }
@@ -276,7 +244,6 @@ PeiHubEnumeration (
           );
         NewPeiUsbDevice->UsbIoPpiList.Ppi = &NewPeiUsbDevice->UsbIoPpi;
         NewPeiUsbDevice->AllocateAddress  = (UINTN)AllocateAddress;
-        NewPeiUsbDevice->UsbHcPpi         = PeiUsbDevice->UsbHcPpi;
         NewPeiUsbDevice->Usb2HcPpi        = PeiUsbDevice->Usb2HcPpi;
         NewPeiUsbDevice->Tier             = (UINT8)(PeiUsbDevice->Tier + 1);
         NewPeiUsbDevice->IsHub            = 0x0;
@@ -403,7 +370,6 @@ PeiHubEnumeration (
   The enumeration routine to detect device change.
 
   @param  PeiServices            Describes the list of possible PEI Services.
-  @param  UsbHcPpi               The pointer of PEI_USB_HOST_CONTROLLER_PPI instance.
   @param  Usb2HcPpi              The pointer of PEI_USB2_HOST_CONTROLLER_PPI instance.
 
   @retval EFI_SUCCESS            The usb is enumerated successfully.
@@ -414,7 +380,6 @@ PeiHubEnumeration (
 EFI_STATUS
 PeiUsbEnumeration (
   IN EFI_PEI_SERVICES              **PeiServices,
-  IN PEI_USB_HOST_CONTROLLER_PPI   *UsbHcPpi,
   IN PEI_USB2_HOST_CONTROLLER_PPI  *Usb2HcPpi
   )
 {
@@ -428,6 +393,7 @@ PeiUsbEnumeration (
   UINT8                 CurrentAddress;
   UINTN                 InterfaceIndex;
   UINTN                 EndpointIndex;
+  UINT8                 UsbEnumLoop;
 
   CurrentAddress = 0;
   if (Usb2HcPpi != NULL) {
@@ -436,12 +402,6 @@ PeiUsbEnumeration (
                  Usb2HcPpi,
                  (UINT8 *)&NumOfRootPort
                  );
-  } else if (UsbHcPpi != NULL) {
-    UsbHcPpi->GetRootHubPortNumber (
-                PeiServices,
-                UsbHcPpi,
-                (UINT8 *)&NumOfRootPort
-                );
   } else {
     ASSERT (FALSE);
     return EFI_INVALID_PARAMETER;
@@ -449,161 +409,31 @@ PeiUsbEnumeration (
 
   DEBUG ((DEBUG_INFO, "PeiUsbEnumeration: NumOfRootPort: %x\n", NumOfRootPort));
 
-  for (Index = 0; Index < NumOfRootPort; Index++) {
-    //
-    // First get root port status to detect changes happen
-    //
-    if (Usb2HcPpi != NULL) {
+  //
+  // USB3.x devices initially appear in USB2.0 ports. When the USB2.0 port is reset, the USB3.x device disappears
+  // from the USB2.0 port and appears on the USB3.0 port. The USB3.x device won't be enumerated if the USB2.0 port
+  // number is greater than the USB3.0 port number. Re-enumerate USB to make sure USB3.x devices in this case.
+  //
+  for (UsbEnumLoop = 0; UsbEnumLoop < 2; UsbEnumLoop++) {
+    for (Index = 0; Index < NumOfRootPort; Index++) {
+      //
+      // First get root port status to detect changes happen
+      //
       Usb2HcPpi->GetRootHubPortStatus (
                    PeiServices,
                    Usb2HcPpi,
                    (UINT8)Index,
                    &PortStatus
                    );
-    } else {
-      UsbHcPpi->GetRootHubPortStatus (
-                  PeiServices,
-                  UsbHcPpi,
-                  (UINT8)Index,
-                  &PortStatus
-                  );
-    }
 
-    DEBUG ((DEBUG_INFO, "USB Status --- Port: %x ConnectChange[%04x] Status[%04x]\n", Index, PortStatus.PortChangeStatus, PortStatus.PortStatus));
-    //
-    // Only handle connection/enable/overcurrent/reset change.
-    //
-    if ((PortStatus.PortChangeStatus & (USB_PORT_STAT_C_CONNECTION | USB_PORT_STAT_C_ENABLE | USB_PORT_STAT_C_OVERCURRENT | USB_PORT_STAT_C_RESET)) == 0) {
-      continue;
-    } else {
-      if (IsPortConnect (PortStatus.PortStatus)) {
-        MemPages = sizeof (PEI_USB_DEVICE) / EFI_PAGE_SIZE + 1;
-        Status   = PeiServicesAllocatePages (
-                     EfiBootServicesCode,
-                     MemPages,
-                     &AllocateAddress
-                     );
-        if (EFI_ERROR (Status)) {
-          return EFI_OUT_OF_RESOURCES;
-        }
-
-        PeiUsbDevice = (PEI_USB_DEVICE *)((UINTN)AllocateAddress);
-        ZeroMem (PeiUsbDevice, sizeof (PEI_USB_DEVICE));
-
-        PeiUsbDevice->Signature      = PEI_USB_DEVICE_SIGNATURE;
-        PeiUsbDevice->DeviceAddress  = 0;
-        PeiUsbDevice->MaxPacketSize0 = 8;
-        PeiUsbDevice->DataToggle     = 0;
-        CopyMem (
-          &(PeiUsbDevice->UsbIoPpi),
-          &mUsbIoPpi,
-          sizeof (PEI_USB_IO_PPI)
-          );
-        CopyMem (
-          &(PeiUsbDevice->UsbIoPpiList),
-          &mUsbIoPpiList,
-          sizeof (EFI_PEI_PPI_DESCRIPTOR)
-          );
-        PeiUsbDevice->UsbIoPpiList.Ppi = &PeiUsbDevice->UsbIoPpi;
-        PeiUsbDevice->AllocateAddress  = (UINTN)AllocateAddress;
-        PeiUsbDevice->UsbHcPpi         = UsbHcPpi;
-        PeiUsbDevice->Usb2HcPpi        = Usb2HcPpi;
-        PeiUsbDevice->IsHub            = 0x0;
-        PeiUsbDevice->DownStreamPortNo = 0x0;
-
-        if (((PortStatus.PortChangeStatus & USB_PORT_STAT_C_RESET) == 0) ||
-            ((PortStatus.PortStatus & (USB_PORT_STAT_CONNECTION | USB_PORT_STAT_ENABLE)) == 0))
-        {
-          //
-          // If the port already has reset change flag and is connected and enabled, skip the port reset logic.
-          //
-          ResetRootPort (
-            PeiServices,
-            PeiUsbDevice->UsbHcPpi,
-            PeiUsbDevice->Usb2HcPpi,
-            Index,
-            0
-            );
-
-          if (Usb2HcPpi != NULL) {
-            Usb2HcPpi->GetRootHubPortStatus (
-                         PeiServices,
-                         Usb2HcPpi,
-                         (UINT8)Index,
-                         &PortStatus
-                         );
-          } else {
-            UsbHcPpi->GetRootHubPortStatus (
-                        PeiServices,
-                        UsbHcPpi,
-                        (UINT8)Index,
-                        &PortStatus
-                        );
-          }
-        } else {
-          if (Usb2HcPpi != NULL) {
-            Usb2HcPpi->ClearRootHubPortFeature (
-                         PeiServices,
-                         Usb2HcPpi,
-                         (UINT8)Index,
-                         EfiUsbPortResetChange
-                         );
-          } else {
-            UsbHcPpi->ClearRootHubPortFeature (
-                        PeiServices,
-                        UsbHcPpi,
-                        (UINT8)Index,
-                        EfiUsbPortResetChange
-                        );
-          }
-        }
-
-        PeiUsbDevice->DeviceSpeed = (UINT8)PeiUsbGetDeviceSpeed (PortStatus.PortStatus);
-        DEBUG ((DEBUG_INFO, "Device Speed =%d\n", PeiUsbDevice->DeviceSpeed));
-
-        if (USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_SUPER_SPEED)) {
-          PeiUsbDevice->MaxPacketSize0 = 512;
-        } else if (USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_HIGH_SPEED)) {
-          PeiUsbDevice->MaxPacketSize0 = 64;
-        } else if (USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_LOW_SPEED)) {
-          PeiUsbDevice->MaxPacketSize0 = 8;
-        } else {
-          PeiUsbDevice->MaxPacketSize0 = 8;
-        }
-
-        //
-        // Configure that Usb Device
-        //
-        Status = PeiConfigureUsbDevice (
-                   PeiServices,
-                   PeiUsbDevice,
-                   Index,
-                   &CurrentAddress
-                   );
-
-        if (EFI_ERROR (Status)) {
-          continue;
-        }
-
-        DEBUG ((DEBUG_INFO, "PeiUsbEnumeration: PeiConfigureUsbDevice Success\n"));
-
-        Status = PeiServicesInstallPpi (&PeiUsbDevice->UsbIoPpiList);
-
-        if (PeiUsbDevice->InterfaceDesc->InterfaceClass == 0x09) {
-          PeiUsbDevice->IsHub = 0x1;
-
-          Status = PeiDoHubConfig (PeiServices, PeiUsbDevice);
-          if (EFI_ERROR (Status)) {
-            return Status;
-          }
-
-          PeiHubEnumeration (PeiServices, PeiUsbDevice, &CurrentAddress);
-        }
-
-        for (InterfaceIndex = 1; InterfaceIndex < PeiUsbDevice->ConfigDesc->NumInterfaces; InterfaceIndex++) {
-          //
-          // Begin to deal with the new device
-          //
+      DEBUG ((DEBUG_INFO, "USB Status --- Port: %x ConnectChange[%04x] Status[%04x]\n", Index, PortStatus.PortChangeStatus, PortStatus.PortStatus));
+      //
+      // Only handle connection/enable/overcurrent/reset change.
+      //
+      if ((PortStatus.PortChangeStatus & (USB_PORT_STAT_C_CONNECTION | USB_PORT_STAT_C_ENABLE | USB_PORT_STAT_C_OVERCURRENT | USB_PORT_STAT_C_RESET)) == 0) {
+        continue;
+      } else {
+        if (IsPortConnect (PortStatus.PortStatus)) {
           MemPages = sizeof (PEI_USB_DEVICE) / EFI_PAGE_SIZE + 1;
           Status   = PeiServicesAllocatePages (
                        EfiBootServicesCode,
@@ -614,15 +444,86 @@ PeiUsbEnumeration (
             return EFI_OUT_OF_RESOURCES;
           }
 
-          CopyMem ((VOID *)(UINTN)AllocateAddress, PeiUsbDevice, sizeof (PEI_USB_DEVICE));
-          PeiUsbDevice                   = (PEI_USB_DEVICE *)((UINTN)AllocateAddress);
-          PeiUsbDevice->AllocateAddress  = (UINTN)AllocateAddress;
+          PeiUsbDevice = (PEI_USB_DEVICE *)((UINTN)AllocateAddress);
+          ZeroMem (PeiUsbDevice, sizeof (PEI_USB_DEVICE));
+
+          PeiUsbDevice->Signature      = PEI_USB_DEVICE_SIGNATURE;
+          PeiUsbDevice->DeviceAddress  = 0;
+          PeiUsbDevice->MaxPacketSize0 = 8;
+          PeiUsbDevice->DataToggle     = 0;
+          CopyMem (
+            &(PeiUsbDevice->UsbIoPpi),
+            &mUsbIoPpi,
+            sizeof (PEI_USB_IO_PPI)
+            );
+          CopyMem (
+            &(PeiUsbDevice->UsbIoPpiList),
+            &mUsbIoPpiList,
+            sizeof (EFI_PEI_PPI_DESCRIPTOR)
+            );
           PeiUsbDevice->UsbIoPpiList.Ppi = &PeiUsbDevice->UsbIoPpi;
-          PeiUsbDevice->InterfaceDesc    = PeiUsbDevice->InterfaceDescList[InterfaceIndex];
-          for (EndpointIndex = 0; EndpointIndex < PeiUsbDevice->InterfaceDesc->NumEndpoints; EndpointIndex++) {
-            PeiUsbDevice->EndpointDesc[EndpointIndex] = PeiUsbDevice->EndpointDescList[InterfaceIndex][EndpointIndex];
+          PeiUsbDevice->AllocateAddress  = (UINTN)AllocateAddress;
+          PeiUsbDevice->Usb2HcPpi        = Usb2HcPpi;
+          PeiUsbDevice->IsHub            = 0x0;
+          PeiUsbDevice->DownStreamPortNo = 0x0;
+
+          if (((PortStatus.PortChangeStatus & USB_PORT_STAT_C_RESET) == 0) ||
+              ((PortStatus.PortStatus & (USB_PORT_STAT_CONNECTION | USB_PORT_STAT_ENABLE)) == 0))
+          {
+            //
+            // If the port already has reset change flag and is connected and enabled, skip the port reset logic.
+            //
+            ResetRootPort (
+              PeiServices,
+              PeiUsbDevice->Usb2HcPpi,
+              Index,
+              0
+              );
+
+            Usb2HcPpi->GetRootHubPortStatus (
+                         PeiServices,
+                         Usb2HcPpi,
+                         (UINT8)Index,
+                         &PortStatus
+                         );
+          } else {
+            Usb2HcPpi->ClearRootHubPortFeature (
+                         PeiServices,
+                         Usb2HcPpi,
+                         (UINT8)Index,
+                         EfiUsbPortResetChange
+                         );
           }
 
+          PeiUsbDevice->DeviceSpeed = (UINT8)PeiUsbGetDeviceSpeed (PortStatus.PortStatus);
+          DEBUG ((DEBUG_INFO, "Device Speed =%d\n", PeiUsbDevice->DeviceSpeed));
+
+          if (USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_SUPER_SPEED)) {
+            PeiUsbDevice->MaxPacketSize0 = 512;
+          } else if (USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_HIGH_SPEED)) {
+            PeiUsbDevice->MaxPacketSize0 = 64;
+          } else if (USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_LOW_SPEED)) {
+            PeiUsbDevice->MaxPacketSize0 = 8;
+          } else {
+            PeiUsbDevice->MaxPacketSize0 = 8;
+          }
+
+          //
+          // Configure that Usb Device
+          //
+          Status = PeiConfigureUsbDevice (
+                     PeiServices,
+                     PeiUsbDevice,
+                     Index,
+                     &CurrentAddress
+                     );
+
+          if (EFI_ERROR (Status)) {
+            continue;
+          }
+
+          DEBUG ((DEBUG_INFO, "PeiUsbEnumeration: PeiConfigureUsbDevice Success\n"));
+
           Status = PeiServicesInstallPpi (&PeiUsbDevice->UsbIoPpiList);
 
           if (PeiUsbDevice->InterfaceDesc->InterfaceClass == 0x09) {
@@ -635,11 +536,48 @@ PeiUsbEnumeration (
 
             PeiHubEnumeration (PeiServices, PeiUsbDevice, &CurrentAddress);
           }
+
+          for (InterfaceIndex = 1; InterfaceIndex < PeiUsbDevice->ConfigDesc->NumInterfaces; InterfaceIndex++) {
+            //
+            // Begin to deal with the new device
+            //
+            MemPages = sizeof (PEI_USB_DEVICE) / EFI_PAGE_SIZE + 1;
+            Status   = PeiServicesAllocatePages (
+                         EfiBootServicesCode,
+                         MemPages,
+                         &AllocateAddress
+                         );
+            if (EFI_ERROR (Status)) {
+              return EFI_OUT_OF_RESOURCES;
+            }
+
+            CopyMem ((VOID *)(UINTN)AllocateAddress, PeiUsbDevice, sizeof (PEI_USB_DEVICE));
+            PeiUsbDevice                   = (PEI_USB_DEVICE *)((UINTN)AllocateAddress);
+            PeiUsbDevice->AllocateAddress  = (UINTN)AllocateAddress;
+            PeiUsbDevice->UsbIoPpiList.Ppi = &PeiUsbDevice->UsbIoPpi;
+            PeiUsbDevice->InterfaceDesc    = PeiUsbDevice->InterfaceDescList[InterfaceIndex];
+            for (EndpointIndex = 0; EndpointIndex < PeiUsbDevice->InterfaceDesc->NumEndpoints; EndpointIndex++) {
+              PeiUsbDevice->EndpointDesc[EndpointIndex] = PeiUsbDevice->EndpointDescList[InterfaceIndex][EndpointIndex];
+            }
+
+            Status = PeiServicesInstallPpi (&PeiUsbDevice->UsbIoPpiList);
+
+            if (PeiUsbDevice->InterfaceDesc->InterfaceClass == 0x09) {
+              PeiUsbDevice->IsHub = 0x1;
+
+              Status = PeiDoHubConfig (PeiServices, PeiUsbDevice);
+              if (EFI_ERROR (Status)) {
+                return Status;
+              }
+
+              PeiHubEnumeration (PeiServices, PeiUsbDevice, &CurrentAddress);
+            }
+          }
+        } else {
+          //
+          // Disconnect change happen, currently we don't support
+          //
         }
-      } else {
-        //
-        // Disconnect change happen, currently we don't support
-        //
       }
     }
   }
@@ -1023,7 +961,6 @@ GetExpectedDescriptor (
   Send reset signal over the given root hub port.
 
   @param  PeiServices       Describes the list of possible PEI Services.
-  @param  UsbHcPpi          The pointer of PEI_USB_HOST_CONTROLLER_PPI instance.
   @param  Usb2HcPpi         The pointer of PEI_USB2_HOST_CONTROLLER_PPI instance.
   @param  PortNum           The port to be reset.
   @param  RetryIndex        The retry times.
@@ -1032,7 +969,6 @@ GetExpectedDescriptor (
 VOID
 ResetRootPort (
   IN EFI_PEI_SERVICES              **PeiServices,
-  IN PEI_USB_HOST_CONTROLLER_PPI   *UsbHcPpi,
   IN PEI_USB2_HOST_CONTROLLER_PPI  *Usb2HcPpi,
   IN UINT8                         PortNum,
   IN UINT8                         RetryIndex
@@ -1042,211 +978,105 @@ ResetRootPort (
   UINTN                Index;
   EFI_USB_PORT_STATUS  PortStatus;
 
-  if (Usb2HcPpi != NULL) {
-    MicroSecondDelay (200 * 1000);
+  MicroSecondDelay (200 * 1000);
 
-    //
-    // reset root port
-    //
-    Status = Usb2HcPpi->SetRootHubPortFeature (
-                          PeiServices,
-                          Usb2HcPpi,
-                          PortNum,
-                          EfiUsbPortReset
-                          );
+  //
+  // reset root port
+  //
+  Status = Usb2HcPpi->SetRootHubPortFeature (
+                        PeiServices,
+                        Usb2HcPpi,
+                        PortNum,
+                        EfiUsbPortReset
+                        );
 
-    if (EFI_ERROR (Status)) {
-      DEBUG ((DEBUG_ERROR, "SetRootHubPortFeature EfiUsbPortReset Failed\n"));
-      return;
-    }
-
-    //
-    // Drive the reset signal for at least 50ms. Check USB 2.0 Spec
-    // section 7.1.7.5 for timing requirements.
-    //
-    MicroSecondDelay (USB_SET_ROOT_PORT_RESET_STALL);
-
-    //
-    // clear reset root port
-    //
-    Status = Usb2HcPpi->ClearRootHubPortFeature (
-                          PeiServices,
-                          Usb2HcPpi,
-                          PortNum,
-                          EfiUsbPortReset
-                          );
-
-    if (EFI_ERROR (Status)) {
-      DEBUG ((DEBUG_ERROR, "ClearRootHubPortFeature EfiUsbPortReset Failed\n"));
-      return;
-    }
-
-    MicroSecondDelay (USB_CLR_ROOT_PORT_RESET_STALL);
-
-    //
-    // USB host controller won't clear the RESET bit until
-    // reset is actually finished.
-    //
-    ZeroMem (&PortStatus, sizeof (EFI_USB_PORT_STATUS));
-
-    for (Index = 0; Index < USB_WAIT_PORT_STS_CHANGE_LOOP; Index++) {
-      Status = Usb2HcPpi->GetRootHubPortStatus (
-                            PeiServices,
-                            Usb2HcPpi,
-                            PortNum,
-                            &PortStatus
-                            );
-      if (EFI_ERROR (Status)) {
-        return;
-      }
-
-      if (!USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_RESET)) {
-        break;
-      }
-
-      MicroSecondDelay (USB_WAIT_PORT_STS_CHANGE_STALL);
-    }
-
-    if (Index == USB_WAIT_PORT_STS_CHANGE_LOOP) {
-      DEBUG ((DEBUG_ERROR, "ResetRootPort: reset not finished in time on port %d\n", PortNum));
-      return;
-    }
-
-    Usb2HcPpi->ClearRootHubPortFeature (
-                 PeiServices,
-                 Usb2HcPpi,
-                 PortNum,
-                 EfiUsbPortResetChange
-                 );
-
-    Usb2HcPpi->ClearRootHubPortFeature (
-                 PeiServices,
-                 Usb2HcPpi,
-                 PortNum,
-                 EfiUsbPortConnectChange
-                 );
-
-    //
-    // Set port enable
-    //
-    Usb2HcPpi->SetRootHubPortFeature (
-                 PeiServices,
-                 Usb2HcPpi,
-                 PortNum,
-                 EfiUsbPortEnable
-                 );
-
-    Usb2HcPpi->ClearRootHubPortFeature (
-                 PeiServices,
-                 Usb2HcPpi,
-                 PortNum,
-                 EfiUsbPortEnableChange
-                 );
-
-    MicroSecondDelay ((RetryIndex + 1) * 50 * 1000);
-  } else {
-    MicroSecondDelay (200 * 1000);
-
-    //
-    // reset root port
-    //
-    Status = UsbHcPpi->SetRootHubPortFeature (
-                         PeiServices,
-                         UsbHcPpi,
-                         PortNum,
-                         EfiUsbPortReset
-                         );
-
-    if (EFI_ERROR (Status)) {
-      DEBUG ((DEBUG_ERROR, "SetRootHubPortFeature EfiUsbPortReset Failed\n"));
-      return;
-    }
-
-    //
-    // Drive the reset signal for at least 50ms. Check USB 2.0 Spec
-    // section 7.1.7.5 for timing requirements.
-    //
-    MicroSecondDelay (USB_SET_ROOT_PORT_RESET_STALL);
-
-    //
-    // clear reset root port
-    //
-    Status = UsbHcPpi->ClearRootHubPortFeature (
-                         PeiServices,
-                         UsbHcPpi,
-                         PortNum,
-                         EfiUsbPortReset
-                         );
-
-    if (EFI_ERROR (Status)) {
-      DEBUG ((DEBUG_ERROR, "ClearRootHubPortFeature EfiUsbPortReset Failed\n"));
-      return;
-    }
-
-    MicroSecondDelay (USB_CLR_ROOT_PORT_RESET_STALL);
-
-    //
-    // USB host controller won't clear the RESET bit until
-    // reset is actually finished.
-    //
-    ZeroMem (&PortStatus, sizeof (EFI_USB_PORT_STATUS));
-
-    for (Index = 0; Index < USB_WAIT_PORT_STS_CHANGE_LOOP; Index++) {
-      Status = UsbHcPpi->GetRootHubPortStatus (
-                           PeiServices,
-                           UsbHcPpi,
-                           PortNum,
-                           &PortStatus
-                           );
-      if (EFI_ERROR (Status)) {
-        return;
-      }
-
-      if (!USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_RESET)) {
-        break;
-      }
-
-      MicroSecondDelay (USB_WAIT_PORT_STS_CHANGE_STALL);
-    }
-
-    if (Index == USB_WAIT_PORT_STS_CHANGE_LOOP) {
-      DEBUG ((DEBUG_ERROR, "ResetRootPort: reset not finished in time on port %d\n", PortNum));
-      return;
-    }
-
-    UsbHcPpi->ClearRootHubPortFeature (
-                PeiServices,
-                UsbHcPpi,
-                PortNum,
-                EfiUsbPortResetChange
-                );
-
-    UsbHcPpi->ClearRootHubPortFeature (
-                PeiServices,
-                UsbHcPpi,
-                PortNum,
-                EfiUsbPortConnectChange
-                );
-
-    //
-    // Set port enable
-    //
-    UsbHcPpi->SetRootHubPortFeature (
-                PeiServices,
-                UsbHcPpi,
-                PortNum,
-                EfiUsbPortEnable
-                );
-
-    UsbHcPpi->ClearRootHubPortFeature (
-                PeiServices,
-                UsbHcPpi,
-                PortNum,
-                EfiUsbPortEnableChange
-                );
-
-    MicroSecondDelay ((RetryIndex + 1) * 50 * 1000);
+  if (EFI_ERROR (Status)) {
+    DEBUG ((DEBUG_ERROR, "SetRootHubPortFeature EfiUsbPortReset Failed\n"));
+    return;
   }
 
-  return;
+  //
+  // Drive the reset signal for at least 50ms. Check USB 2.0 Spec
+  // section 7.1.7.5 for timing requirements.
+  //
+  MicroSecondDelay (USB_SET_ROOT_PORT_RESET_STALL);
+
+  //
+  // clear reset root port
+  //
+  Status = Usb2HcPpi->ClearRootHubPortFeature (
+                        PeiServices,
+                        Usb2HcPpi,
+                        PortNum,
+                        EfiUsbPortReset
+                        );
+
+  if (EFI_ERROR (Status)) {
+    DEBUG ((DEBUG_ERROR, "ClearRootHubPortFeature EfiUsbPortReset Failed\n"));
+    return;
+  }
+
+  MicroSecondDelay (USB_CLR_ROOT_PORT_RESET_STALL);
+
+  //
+  // USB host controller won't clear the RESET bit until
+  // reset is actually finished.
+  //
+  ZeroMem (&PortStatus, sizeof (EFI_USB_PORT_STATUS));
+
+  for (Index = 0; Index < USB_WAIT_PORT_STS_CHANGE_LOOP; Index++) {
+    Status = Usb2HcPpi->GetRootHubPortStatus (
+                          PeiServices,
+                          Usb2HcPpi,
+                          PortNum,
+                          &PortStatus
+                          );
+    if (EFI_ERROR (Status)) {
+      return;
+    }
+
+    if (!USB_BIT_IS_SET (PortStatus.PortStatus, USB_PORT_STAT_RESET)) {
+      break;
+    }
+
+    MicroSecondDelay (USB_WAIT_PORT_STS_CHANGE_STALL);
+  }
+
+  if (Index == USB_WAIT_PORT_STS_CHANGE_LOOP) {
+    DEBUG ((DEBUG_ERROR, "ResetRootPort: reset not finished in time on port %d\n", PortNum));
+    return;
+  }
+
+  Usb2HcPpi->ClearRootHubPortFeature (
+               PeiServices,
+               Usb2HcPpi,
+               PortNum,
+               EfiUsbPortResetChange
+               );
+
+  Usb2HcPpi->ClearRootHubPortFeature (
+               PeiServices,
+               Usb2HcPpi,
+               PortNum,
+               EfiUsbPortConnectChange
+               );
+
+  //
+  // Set port enable
+  //
+  Usb2HcPpi->SetRootHubPortFeature (
+               PeiServices,
+               Usb2HcPpi,
+               PortNum,
+               EfiUsbPortEnable
+               );
+
+  Usb2HcPpi->ClearRootHubPortFeature (
+               PeiServices,
+               Usb2HcPpi,
+               PortNum,
+               EfiUsbPortEnableChange
+               );
+
+  MicroSecondDelay ((RetryIndex + 1) * 50 * 1000);
 }
