@@ -2,20 +2,13 @@
   Helper routine and corresponding data struct used by USB Mouse Driver.
 
 Copyright (c) 2004 - 2018, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
 #ifndef _EFI_USB_MOUSE_H_
 #define _EFI_USB_MOUSE_H_
 
-
 #include <Uefi.h>
 
 #include <Protocol/SimplePointer.h>
@@ -33,14 +26,14 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 
 #include <IndustryStandard/Usb.h>
 
-#define CLASS_HID               3
-#define SUBCLASS_BOOT           1
-#define PROTOCOL_MOUSE          2
+#define CLASS_HID       3
+#define SUBCLASS_BOOT   1
+#define PROTOCOL_MOUSE  2
 
-#define BOOT_PROTOCOL           0
-#define REPORT_PROTOCOL         1
+#define BOOT_PROTOCOL    0
+#define REPORT_PROTOCOL  1
 
-#define USB_MOUSE_DEV_SIGNATURE SIGNATURE_32 ('u', 'm', 'o', 'u')
+#define USB_MOUSE_DEV_SIGNATURE  SIGNATURE_32 ('u', 'm', 'o', 'u')
 
 //
 // A common header for usb standard descriptor.
@@ -48,8 +41,8 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 //
 #pragma pack(1)
 typedef struct {
-  UINT8                   Len;
-  UINT8                   Type;
+  UINT8    Len;
+  UINT8    Type;
 } USB_DESC_HEAD;
 #pragma pack()
 
@@ -57,33 +50,33 @@ typedef struct {
 /// Button range and status
 ///
 typedef struct {
-  BOOLEAN ButtonDetected;
-  UINT8   ButtonMinIndex;
-  UINT8   ButtonMaxIndex;
-  UINT8   Reserved;
+  BOOLEAN    ButtonDetected;
+  UINT8      ButtonMinIndex;
+  UINT8      ButtonMaxIndex;
+  UINT8      Reserved;
 } USB_MOUSE_BUTTON_DATA;
 
 ///
 /// Device instance of USB mouse.
 ///
 typedef struct {
-  UINTN                         Signature;
-  EFI_DEVICE_PATH_PROTOCOL      *DevicePath;
-  EFI_EVENT                     DelayedRecoveryEvent;
-  EFI_USB_IO_PROTOCOL           *UsbIo;
-  EFI_USB_INTERFACE_DESCRIPTOR  InterfaceDescriptor;
-  EFI_USB_ENDPOINT_DESCRIPTOR   IntEndpointDescriptor;
-  UINT8                         NumberOfButtons;
-  INT32                         XLogicMax;
-  INT32                         XLogicMin;
-  INT32                         YLogicMax;
-  INT32                         YLogicMin;
-  EFI_SIMPLE_POINTER_PROTOCOL   SimplePointerProtocol;
-  EFI_SIMPLE_POINTER_STATE      State;
-  EFI_SIMPLE_POINTER_MODE       Mode;
-  BOOLEAN                       StateChanged;
-  USB_MOUSE_BUTTON_DATA         PrivateData;
-  EFI_UNICODE_STRING_TABLE      *ControllerNameTable;
+  UINTN                           Signature;
+  EFI_DEVICE_PATH_PROTOCOL        *DevicePath;
+  EFI_EVENT                       DelayedRecoveryEvent;
+  EFI_USB_IO_PROTOCOL             *UsbIo;
+  EFI_USB_INTERFACE_DESCRIPTOR    InterfaceDescriptor;
+  EFI_USB_ENDPOINT_DESCRIPTOR     IntEndpointDescriptor;
+  UINT8                           NumberOfButtons;
+  INT32                           XLogicMax;
+  INT32                           XLogicMin;
+  INT32                           YLogicMax;
+  INT32                           YLogicMin;
+  EFI_SIMPLE_POINTER_PROTOCOL     SimplePointerProtocol;
+  EFI_SIMPLE_POINTER_STATE        State;
+  EFI_SIMPLE_POINTER_MODE         Mode;
+  BOOLEAN                         StateChanged;
+  USB_MOUSE_BUTTON_DATA           PrivateData;
+  EFI_UNICODE_STRING_TABLE        *ControllerNameTable;
 } USB_MOUSE_DEV;
 
 ///
@@ -91,21 +84,21 @@ typedef struct {
 ///
 
 typedef union {
-  UINT8   Uint8;
-  UINT16  Uint16;
-  UINT32  Uint32;
-  INT8    Int8;
-  INT16   Int16;
-  INT32   Int32;
-  UINT8   *LongData;
+  UINT8     Uint8;
+  UINT16    Uint16;
+  UINT32    Uint32;
+  INT8      Int8;
+  INT16     Int16;
+  INT32     Int32;
+  UINT8     *LongData;
 } HID_DATA;
 
 typedef struct {
-  UINT16    Format;
-  UINT8     Size;
-  UINT8     Type;
-  UINT8     Tag;
-  HID_DATA  Data;
+  UINT16      Format;
+  UINT8       Size;
+  UINT8       Type;
+  UINT8       Tag;
+  HID_DATA    Data;
 } HID_ITEM;
 
 #define USB_MOUSE_DEV_FROM_MOUSE_PROTOCOL(a) \
@@ -136,15 +129,15 @@ extern EFI_COMPONENT_NAME2_PROTOCOL  gUsbMouseComponentName2;
 EFI_STATUS
 EFIAPI
 USBMouseDriverBindingSupported (
-  IN EFI_DRIVER_BINDING_PROTOCOL    *This,
-  IN EFI_HANDLE                     Controller,
-  IN EFI_DEVICE_PATH_PROTOCOL       *RemainingDevicePath
+  IN EFI_DRIVER_BINDING_PROTOCOL  *This,
+  IN EFI_HANDLE                   Controller,
+  IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   );
 
 /**
   Starts the mouse device with this driver.
 
-  This function consumes USB I/O Portocol, intializes USB mouse device,
+  This function consumes USB I/O Protocol, initializes USB mouse device,
   installs Simple Pointer Protocol, and submits Asynchronous Interrupt
   Transfer to manage the USB mouse device.
 
@@ -163,9 +156,9 @@ USBMouseDriverBindingSupported (
 EFI_STATUS
 EFIAPI
 USBMouseDriverBindingStart (
-  IN EFI_DRIVER_BINDING_PROTOCOL    *This,
-  IN EFI_HANDLE                     Controller,
-  IN EFI_DEVICE_PATH_PROTOCOL       *RemainingDevicePath
+  IN EFI_DRIVER_BINDING_PROTOCOL  *This,
+  IN EFI_HANDLE                   Controller,
+  IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   );
 
 /**
@@ -184,10 +177,10 @@ USBMouseDriverBindingStart (
 EFI_STATUS
 EFIAPI
 USBMouseDriverBindingStop (
-  IN  EFI_DRIVER_BINDING_PROTOCOL   *This,
-  IN  EFI_HANDLE                    Controller,
-  IN  UINTN                         NumberOfChildren,
-  IN  EFI_HANDLE                    *ChildHandleBuffer
+  IN  EFI_DRIVER_BINDING_PROTOCOL  *This,
+  IN  EFI_HANDLE                   Controller,
+  IN  UINTN                        NumberOfChildren,
+  IN  EFI_HANDLE                   *ChildHandleBuffer
   );
 
 //
@@ -297,11 +290,11 @@ UsbMouseComponentNameGetDriverName (
 EFI_STATUS
 EFIAPI
 UsbMouseComponentNameGetControllerName (
-  IN  EFI_COMPONENT_NAME_PROTOCOL                     *This,
-  IN  EFI_HANDLE                                      ControllerHandle,
-  IN  EFI_HANDLE                                      ChildHandle        OPTIONAL,
-  IN  CHAR8                                           *Language,
-  OUT CHAR16                                          **ControllerName
+  IN  EFI_COMPONENT_NAME_PROTOCOL  *This,
+  IN  EFI_HANDLE                   ControllerHandle,
+  IN  EFI_HANDLE                   ChildHandle        OPTIONAL,
+  IN  CHAR8                        *Language,
+  OUT CHAR16                       **ControllerName
   );
 
 //
@@ -343,8 +336,8 @@ GetMouseState (
 EFI_STATUS
 EFIAPI
 UsbMouseReset (
-  IN EFI_SIMPLE_POINTER_PROTOCOL    *This,
-  IN BOOLEAN                        ExtendedVerification
+  IN EFI_SIMPLE_POINTER_PROTOCOL  *This,
+  IN BOOLEAN                      ExtendedVerification
   );
 
 /**
@@ -357,8 +350,8 @@ UsbMouseReset (
 VOID
 EFIAPI
 UsbMouseWaitForInput (
-  IN  EFI_EVENT               Event,
-  IN  VOID                    *Context
+  IN  EFI_EVENT  Event,
+  IN  VOID       *Context
   );
 
 //
@@ -376,7 +369,7 @@ UsbMouseWaitForInput (
 **/
 BOOLEAN
 IsUsbMouse (
-  IN  EFI_USB_IO_PROTOCOL     *UsbIo
+  IN  EFI_USB_IO_PROTOCOL  *UsbIo
   );
 
 /**
@@ -396,7 +389,7 @@ IsUsbMouse (
 **/
 EFI_STATUS
 InitializeUsbMouseDevice (
-  IN OUT USB_MOUSE_DEV           *UsbMouseDev
+  IN OUT USB_MOUSE_DEV  *UsbMouseDev
   );
 
 /**
@@ -409,7 +402,7 @@ InitializeUsbMouseDevice (
   @param  Data             A pointer to a buffer that is filled with key data which is
                            retrieved via asynchronous interrupt transfer.
   @param  DataLength       Indicates the size of the data buffer.
-  @param  Context          Pointing to USB_KB_DEV instance.
+  @param  Context          Pointing to USB_MOUSE_DEV instance.
   @param  Result           Indicates the result of the asynchronous interrupt transfer.
 
   @retval EFI_SUCCESS      Asynchronous interrupt transfer is handled successfully.
@@ -419,10 +412,10 @@ InitializeUsbMouseDevice (
 EFI_STATUS
 EFIAPI
 OnMouseInterruptComplete (
-  IN  VOID        *Data,
-  IN  UINTN       DataLength,
-  IN  VOID        *Context,
-  IN  UINT32      Result
+  IN  VOID    *Data,
+  IN  UINTN   DataLength,
+  IN  VOID    *Context,
+  IN  UINT32  Result
   );
 
 /**
@@ -441,8 +434,8 @@ OnMouseInterruptComplete (
 VOID
 EFIAPI
 USBMouseRecoveryHandler (
-  IN    EFI_EVENT    Event,
-  IN    VOID         *Context
+  IN    EFI_EVENT  Event,
+  IN    VOID       *Context
   );
 
 /**
@@ -463,9 +456,9 @@ USBMouseRecoveryHandler (
 **/
 EFI_STATUS
 ParseMouseReportDescriptor (
-  OUT USB_MOUSE_DEV   *UsbMouse,
-  IN  UINT8           *ReportDescriptor,
-  IN  UINTN           ReportSize
+  OUT USB_MOUSE_DEV  *UsbMouse,
+  IN  UINT8          *ReportDescriptor,
+  IN  UINTN          ReportSize
   );
 
 #endif
