@@ -3,25 +3,21 @@
   This library class defines a set of interfaces to customize Display module
 
 Copyright (c) 2013 - 2018, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials are licensed and made available under
-the terms and conditions of the BSD License that accompanies this distribution.
-The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php.
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 #include "CustomizedDisplayLibInternal.h"
 
-EFI_GUID          gCustomizedDisplayLibGuid = { 0x99fdc8fd, 0x849b, 0x4eba, { 0xad, 0x13, 0xfb, 0x96, 0x99, 0xc9, 0xa, 0x4d } };
+EFI_GUID  gCustomizedDisplayLibGuid = {
+  0x99fdc8fd, 0x849b, 0x4eba, { 0xad, 0x13, 0xfb, 0x96, 0x99, 0xc9, 0xa, 0x4d }
+};
 
-EFI_HII_HANDLE    mCDLStringPackHandle;
-UINT16            gClassOfVfr;                 // Formset class information
-BOOLEAN           gLibIsFirstForm = TRUE;
-BANNER_DATA       *gBannerData;
+EFI_HII_HANDLE  mCDLStringPackHandle;
+UINT16          gClassOfVfr;                   // Formset class information
+BOOLEAN         gLibIsFirstForm = TRUE;
+BANNER_DATA     *gBannerData;
 
-UINTN             gFooterHeight;
+UINTN  gFooterHeight;
 
 /**
 +------------------------------------------------------------------------------+
@@ -57,35 +53,36 @@ Statement
 EFI_STATUS
 EFIAPI
 DisplayPageFrame (
-  IN FORM_DISPLAY_ENGINE_FORM       *FormData,
-  OUT EFI_SCREEN_DESCRIPTOR         *ScreenForStatement
+  IN FORM_DISPLAY_ENGINE_FORM  *FormData,
+  OUT EFI_SCREEN_DESCRIPTOR    *ScreenForStatement
   )
 {
-  EFI_STATUS             Status;
+  EFI_STATUS  Status;
 
   ASSERT (FormData != NULL && ScreenForStatement != NULL);
-  if (FormData == NULL || ScreenForStatement == NULL) {
+  if ((FormData == NULL) || (ScreenForStatement == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
-  Status = ScreenDiemensionInfoValidate (FormData);
+  Status = ScreenDimensionInfoValidate (FormData);
   if (EFI_ERROR (Status)) {
     return Status;
   }
 
   gClassOfVfr = FORMSET_CLASS_PLATFORM_SETUP;
 
-  ProcessExternedOpcode(FormData);
+  ProcessExternedOpcode (FormData);
 
   //
   // Calculate the ScreenForStatement.
   //
-  ScreenForStatement->BottomRow   = gScreenDimensions.BottomRow - STATUS_BAR_HEIGHT - gFooterHeight;
+  ScreenForStatement->BottomRow = gScreenDimensions.BottomRow - STATUS_BAR_HEIGHT - gFooterHeight;
   if (gClassOfVfr == FORMSET_CLASS_FRONT_PAGE) {
-    ScreenForStatement->TopRow    = gScreenDimensions.TopRow + FRONT_PAGE_HEADER_HEIGHT;
+    ScreenForStatement->TopRow = gScreenDimensions.TopRow + FRONT_PAGE_HEADER_HEIGHT;
   } else {
-    ScreenForStatement->TopRow    = gScreenDimensions.TopRow + NONE_FRONT_PAGE_HEADER_HEIGHT;
+    ScreenForStatement->TopRow = gScreenDimensions.TopRow + NONE_FRONT_PAGE_HEADER_HEIGHT;
   }
+
   ScreenForStatement->LeftColumn  = gScreenDimensions.LeftColumn;
   ScreenForStatement->RightColumn = gScreenDimensions.RightColumn;
 
@@ -111,7 +108,7 @@ DisplayPageFrame (
 
   PrintFramework (FormData);
 
-  UpdateStatusBar(NV_UPDATE_REQUIRED, FormData->SettingChangedFlag);
+  UpdateStatusBar (NV_UPDATE_REQUIRED, FormData->SettingChangedFlag);
 
   return EFI_SUCCESS;
 }
@@ -128,27 +125,27 @@ DisplayPageFrame (
 VOID
 EFIAPI
 RefreshKeyHelp (
-  IN FORM_DISPLAY_ENGINE_FORM      *FormData,
-  IN FORM_DISPLAY_ENGINE_STATEMENT *Statement,
-  IN  BOOLEAN                      Selected
+  IN FORM_DISPLAY_ENGINE_FORM       *FormData,
+  IN FORM_DISPLAY_ENGINE_STATEMENT  *Statement,
+  IN  BOOLEAN                       Selected
   )
 {
-  UINTN                  SecCol;
-  UINTN                  ThdCol;
-  UINTN                  RightColumnOfHelp;
-  UINTN                  TopRowOfHelp;
-  UINTN                  BottomRowOfHelp;
-  UINTN                  StartColumnOfHelp;
-  EFI_IFR_NUMERIC        *NumericOp;
-  EFI_IFR_DATE           *DateOp;
-  EFI_IFR_TIME           *TimeOp;
-  BOOLEAN                HexDisplay;
-  UINTN                  ColumnWidth1;
-  UINTN                  ColumnWidth2;
-  UINTN                  ColumnWidth3;
-  CHAR16                 *ColumnStr1;
-  CHAR16                 *ColumnStr2;
-  CHAR16                 *ColumnStr3;
+  UINTN            SecCol;
+  UINTN            ThdCol;
+  UINTN            RightColumnOfHelp;
+  UINTN            TopRowOfHelp;
+  UINTN            BottomRowOfHelp;
+  UINTN            StartColumnOfHelp;
+  EFI_IFR_NUMERIC  *NumericOp;
+  EFI_IFR_DATE     *DateOp;
+  EFI_IFR_TIME     *TimeOp;
+  BOOLEAN          HexDisplay;
+  UINTN            ColumnWidth1;
+  UINTN            ColumnWidth2;
+  UINTN            ColumnWidth3;
+  CHAR16           *ColumnStr1;
+  CHAR16           *ColumnStr2;
+  CHAR16           *ColumnStr3;
 
   ASSERT (FormData != NULL);
   if (FormData == NULL) {
@@ -161,8 +158,8 @@ RefreshKeyHelp (
     return;
   }
 
-  SecCol            = gScreenDimensions.LeftColumn + (gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn) / 3;
-  ThdCol            = gScreenDimensions.LeftColumn + (gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn) / 3 * 2;
+  SecCol = gScreenDimensions.LeftColumn + (gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn) / 3;
+  ThdCol = gScreenDimensions.LeftColumn + (gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn) / 3 * 2;
 
   //
   // + 2 means leave 1 space before the first hotkey info.
@@ -172,12 +169,12 @@ RefreshKeyHelp (
   TopRowOfHelp      = gScreenDimensions.BottomRow - STATUS_BAR_HEIGHT - gFooterHeight + 1;
   BottomRowOfHelp   = gScreenDimensions.BottomRow - STATUS_BAR_HEIGHT - 2;
 
-  ColumnWidth1      = SecCol - StartColumnOfHelp;
-  ColumnWidth2      = ThdCol - SecCol;
-  ColumnWidth3      = RightColumnOfHelp - ThdCol;
-  ColumnStr1        = gLibEmptyString;
-  ColumnStr2        = gLibEmptyString;
-  ColumnStr3        = gLibEmptyString;
+  ColumnWidth1 = SecCol - StartColumnOfHelp;
+  ColumnWidth2 = ThdCol - SecCol;
+  ColumnWidth3 = RightColumnOfHelp - ThdCol;
+  ColumnStr1   = gLibEmptyString;
+  ColumnStr2   = gLibEmptyString;
+  ColumnStr3   = gLibEmptyString;
 
   //
   // Clean the space at gScreenDimensions.LeftColumn + 1.
@@ -196,139 +193,152 @@ RefreshKeyHelp (
     if (gClassOfVfr == FORMSET_CLASS_PLATFORM_SETUP) {
       ColumnStr3 = gEscapeString;
     }
+
     PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
 
     return;
   }
 
   HexDisplay = FALSE;
-  NumericOp = NULL;
-  DateOp    = NULL;
-  TimeOp    = NULL;
+  NumericOp  = NULL;
+  DateOp     = NULL;
+  TimeOp     = NULL;
   if (Statement->OpCode->OpCode == EFI_IFR_NUMERIC_OP) {
-    NumericOp = (EFI_IFR_NUMERIC *) Statement->OpCode;
+    NumericOp  = (EFI_IFR_NUMERIC *)Statement->OpCode;
     HexDisplay = (NumericOp->Flags & EFI_IFR_DISPLAY_UINT_HEX) == EFI_IFR_DISPLAY_UINT_HEX;
   } else if (Statement->OpCode->OpCode == EFI_IFR_DATE_OP) {
-    DateOp   = (EFI_IFR_DATE *) Statement->OpCode;
+    DateOp     = (EFI_IFR_DATE *)Statement->OpCode;
     HexDisplay = (DateOp->Flags & EFI_IFR_DISPLAY_UINT_HEX) == EFI_IFR_DISPLAY_UINT_HEX;
   } else if (Statement->OpCode->OpCode == EFI_IFR_TIME_OP) {
-    TimeOp  = (EFI_IFR_TIME *) Statement->OpCode;
+    TimeOp     = (EFI_IFR_TIME *)Statement->OpCode;
     HexDisplay = (TimeOp->Flags & EFI_IFR_DISPLAY_UINT_HEX) == EFI_IFR_DISPLAY_UINT_HEX;
   }
+
   switch (Statement->OpCode->OpCode) {
-  case EFI_IFR_ORDERED_LIST_OP:
-  case EFI_IFR_ONE_OF_OP:
-  case EFI_IFR_NUMERIC_OP:
-  case EFI_IFR_TIME_OP:
-  case EFI_IFR_DATE_OP:
-    if (!Selected) {
-      PrintHotKeyHelpString (FormData, TRUE);
+    case EFI_IFR_ORDERED_LIST_OP:
+    case EFI_IFR_ONE_OF_OP:
+    case EFI_IFR_NUMERIC_OP:
+    case EFI_IFR_TIME_OP:
+    case EFI_IFR_DATE_OP:
+      if (!Selected) {
+        PrintHotKeyHelpString (FormData, TRUE);
 
-      if (gClassOfVfr == FORMSET_CLASS_PLATFORM_SETUP) {
-        ColumnStr3 = gEscapeString;
-      }
-      PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
-
-      if ((Statement->OpCode->OpCode == EFI_IFR_DATE_OP) ||
-          (Statement->OpCode->OpCode == EFI_IFR_TIME_OP)) {
-        PrintAt (
-          ColumnWidth1,
-          StartColumnOfHelp,
-          BottomRowOfHelp,
-          L"%c%c%c%c%s",
-          ARROW_UP,
-          ARROW_DOWN,
-          ARROW_RIGHT,
-          ARROW_LEFT,
-          gMoveHighlight
-          );
-        PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gEnterString, ColumnWidth2);
-        PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, gAdjustNumber, ColumnWidth1);
-      } else {
-        PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
-        if (Statement->OpCode->OpCode == EFI_IFR_NUMERIC_OP && NumericOp != NULL && LibGetFieldFromNum(Statement->OpCode) != 0) {
-          ColumnStr1 = gAdjustNumber;
+        if (gClassOfVfr == FORMSET_CLASS_PLATFORM_SETUP) {
+          ColumnStr3 = gEscapeString;
         }
-        PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
-        PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gEnterString, ColumnWidth2);
-      }
-    } else {
-      PrintHotKeyHelpString (FormData, FALSE);
-      PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gEnterCommitString, ColumnWidth2);
 
-      //
-      // If it is a selected numeric with manual input, display different message
-      //
-      if ((Statement->OpCode->OpCode == EFI_IFR_NUMERIC_OP) ||
-          (Statement->OpCode->OpCode == EFI_IFR_DATE_OP) ||
-          (Statement->OpCode->OpCode == EFI_IFR_TIME_OP)) {
-        ColumnStr2 = HexDisplay ? gHexNumericInput : gDecNumericInput;
-        PrintStringAtWithWidth (StartColumnOfHelp, BottomRowOfHelp, gLibEmptyString, ColumnWidth1);
+        PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
+
+        if ((Statement->OpCode->OpCode == EFI_IFR_DATE_OP) ||
+            (Statement->OpCode->OpCode == EFI_IFR_TIME_OP))
+        {
+          PrintAt (
+            ColumnWidth1,
+            StartColumnOfHelp,
+            BottomRowOfHelp,
+            L"%c%c%c%c%s",
+            ARROW_UP,
+            ARROW_DOWN,
+            ARROW_RIGHT,
+            ARROW_LEFT,
+            gMoveHighlight
+            );
+          PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gEnterString, ColumnWidth2);
+          PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, gAdjustNumber, ColumnWidth1);
+        } else {
+          PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
+          if ((Statement->OpCode->OpCode == EFI_IFR_NUMERIC_OP) && (NumericOp != NULL) && (LibGetFieldFromNum (Statement->OpCode) != 0)) {
+            ColumnStr1 = gAdjustNumber;
+          }
+
+          PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
+          PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gEnterString, ColumnWidth2);
+        }
       } else {
-        PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
+        PrintHotKeyHelpString (FormData, FALSE);
+        PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gEnterCommitString, ColumnWidth2);
+
+        //
+        // If it is a selected numeric with manual input, display different message
+        //
+        if ((Statement->OpCode->OpCode == EFI_IFR_NUMERIC_OP) ||
+            (Statement->OpCode->OpCode == EFI_IFR_DATE_OP) ||
+            (Statement->OpCode->OpCode == EFI_IFR_TIME_OP))
+        {
+          ColumnStr2 = HexDisplay ? gHexNumericInput : gDecNumericInput;
+          PrintStringAtWithWidth (StartColumnOfHelp, BottomRowOfHelp, gLibEmptyString, ColumnWidth1);
+        } else {
+          PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
+        }
+
+        if (Statement->OpCode->OpCode == EFI_IFR_ORDERED_LIST_OP) {
+          ColumnStr1 = gPlusString;
+          ColumnStr3 = gMinusString;
+        }
+
+        PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
+        PrintStringAtWithWidth (ThdCol, TopRowOfHelp, ColumnStr3, ColumnWidth3);
+        PrintStringAtWithWidth (SecCol, TopRowOfHelp, ColumnStr2, ColumnWidth2);
+
+        PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, gEnterEscapeString, ColumnWidth3);
       }
 
-      if (Statement->OpCode->OpCode == EFI_IFR_ORDERED_LIST_OP) {
-        ColumnStr1 = gPlusString;
-        ColumnStr3 = gMinusString;
-      }
-      PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
-      PrintStringAtWithWidth (ThdCol, TopRowOfHelp, ColumnStr3, ColumnWidth3);
-      PrintStringAtWithWidth (SecCol, TopRowOfHelp, ColumnStr2, ColumnWidth2);
+      break;
 
-      PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, gEnterEscapeString, ColumnWidth3);
-    }
-    break;
-
-  case EFI_IFR_CHECKBOX_OP:
-    PrintHotKeyHelpString (FormData, TRUE);
-
-    if (gClassOfVfr == FORMSET_CLASS_PLATFORM_SETUP) {
-      ColumnStr3 = gEscapeString;
-    }
-    PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
-
-    PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
-    PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gToggleCheckBox, ColumnWidth2);
-    PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, gLibEmptyString, ColumnWidth1);
-    break;
-
-  case EFI_IFR_REF_OP:
-  case EFI_IFR_PASSWORD_OP:
-  case EFI_IFR_STRING_OP:
-  case EFI_IFR_TEXT_OP:
-  case EFI_IFR_ACTION_OP:
-  case EFI_IFR_RESET_BUTTON_OP:
-  case EFI_IFR_SUBTITLE_OP:
-     if (!Selected) {
+    case EFI_IFR_CHECKBOX_OP:
       PrintHotKeyHelpString (FormData, TRUE);
 
       if (gClassOfVfr == FORMSET_CLASS_PLATFORM_SETUP) {
         ColumnStr3 = gEscapeString;
       }
+
       PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
 
       PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
-      if (Statement->OpCode->OpCode != EFI_IFR_TEXT_OP && Statement->OpCode->OpCode != EFI_IFR_SUBTITLE_OP) {
-        ColumnStr2 = gEnterString;
-      }
-      PrintStringAtWithWidth (SecCol, BottomRowOfHelp, ColumnStr2, ColumnWidth2);
-      PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
-    } else {
-      PrintHotKeyHelpString (FormData, FALSE);
-      if (Statement->OpCode->OpCode != EFI_IFR_REF_OP) {
-        ColumnStr2 = gEnterCommitString;
-        ColumnStr3 = gEnterEscapeString;
-      }
-      PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
-      PrintStringAtWithWidth (StartColumnOfHelp, BottomRowOfHelp, ColumnStr1, ColumnWidth1);
-      PrintStringAtWithWidth (SecCol, BottomRowOfHelp, ColumnStr2, ColumnWidth2);
-      PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
-    }
-    break;
+      PrintStringAtWithWidth (SecCol, BottomRowOfHelp, gToggleCheckBox, ColumnWidth2);
+      PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, gLibEmptyString, ColumnWidth1);
+      break;
 
-  default:
-    break;
+    case EFI_IFR_REF_OP:
+    case EFI_IFR_PASSWORD_OP:
+    case EFI_IFR_STRING_OP:
+    case EFI_IFR_TEXT_OP:
+    case EFI_IFR_ACTION_OP:
+    case EFI_IFR_RESET_BUTTON_OP:
+    case EFI_IFR_SUBTITLE_OP:
+      if (!Selected) {
+        PrintHotKeyHelpString (FormData, TRUE);
+
+        if (gClassOfVfr == FORMSET_CLASS_PLATFORM_SETUP) {
+          ColumnStr3 = gEscapeString;
+        }
+
+        PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
+
+        PrintAt (ColumnWidth1, StartColumnOfHelp, BottomRowOfHelp, L"%c%c%s", ARROW_UP, ARROW_DOWN, gMoveHighlight);
+        if ((Statement->OpCode->OpCode != EFI_IFR_TEXT_OP) && (Statement->OpCode->OpCode != EFI_IFR_SUBTITLE_OP)) {
+          ColumnStr2 = gEnterString;
+        }
+
+        PrintStringAtWithWidth (SecCol, BottomRowOfHelp, ColumnStr2, ColumnWidth2);
+        PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
+      } else {
+        PrintHotKeyHelpString (FormData, FALSE);
+        if (Statement->OpCode->OpCode != EFI_IFR_REF_OP) {
+          ColumnStr2 = gEnterCommitString;
+          ColumnStr3 = gEnterEscapeString;
+        }
+
+        PrintStringAtWithWidth (StartColumnOfHelp, TopRowOfHelp, ColumnStr1, ColumnWidth1);
+        PrintStringAtWithWidth (StartColumnOfHelp, BottomRowOfHelp, ColumnStr1, ColumnWidth1);
+        PrintStringAtWithWidth (SecCol, BottomRowOfHelp, ColumnStr2, ColumnWidth2);
+        PrintStringAtWithWidth (ThdCol, BottomRowOfHelp, ColumnStr3, ColumnWidth3);
+      }
+
+      break;
+
+    default:
+      break;
   }
 }
 
@@ -344,57 +354,59 @@ RefreshKeyHelp (
 VOID
 EFIAPI
 UpdateStatusBar (
-  IN  UINTN                  MessageType,
-  IN  BOOLEAN                State
+  IN  UINTN    MessageType,
+  IN  BOOLEAN  State
   )
 {
-  UINTN           Index;
-  CHAR16          OptionWidth;
+  UINTN   Index;
+  CHAR16  OptionWidth;
 
-  OptionWidth = (CHAR16) ((gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn) / 3);
+  OptionWidth = (CHAR16)((gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn) / 3);
 
   switch (MessageType) {
-  case INPUT_ERROR:
-    if (State) {
-      gST->ConOut->SetAttribute (gST->ConOut, ERROR_TEXT);
-      PrintStringAt (
-        gScreenDimensions.LeftColumn + OptionWidth,
-        gScreenDimensions.BottomRow - 1,
-        gInputErrorMessage
-        );
-    } else {
-      gST->ConOut->SetAttribute (gST->ConOut, KEYHELP_BACKGROUND);
-      for (Index = 0; Index < (LibGetStringWidth (gInputErrorMessage) - 2) / 2; Index++) {
-        PrintStringAt (gScreenDimensions.LeftColumn + OptionWidth + Index, gScreenDimensions.BottomRow - 1, L"  ");
-      }
-    }
-    break;
-
-  case NV_UPDATE_REQUIRED:
-    //
-    // Global setting support. Show configuration change on every form.
-    //
-    if (State) {
-      gST->ConOut->SetAttribute (gST->ConOut, INFO_TEXT);
-      PrintStringAt (
-        gScreenDimensions.LeftColumn + OptionWidth * 2,
-        gScreenDimensions.BottomRow - 1,
-        gNvUpdateMessage
-        );
-    } else {
-      gST->ConOut->SetAttribute (gST->ConOut, KEYHELP_BACKGROUND);
-      for (Index = 0; Index < (LibGetStringWidth (gNvUpdateMessage) - 2) / 2; Index++) {
+    case INPUT_ERROR:
+      if (State) {
+        gST->ConOut->SetAttribute (gST->ConOut, ERROR_TEXT);
         PrintStringAt (
-          (gScreenDimensions.LeftColumn + OptionWidth * 2 + Index),
+          gScreenDimensions.LeftColumn + OptionWidth,
           gScreenDimensions.BottomRow - 1,
-          L"  "
+          gInputErrorMessage
           );
+      } else {
+        gST->ConOut->SetAttribute (gST->ConOut, KEYHELP_BACKGROUND);
+        for (Index = 0; Index < (LibGetStringWidth (gInputErrorMessage) - 2) / 2; Index++) {
+          PrintStringAt (gScreenDimensions.LeftColumn + OptionWidth + Index, gScreenDimensions.BottomRow - 1, L"  ");
+        }
       }
-    }
-    break;
 
-  default:
-    break;
+      break;
+
+    case NV_UPDATE_REQUIRED:
+      //
+      // Global setting support. Show configuration change on every form.
+      //
+      if (State) {
+        gST->ConOut->SetAttribute (gST->ConOut, INFO_TEXT);
+        PrintStringAt (
+          gScreenDimensions.LeftColumn + OptionWidth * 2,
+          gScreenDimensions.BottomRow - 1,
+          gNvUpdateMessage
+          );
+      } else {
+        gST->ConOut->SetAttribute (gST->ConOut, KEYHELP_BACKGROUND);
+        for (Index = 0; Index < (LibGetStringWidth (gNvUpdateMessage) - 2) / 2; Index++) {
+          PrintStringAt (
+            (gScreenDimensions.LeftColumn + OptionWidth * 2 + Index),
+            gScreenDimensions.BottomRow - 1,
+            L"  "
+            );
+        }
+      }
+
+      break;
+
+    default:
+      break;
   }
 }
 
@@ -410,32 +422,32 @@ UpdateStatusBar (
 VOID
 EFIAPI
 CreateDialog (
-  OUT EFI_INPUT_KEY  *Key,        OPTIONAL
+  OUT EFI_INPUT_KEY  *Key         OPTIONAL,
   ...
   )
 {
-  VA_LIST       Marker;
-  EFI_INPUT_KEY KeyValue;
-  EFI_STATUS    Status;
-  UINTN         LargestString;
-  UINTN         LineNum;
-  UINTN   Index;
-  UINTN   Count;
-  CHAR16  Character;
-  UINTN   Start;
-  UINTN   End;
-  UINTN   Top;
-  UINTN   Bottom;
-  CHAR16  *String;
-  UINTN   DimensionsWidth;
-  UINTN   DimensionsHeight;
-  UINTN   CurrentAttribute;
-  BOOLEAN CursorVisible;
+  VA_LIST        Marker;
+  EFI_INPUT_KEY  KeyValue;
+  EFI_STATUS     Status;
+  UINTN          LargestString;
+  UINTN          LineNum;
+  UINTN          Index;
+  UINTN          Count;
+  CHAR16         Character;
+  UINTN          Start;
+  UINTN          End;
+  UINTN          Top;
+  UINTN          Bottom;
+  CHAR16         *String;
+  UINTN          DimensionsWidth;
+  UINTN          DimensionsHeight;
+  UINTN          CurrentAttribute;
+  BOOLEAN        CursorVisible;
 
   //
   // If screen dimension info is not ready, get it from console.
   //
-  if (gScreenDimensions.RightColumn == 0 || gScreenDimensions.BottomRow == 0) {
+  if ((gScreenDimensions.RightColumn == 0) || (gScreenDimensions.BottomRow == 0)) {
     ZeroMem (&gScreenDimensions, sizeof (EFI_SCREEN_DESCRIPTOR));
     gST->ConOut->QueryMode (
                    gST->ConOut,
@@ -445,27 +457,28 @@ CreateDialog (
                    );
   }
 
-  DimensionsWidth   = gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn;
-  DimensionsHeight  = gScreenDimensions.BottomRow - gScreenDimensions.TopRow;
+  DimensionsWidth  = gScreenDimensions.RightColumn - gScreenDimensions.LeftColumn;
+  DimensionsHeight = gScreenDimensions.BottomRow - gScreenDimensions.TopRow;
 
   LargestString = 0;
   LineNum       = 0;
   VA_START (Marker, Key);
-  while  ((String = VA_ARG (Marker, CHAR16 *)) != NULL) {
-    LineNum ++;
+  while ((String = VA_ARG (Marker, CHAR16 *)) != NULL) {
+    LineNum++;
 
     if ((LibGetStringWidth (String) / 2) > LargestString) {
       LargestString = (LibGetStringWidth (String) / 2);
     }
   }
+
   VA_END (Marker);
 
   if ((LargestString + 2) > DimensionsWidth) {
     LargestString = DimensionsWidth - 2;
   }
 
-  CurrentAttribute  = gST->ConOut->Mode->Attribute;
-  CursorVisible     = gST->ConOut->Mode->CursorVisible;
+  CurrentAttribute = gST->ConOut->Mode->Attribute;
+  CursorVisible    = gST->ConOut->Mode->CursorVisible;
   gST->ConOut->EnableCursor (gST->ConOut, FALSE);
   gST->ConOut->SetAttribute (gST->ConOut, GetPopupColor ());
 
@@ -473,11 +486,11 @@ CreateDialog (
   // Subtract the PopUp width from total Columns, allow for one space extra on
   // each end plus a border.
   //
-  Start     = (DimensionsWidth - LargestString - 2) / 2 + gScreenDimensions.LeftColumn + 1;
-  End       = Start + LargestString + 1;
+  Start = (DimensionsWidth - LargestString - 2) / 2 + gScreenDimensions.LeftColumn + 1;
+  End   = Start + LargestString + 1;
 
-  Top       = ((DimensionsHeight - LineNum - 2) / 2) + gScreenDimensions.TopRow - 1;
-  Bottom    = Top + LineNum + 2;
+  Top    = ((DimensionsHeight - LineNum - 2) / 2) + gScreenDimensions.TopRow - 1;
+  Bottom = Top + LineNum + 2;
 
   Character = BOXDRAW_DOWN_RIGHT;
   PrintCharAt (Start, Top, Character);
@@ -493,7 +506,7 @@ CreateDialog (
   Count = 0;
   VA_START (Marker, Key);
   for (Index = Top; Index + 2 < Bottom; Index++, Count++) {
-    String = VA_ARG (Marker, CHAR16*);
+    String = VA_ARG (Marker, CHAR16 *);
 
     if (String[0] == CHAR_NULL) {
       //
@@ -528,17 +541,18 @@ CreateDialog (
     PrintCharAt (Start, Index + 1, Character);
     PrintCharAt (End - 1, Index + 1, Character);
   }
+
   VA_END (Marker);
 
   Character = BOXDRAW_UP_RIGHT;
   PrintCharAt (Start, Bottom - 1, Character);
   Character = BOXDRAW_HORIZONTAL;
   for (Index = Start; Index + 2 < End; Index++) {
-    PrintCharAt ((UINTN)-1, (UINTN) -1, Character);
+    PrintCharAt ((UINTN)-1, (UINTN)-1, Character);
   }
 
   Character = BOXDRAW_UP_LEFT;
-  PrintCharAt ((UINTN)-1, (UINTN) -1, Character);
+  PrintCharAt ((UINTN)-1, (UINTN)-1, Character);
 
   if (Key != NULL) {
     Status = WaitForKeyStroke (&KeyValue);
@@ -561,9 +575,9 @@ ConfirmDataChange (
   VOID
   )
 {
-  CHAR16                  YesResponse;
-  CHAR16                  NoResponse;
-  EFI_INPUT_KEY           Key;
+  CHAR16         YesResponse;
+  CHAR16         NoResponse;
+  EFI_INPUT_KEY  Key;
 
   gST->ConIn->ReadKeyStroke (gST->ConIn, &Key);
 
@@ -577,9 +591,9 @@ ConfirmDataChange (
     CreateDialog (&Key, gLibEmptyString, gSaveChanges, gAreYouSure, gLibEmptyString, NULL);
   } while
   (
-    (Key.ScanCode != SCAN_ESC) &&
-    ((Key.UnicodeChar | UPPER_LOWER_CASE_OFFSET) != (NoResponse | UPPER_LOWER_CASE_OFFSET)) &&
-    ((Key.UnicodeChar | UPPER_LOWER_CASE_OFFSET) != (YesResponse | UPPER_LOWER_CASE_OFFSET))
+   (Key.ScanCode != SCAN_ESC) &&
+   ((Key.UnicodeChar | UPPER_LOWER_CASE_OFFSET) != (NoResponse | UPPER_LOWER_CASE_OFFSET)) &&
+   ((Key.UnicodeChar | UPPER_LOWER_CASE_OFFSET) != (YesResponse | UPPER_LOWER_CASE_OFFSET))
   );
 
   if (Key.ScanCode == SCAN_ESC) {
@@ -623,14 +637,16 @@ FormExitPolicy (
 UINT64
 EFIAPI
 FormExitTimeout (
-  IN FORM_DISPLAY_ENGINE_FORM      *FormData
+  IN FORM_DISPLAY_ENGINE_FORM  *FormData
   )
 {
   return 0;
 }
+
 //
 // Print Functions
 //
+
 /**
   Prints a unicode string to the default console, at
   the supplied cursor position, using L"%s" format.
@@ -645,9 +661,9 @@ FormExitTimeout (
 UINTN
 EFIAPI
 PrintStringAt (
-  IN UINTN     Column,
-  IN UINTN     Row,
-  IN CHAR16    *String
+  IN UINTN   Column,
+  IN UINTN   Row,
+  IN CHAR16  *String
   )
 {
   return PrintAt (0, Column, Row, L"%s", String);
@@ -668,10 +684,10 @@ PrintStringAt (
 UINTN
 EFIAPI
 PrintStringAtWithWidth (
-  IN UINTN     Column,
-  IN UINTN     Row,
-  IN CHAR16    *String,
-  IN UINTN     Width
+  IN UINTN   Column,
+  IN UINTN   Row,
+  IN CHAR16  *String,
+  IN UINTN   Width
   )
 {
   return PrintAt (Width, Column, Row, L"%s", String);
@@ -691,9 +707,9 @@ PrintStringAtWithWidth (
 UINTN
 EFIAPI
 PrintCharAt (
-  IN UINTN     Column,
-  IN UINTN     Row,
-  CHAR16       Character
+  IN UINTN  Column,
+  IN UINTN  Row,
+  CHAR16    Character
   )
 {
   return PrintAt (0, Column, Row, L"%c", Character);
@@ -712,11 +728,11 @@ PrintCharAt (
 VOID
 EFIAPI
 ClearLines (
-  IN UINTN               LeftColumn,
-  IN UINTN               RightColumn,
-  IN UINTN               TopRow,
-  IN UINTN               BottomRow,
-  IN UINTN               TextAttribute
+  IN UINTN  LeftColumn,
+  IN UINTN  RightColumn,
+  IN UINTN  TopRow,
+  IN UINTN  BottomRow,
+  IN UINTN  TextAttribute
   )
 {
   CHAR16  *Buffer;
@@ -920,14 +936,14 @@ ClearDisplayPage (
 EFI_STATUS
 EFIAPI
 CustomizedDisplayLibConstructor (
-  IN      EFI_HANDLE                ImageHandle,
-  IN      EFI_SYSTEM_TABLE          *SystemTable
+  IN      EFI_HANDLE        ImageHandle,
+  IN      EFI_SYSTEM_TABLE  *SystemTable
   )
 {
   mCDLStringPackHandle = HiiAddPackages (&gCustomizedDisplayLibGuid, ImageHandle, CustomizedDisplayLibStrings, NULL);
   ASSERT (mCDLStringPackHandle != NULL);
 
-  InitializeLibStrings();
+  InitializeLibStrings ();
 
   return EFI_SUCCESS;
 }
@@ -949,10 +965,9 @@ CustomizedDisplayLibDestructor (
   IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
-  HiiRemovePackages(mCDLStringPackHandle);
+  HiiRemovePackages (mCDLStringPackHandle);
 
   FreeLibStrings ();
 
   return EFI_SUCCESS;
 }
-
