@@ -4,20 +4,12 @@
   with memory profile support.
 
   Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
-
 #include <PiDxe.h>
 
-
 #include <Library/MemoryAllocationLib.h>
 #include <Library/BaseMemoryLib.h>
 #include <Library/DebugLib.h>
@@ -55,7 +47,8 @@ InternalAllocatePages (
   if (EFI_ERROR (Status)) {
     return NULL;
   }
-  return (VOID *) (UINTN) Memory;
+
+  return (VOID *)(UINTN)Memory;
 }
 
 /**
@@ -82,7 +75,7 @@ AllocatePages (
   Buffer = InternalAllocatePages (EfiBootServicesData, Pages);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_PAGES,
       EfiBootServicesData,
       Buffer,
@@ -90,6 +83,7 @@ AllocatePages (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -117,7 +111,7 @@ AllocateRuntimePages (
   Buffer = InternalAllocatePages (EfiRuntimeServicesData, Pages);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RUNTIME_PAGES,
       EfiRuntimeServicesData,
       Buffer,
@@ -125,6 +119,7 @@ AllocateRuntimePages (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -152,7 +147,7 @@ AllocateReservedPages (
   Buffer = InternalAllocatePages (EfiReservedMemoryType, Pages);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RESERVED_PAGES,
       EfiReservedMemoryType,
       Buffer,
@@ -160,6 +155,7 @@ AllocateReservedPages (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -190,7 +186,7 @@ FreePages (
   EFI_STATUS  Status;
 
   ASSERT (Pages != 0);
-  Status = CoreFreePages ((EFI_PHYSICAL_ADDRESS) (UINTN) Buffer, Pages);
+  Status = CoreFreePages ((EFI_PHYSICAL_ADDRESS)(UINTN)Buffer, Pages);
   ASSERT_EFI_ERROR (Status);
 }
 
@@ -234,23 +230,25 @@ InternalAllocateAlignedPages (
   if (Pages == 0) {
     return NULL;
   }
+
   if (Alignment > EFI_PAGE_SIZE) {
     //
     // Calculate the total number of pages since alignment is larger than page size.
     //
-    AlignmentMask  = Alignment - 1;
-    RealPages      = Pages + EFI_SIZE_TO_PAGES (Alignment);
+    AlignmentMask = Alignment - 1;
+    RealPages     = Pages + EFI_SIZE_TO_PAGES (Alignment);
     //
     // Make sure that Pages plus EFI_SIZE_TO_PAGES (Alignment) does not overflow.
     //
     ASSERT (RealPages > Pages);
 
-    Status         = CoreAllocatePages (AllocateAnyPages, MemoryType, RealPages, &Memory);
+    Status = CoreAllocatePages (AllocateAnyPages, MemoryType, RealPages, &Memory);
     if (EFI_ERROR (Status)) {
       return NULL;
     }
-    AlignedMemory  = ((UINTN) Memory + AlignmentMask) & ~AlignmentMask;
-    UnalignedPages = EFI_SIZE_TO_PAGES (AlignedMemory - (UINTN) Memory);
+
+    AlignedMemory  = ((UINTN)Memory + AlignmentMask) & ~AlignmentMask;
+    UnalignedPages = EFI_SIZE_TO_PAGES (AlignedMemory - (UINTN)Memory);
     if (UnalignedPages > 0) {
       //
       // Free first unaligned page(s).
@@ -258,6 +256,7 @@ InternalAllocateAlignedPages (
       Status = CoreFreePages (Memory, UnalignedPages);
       ASSERT_EFI_ERROR (Status);
     }
+
     Memory         = AlignedMemory + EFI_PAGES_TO_SIZE (Pages);
     UnalignedPages = RealPages - Pages - UnalignedPages;
     if (UnalignedPages > 0) {
@@ -275,9 +274,11 @@ InternalAllocateAlignedPages (
     if (EFI_ERROR (Status)) {
       return NULL;
     }
-    AlignedMemory  = (UINTN) Memory;
+
+    AlignedMemory = (UINTN)Memory;
   }
-  return (VOID *) AlignedMemory;
+
+  return (VOID *)AlignedMemory;
 }
 
 /**
@@ -310,7 +311,7 @@ AllocateAlignedPages (
   Buffer = InternalAllocateAlignedPages (EfiBootServicesData, Pages, Alignment);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_ALIGNED_PAGES,
       EfiBootServicesData,
       Buffer,
@@ -318,6 +319,7 @@ AllocateAlignedPages (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -351,7 +353,7 @@ AllocateAlignedRuntimePages (
   Buffer = InternalAllocateAlignedPages (EfiRuntimeServicesData, Pages, Alignment);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_ALIGNED_RUNTIME_PAGES,
       EfiRuntimeServicesData,
       Buffer,
@@ -359,6 +361,7 @@ AllocateAlignedRuntimePages (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -392,7 +395,7 @@ AllocateAlignedReservedPages (
   Buffer = InternalAllocateAlignedPages (EfiReservedMemoryType, Pages, Alignment);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_ALIGNED_RESERVED_PAGES,
       EfiReservedMemoryType,
       Buffer,
@@ -400,6 +403,7 @@ AllocateAlignedReservedPages (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -430,7 +434,7 @@ FreeAlignedPages (
   EFI_STATUS  Status;
 
   ASSERT (Pages != 0);
-  Status = CoreFreePages ((EFI_PHYSICAL_ADDRESS) (UINTN) Buffer, Pages);
+  Status = CoreFreePages ((EFI_PHYSICAL_ADDRESS)(UINTN)Buffer, Pages);
   ASSERT_EFI_ERROR (Status);
 }
 
@@ -462,6 +466,7 @@ InternalAllocatePool (
   if (EFI_ERROR (Status)) {
     Memory = NULL;
   }
+
   return Memory;
 }
 
@@ -488,7 +493,7 @@ AllocatePool (
   Buffer = InternalAllocatePool (EfiBootServicesData, AllocationSize);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_POOL,
       EfiBootServicesData,
       Buffer,
@@ -496,6 +501,7 @@ AllocatePool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -522,7 +528,7 @@ AllocateRuntimePool (
   Buffer = InternalAllocatePool (EfiRuntimeServicesData, AllocationSize);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RUNTIME_POOL,
       EfiRuntimeServicesData,
       Buffer,
@@ -530,6 +536,7 @@ AllocateRuntimePool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -556,7 +563,7 @@ AllocateReservedPool (
   Buffer = InternalAllocatePool (EfiReservedMemoryType, AllocationSize);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RESERVED_POOL,
       EfiReservedMemoryType,
       Buffer,
@@ -564,6 +571,7 @@ AllocateReservedPool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -593,6 +601,7 @@ InternalAllocateZeroPool (
   if (Memory != NULL) {
     Memory = ZeroMem (Memory, AllocationSize);
   }
+
   return Memory;
 }
 
@@ -620,7 +629,7 @@ AllocateZeroPool (
   Buffer = InternalAllocateZeroPool (EfiBootServicesData, AllocationSize);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_ZERO_POOL,
       EfiBootServicesData,
       Buffer,
@@ -628,6 +637,7 @@ AllocateZeroPool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -655,7 +665,7 @@ AllocateRuntimeZeroPool (
   Buffer = InternalAllocateZeroPool (EfiRuntimeServicesData, AllocationSize);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RUNTIME_ZERO_POOL,
       EfiRuntimeServicesData,
       Buffer,
@@ -663,6 +673,7 @@ AllocateRuntimeZeroPool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -690,7 +701,7 @@ AllocateReservedZeroPool (
   Buffer = InternalAllocateZeroPool (EfiReservedMemoryType, AllocationSize);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RESERVED_ZERO_POOL,
       EfiReservedMemoryType,
       Buffer,
@@ -698,6 +709,7 @@ AllocateReservedZeroPool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -728,12 +740,13 @@ InternalAllocateCopyPool (
   VOID  *Memory;
 
   ASSERT (Buffer != NULL);
-  ASSERT (AllocationSize <= (MAX_ADDRESS - (UINTN) Buffer + 1));
+  ASSERT (AllocationSize <= (MAX_ADDRESS - (UINTN)Buffer + 1));
 
   Memory = InternalAllocatePool (PoolType, AllocationSize);
   if (Memory != NULL) {
-     Memory = CopyMem (Memory, Buffer, AllocationSize);
+    Memory = CopyMem (Memory, Buffer, AllocationSize);
   }
+
   return Memory;
 }
 
@@ -766,7 +779,7 @@ AllocateCopyPool (
   NewBuffer = InternalAllocateCopyPool (EfiBootServicesData, AllocationSize, Buffer);
   if (NewBuffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_COPY_POOL,
       EfiBootServicesData,
       NewBuffer,
@@ -774,6 +787,7 @@ AllocateCopyPool (
       NULL
       );
   }
+
   return NewBuffer;
 }
 
@@ -806,7 +820,7 @@ AllocateRuntimeCopyPool (
   NewBuffer = InternalAllocateCopyPool (EfiRuntimeServicesData, AllocationSize, Buffer);
   if (NewBuffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RUNTIME_COPY_POOL,
       EfiRuntimeServicesData,
       NewBuffer,
@@ -814,6 +828,7 @@ AllocateRuntimeCopyPool (
       NULL
       );
   }
+
   return NewBuffer;
 }
 
@@ -846,7 +861,7 @@ AllocateReservedCopyPool (
   NewBuffer = InternalAllocateCopyPool (EfiReservedMemoryType, AllocationSize, Buffer);
   if (NewBuffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_ALLOCATE_RESERVED_COPY_POOL,
       EfiRuntimeServicesData,
       NewBuffer,
@@ -854,6 +869,7 @@ AllocateReservedCopyPool (
       NULL
       );
   }
+
   return NewBuffer;
 }
 
@@ -890,10 +906,11 @@ InternalReallocatePool (
   VOID  *NewBuffer;
 
   NewBuffer = InternalAllocateZeroPool (PoolType, NewSize);
-  if (NewBuffer != NULL && OldBuffer != NULL) {
+  if ((NewBuffer != NULL) && (OldBuffer != NULL)) {
     CopyMem (NewBuffer, OldBuffer, MIN (OldSize, NewSize));
     FreePool (OldBuffer);
   }
+
   return NewBuffer;
 }
 
@@ -931,7 +948,7 @@ ReallocatePool (
   Buffer = InternalReallocatePool (EfiBootServicesData, OldSize, NewSize, OldBuffer);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_REALLOCATE_POOL,
       EfiBootServicesData,
       Buffer,
@@ -939,6 +956,7 @@ ReallocatePool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -976,7 +994,7 @@ ReallocateRuntimePool (
   Buffer = InternalReallocatePool (EfiRuntimeServicesData, OldSize, NewSize, OldBuffer);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_REALLOCATE_RUNTIME_POOL,
       EfiRuntimeServicesData,
       Buffer,
@@ -984,6 +1002,7 @@ ReallocateRuntimePool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -1021,7 +1040,7 @@ ReallocateReservedPool (
   Buffer = InternalReallocatePool (EfiReservedMemoryType, OldSize, NewSize, OldBuffer);
   if (Buffer != NULL) {
     MemoryProfileLibRecord (
-      (PHYSICAL_ADDRESS) (UINTN) RETURN_ADDRESS(0),
+      (PHYSICAL_ADDRESS)(UINTN)RETURN_ADDRESS (0),
       MEMORY_PROFILE_ACTION_LIB_REALLOCATE_RESERVED_POOL,
       EfiReservedMemoryType,
       Buffer,
@@ -1029,6 +1048,7 @@ ReallocateReservedPool (
       NULL
       );
   }
+
   return Buffer;
 }
 
@@ -1049,12 +1069,11 @@ ReallocateReservedPool (
 VOID
 EFIAPI
 FreePool (
-  IN VOID   *Buffer
+  IN VOID  *Buffer
   )
 {
-  EFI_STATUS    Status;
+  EFI_STATUS  Status;
 
   Status = CoreFreePool (Buffer);
   ASSERT_EFI_ERROR (Status);
 }
-
