@@ -1,14 +1,8 @@
 /** @file
 Private structure, MACRO and function definitions for User Interface related functionalities.
 
-Copyright (c) 2004 - 2013, Intel Corporation. All rights reserved.<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+Copyright (c) 2004 - 2018, Intel Corporation. All rights reserved.<BR>
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -17,17 +11,17 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 
 /**
   Get the expression list count.
-  
-  @param  Level                  Which type this expression belong to. Form, 
+
+  @param  Level                  Which type this expression belong to. Form,
                                  statement or option?
 
   @retval >=0                    The expression count
   @retval -1                     Input parameter error.
 
 **/
-INTN 
+INTN
 GetConditionalExpressionCount (
-  IN EXPRESS_LEVEL       Level
+  IN EXPRESS_LEVEL  Level
   );
 
 /**
@@ -69,13 +63,13 @@ ResetScopeStack (
 **/
 EFI_STATUS
 PushScope (
-  IN UINT8   Operand
+  IN UINT8  Operand
   );
 
 /**
   Get the expression Buffer pointer.
-  
-  @param  Level                  Which type this expression belong to. Form, 
+
+  @param  Level                  Which type this expression belong to. Form,
                                  statement or option?
 
   @retval  The start pointer of the expression buffer or NULL.
@@ -83,7 +77,7 @@ PushScope (
 **/
 FORM_EXPRESSION **
 GetConditionalExpressionList (
-  IN EXPRESS_LEVEL       Level
+  IN EXPRESS_LEVEL  Level
   );
 
 /**
@@ -98,7 +92,7 @@ GetConditionalExpressionList (
 **/
 EFI_STATUS
 PopScope (
-  OUT UINT8     *Operand
+  OUT UINT8  *Operand
   );
 
 /**
@@ -137,14 +131,14 @@ PushCurrentExpression (
 **/
 VOID
 ExtendValueToU64 (
-  IN  EFI_HII_VALUE   *Value
+  IN  EFI_HII_VALUE  *Value
   );
 
 /**
   Push the expression options onto the Stack.
 
   @param  Pointer                Pointer to the current expression.
-  @param  Level                  Which type this expression belong to. Form, 
+  @param  Level                  Which type this expression belong to. Form,
                                  statement or option?
 
   @retval EFI_SUCCESS            The value was pushed onto the stack.
@@ -153,14 +147,14 @@ ExtendValueToU64 (
 **/
 EFI_STATUS
 PushConditionalExpression (
-  IN FORM_EXPRESSION   *Pointer,
-  IN EXPRESS_LEVEL     Level
+  IN FORM_EXPRESSION  *Pointer,
+  IN EXPRESS_LEVEL    Level
   );
 
 /**
   Pop the expression options from the Stack
 
-  @param  Level                  Which type this expression belong to. Form, 
+  @param  Level                  Which type this expression belong to. Form,
                                  statement or option?
 
   @retval EFI_SUCCESS            The value was pushed onto the stack.
@@ -169,7 +163,7 @@ PushConditionalExpression (
 **/
 EFI_STATUS
 PopConditionalExpression (
-  IN  EXPRESS_LEVEL      Level
+  IN  EXPRESS_LEVEL  Level
   );
 
 /**
@@ -183,7 +177,7 @@ PopConditionalExpression (
 **/
 EFI_STATUS
 PopMapExpressionList (
-  OUT VOID    **Pointer
+  OUT VOID  **Pointer
   );
 
 /**
@@ -197,7 +191,7 @@ PopMapExpressionList (
 **/
 EFI_STATUS
 PopCurrentExpression (
-  OUT VOID    **Pointer
+  OUT VOID  **Pointer
   );
 
 /**
@@ -224,26 +218,27 @@ EvaluateExpression (
   IN FORM_BROWSER_FORM     *Form,
   IN OUT FORM_EXPRESSION   *Expression
   );
+
 /**
-  Return the result of the expression list. Check the expression list and 
-  return the highest priority express result.  
+  Return the result of the expression list. Check the expression list and
+  return the highest priority express result.
   Priority: DisableIf > SuppressIf > GrayOutIf > FALSE
 
   @param  ExpList             The input expression list.
   @param  Evaluate            Whether need to evaluate the expression first.
   @param  FormSet             FormSet associated with this expression.
-  @param  Form                Form associated with this expression.  
+  @param  Form                Form associated with this expression.
 
-  @retval EXPRESS_RESULT      Return the higher priority express result. 
+  @retval EXPRESS_RESULT      Return the higher priority express result.
                               DisableIf > SuppressIf > GrayOutIf > FALSE
 
 **/
-EXPRESS_RESULT 
+EXPRESS_RESULT
 EvaluateExpressionList (
-  IN FORM_EXPRESSION_LIST *ExpList,
-  IN BOOLEAN              Evaluate,
-  IN FORM_BROWSER_FORMSET *FormSet, OPTIONAL
-  IN FORM_BROWSER_FORM    *Form OPTIONAL
+  IN FORM_EXPRESSION_LIST  *ExpList,
+  IN BOOLEAN               Evaluate,
+  IN FORM_BROWSER_FORMSET  *FormSet  OPTIONAL,
+  IN FORM_BROWSER_FORM     *Form OPTIONAL
   );
 
 /**
