@@ -2,13 +2,7 @@
   InterLockedIncrement function
 
   Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -16,9 +10,10 @@
   Microsoft Visual Studio 7.1 Function Prototypes for I/O Intrinsics.
 **/
 
-long _InterlockedIncrement(
-   long * lpAddend
-);
+long
+_InterlockedIncrement (
+  long  *lpAddend
+  );
 
 #pragma intrinsic(_InterlockedIncrement)
 
@@ -38,9 +33,8 @@ long _InterlockedIncrement(
 UINT32
 EFIAPI
 InternalSyncIncrement (
-  IN      volatile UINT32           *Value
+  IN      volatile UINT32  *Value
   )
 {
   return _InterlockedIncrement ((long *)(Value));
 }
-
