@@ -5,12 +5,8 @@
   This file includes package header files, library classes and protocol, PPI & GUID definitions.
 
   Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
-   This program and the accompanying materials
-   are licensed and made available under the terms and conditions of the BSD License
-   which accompanies this distribution. The full text of the license may be found at
-   http://opensource.org/licenses/bsd-license.php.
-   THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-   WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  Copyright (c) 2024, American Megatrends International LLC. All rights reserved.<BR>
+   SPDX-License-Identifier: BSD-2-Clause-Patent
 **/
 
 #ifndef _UEFI_USB_LIB_INTERNAL_H_
@@ -22,8 +18,8 @@
 #include <Library/BaseMemoryLib.h>
 #include <Library/DebugLib.h>
 #include <Library/PcdLib.h>
+#include <Library/UefiBootServicesTableLib.h>
 
 #include <IndustryStandard/Usb.h>
 
-
 #endif
