@@ -23,20 +23,20 @@
 //
 // String token ID of VConfig command help message text.
 //
-GLOBAL_REMOVE_IF_UNREFERENCED EFI_STRING_ID mStringVConfigHelpTokenId = STRING_TOKEN (STR_VCONFIG_HELP);
+GLOBAL_REMOVE_IF_UNREFERENCED EFI_STRING_ID  mStringVConfigHelpTokenId = STRING_TOKEN (STR_VCONFIG_HELP);
 
-#define INVALID_NIC_INDEX   0xffff
-#define INVALID_VLAN_ID     0xffff
+#define INVALID_NIC_INDEX  0xffff
+#define INVALID_VLAN_ID    0xffff
 
 //
 // This is the generated String package data for all .UNI files.
 // This data array is ready to be used as input of HiiAddPackages() to
 // create a packagelist (which contains Form packages, String packages, etc).
 //
-extern UINT8      VConfigStrings[];
+extern UINT8  VConfigStrings[];
 
-EFI_HANDLE        mImageHandle  = NULL;
-EFI_HII_HANDLE    mHiiHandle    = NULL;
+EFI_HANDLE      mImageHandle = NULL;
+EFI_HII_HANDLE  mHiiHandle   = NULL;
 
 SHELL_PARAM_ITEM  mParamList[] = {
   {
@@ -66,14 +66,14 @@ SHELL_PARAM_ITEM  mParamList[] = {
 **/
 VOID
 LocateNicHandleBuffer (
-  OUT UINTN                       *NumberOfHandles,
-  OUT EFI_HANDLE                  **HandleBuffer
+  OUT UINTN       *NumberOfHandles,
+  OUT EFI_HANDLE  **HandleBuffer
   )
 {
   EFI_STATUS  Status;
 
-  *NumberOfHandles  = 0;
-  *HandleBuffer     = NULL;
+  *NumberOfHandles = 0;
+  *HandleBuffer    = NULL;
 
   Status = gBS->LocateHandleBuffer (
                   ByProtocol,
@@ -83,7 +83,7 @@ LocateNicHandleBuffer (
                   HandleBuffer
                   );
   if (EFI_ERROR (Status)) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_LOCATE_FAIL), mHiiHandle, Status);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_LOCATE_FAIL), mHiiHandle, Status);
   }
 }
 
@@ -98,7 +98,7 @@ LocateNicHandleBuffer (
 **/
 UINTN
 NicNameToIndex (
-  IN CHAR16                   *Name
+  IN CHAR16  *Name
   )
 {
   CHAR16  *Str;
@@ -116,7 +116,7 @@ NicNameToIndex (
     Str++;
   }
 
-  return (UINT16) StrDecimalToUintn (Name + 3);
+  return (UINT16)StrDecimalToUintn (Name + 3);
 }
 
 /**
@@ -130,7 +130,7 @@ NicNameToIndex (
 **/
 EFI_HANDLE
 NicNameToHandle (
-  IN CHAR16                   *Name
+  IN CHAR16  *Name
   )
 {
   UINTN       NumberOfHandles;
@@ -148,7 +148,7 @@ NicNameToHandle (
 
   Index = NicNameToIndex (Name);
   if (Index >= NumberOfHandles) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_INVALID_IF), mHiiHandle, Name);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_INVALID_IF), mHiiHandle, Name);
     Handle = NULL;
   } else {
     Handle = HandleBuffer[Index];
@@ -168,7 +168,7 @@ NicNameToHandle (
 **/
 EFI_VLAN_CONFIG_PROTOCOL *
 OpenVlanConfigProtocol (
-  IN EFI_HANDLE                 Handle
+  IN EFI_HANDLE  Handle
   )
 {
   EFI_VLAN_CONFIG_PROTOCOL  *VlanConfig;
@@ -177,7 +177,7 @@ OpenVlanConfigProtocol (
   gBS->OpenProtocol (
          Handle,
          &gEfiVlanConfigProtocolGuid,
-         (VOID **) &VlanConfig,
+         (VOID **)&VlanConfig,
          mImageHandle,
          Handle,
          EFI_OPEN_PROTOCOL_GET_PROTOCOL
@@ -194,7 +194,7 @@ OpenVlanConfigProtocol (
 **/
 VOID
 CloseVlanConfigProtocol (
-  IN EFI_HANDLE                 Handle
+  IN EFI_HANDLE  Handle
   )
 {
   gBS->CloseProtocol (
@@ -214,8 +214,8 @@ CloseVlanConfigProtocol (
 **/
 VOID
 ShowNicVlanInfo (
-  IN EFI_HANDLE              Handle,
-  IN UINTN                   NicIndex
+  IN EFI_HANDLE  Handle,
+  IN UINTN       NicIndex
   )
 {
   CHAR16                    *MacStr;
@@ -227,34 +227,31 @@ ShowNicVlanInfo (
 
   VlanConfig = OpenVlanConfigProtocol (Handle);
   if (VlanConfig == NULL) {
-    return ;
+    return;
   }
 
-  MacStr  = NULL;
-  Status  = NetLibGetMacString (Handle, mImageHandle, &MacStr);
+  MacStr = NULL;
+  Status = NetLibGetMacString (Handle, mImageHandle, &MacStr);
   if (EFI_ERROR (Status)) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_MAC_FAIL), mHiiHandle, Status);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_MAC_FAIL), mHiiHandle, Status);
     goto Exit;
   }
 
-  ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_ETH_MAC), mHiiHandle, NicIndex, MacStr);
+  ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_ETH_MAC), mHiiHandle, NicIndex, MacStr);
 
   Status = VlanConfig->Find (VlanConfig, NULL, &NumberOfVlan, &VlanData);
   if (EFI_ERROR (Status)) {
     if (Status == EFI_NOT_FOUND) {
-      ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_VLAN), mHiiHandle);
+      ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_VLAN), mHiiHandle);
     } else {
-      ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_FIND_FAIL), mHiiHandle, Status);
+      ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_FIND_FAIL), mHiiHandle, Status);
     }
 
     goto Exit;
   }
 
   for (Index = 0; Index < NumberOfVlan; Index++) {
-    ShellPrintHiiEx (
-      -1,
-      -1,
-      NULL,
+    ShellPrintHiiDefaultEx (
       STRING_TOKEN (STR_VCONFIG_VLAN_DISPLAY),
       mHiiHandle,
       VlanData[Index].VlanId,
@@ -281,7 +278,7 @@ Exit:
 **/
 VOID
 DisplayVlan (
-  IN CHAR16              *Name OPTIONAL
+  IN CHAR16  *Name OPTIONAL
   )
 {
   UINTN       NumberOfHandles;
@@ -295,11 +292,11 @@ DisplayVlan (
     //
     NicHandle = NicNameToHandle (Name);
     if (NicHandle == NULL) {
-      return ;
+      return;
     }
 
     ShowNicVlanInfo (NicHandle, 0);
-    return ;
+    return;
   }
 
   //
@@ -307,7 +304,7 @@ DisplayVlan (
   //
   LocateNicHandleBuffer (&NumberOfHandles, &HandleBuffer);
   if (NumberOfHandles == 0) {
-    return ;
+    return;
   }
 
   for (Index = 0; Index < NumberOfHandles; Index++) {
@@ -327,7 +324,7 @@ DisplayVlan (
 **/
 UINT16
 StrToVlanId (
-  IN CHAR16             *String
+  IN CHAR16  *String
   )
 {
   CHAR16  *Str;
@@ -345,7 +342,7 @@ StrToVlanId (
     return INVALID_VLAN_ID;
   }
 
-  return (UINT16) StrDecimalToUintn (String);
+  return (UINT16)StrDecimalToUintn (String);
 }
 
 /**
@@ -356,7 +353,7 @@ StrToVlanId (
 **/
 VOID
 AddVlan (
-  IN CHAR16             *ParamStr
+  IN CHAR16  *ParamStr
   )
 {
   CHAR16                    *Name;
@@ -371,17 +368,17 @@ AddVlan (
   EFI_VLAN_CONFIG_PROTOCOL  *VlanConfig;
   EFI_STATUS                Status;
 
-  VlanConfig  = NULL;
-  Priority    = 0;
+  VlanConfig = NULL;
+  Priority   = 0;
 
   if (ParamStr == NULL) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_IF), mHiiHandle);
-    return ;
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_IF), mHiiHandle);
+    return;
   }
 
   StrPtr = AllocateCopyPool (StrSize (ParamStr), ParamStr);
   if (StrPtr == NULL) {
-    return ;
+    return;
   }
 
   Name        = StrPtr;
@@ -435,13 +432,13 @@ AddVlan (
   // Check VLAN ID.
   //
   if ((VlanIdStr == NULL) || (*VlanIdStr == 0)) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_VID), mHiiHandle);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_VID), mHiiHandle);
     goto Exit;
   }
 
   VlanId = StrToVlanId (VlanIdStr);
   if (VlanId > 4094) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_INVALID_VID), mHiiHandle, VlanIdStr);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_INVALID_VID), mHiiHandle, VlanIdStr);
     goto Exit;
   }
 
@@ -451,7 +448,7 @@ AddVlan (
   if ((PriorityStr != NULL) && (*PriorityStr != 0)) {
     Priority = StrDecimalToUintn (PriorityStr);
     if (Priority > 7) {
-      ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_INVALID_PRIORITY), mHiiHandle, PriorityStr);
+      ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_INVALID_PRIORITY), mHiiHandle, PriorityStr);
       goto Exit;
     }
   }
@@ -459,21 +456,21 @@ AddVlan (
   //
   // Set VLAN
   //
-  Status = VlanConfig->Set (VlanConfig, (UINT16) VlanId, (UINT8) Priority);
+  Status = VlanConfig->Set (VlanConfig, (UINT16)VlanId, (UINT8)Priority);
   if (EFI_ERROR (Status)) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_SET_FAIL), mHiiHandle, Status);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_SET_FAIL), mHiiHandle, Status);
     goto Exit;
   }
 
   //
   // Connect the VLAN device.
   //
-  VlanHandle = NetLibGetVlanHandle (Handle, (UINT16) VlanId);
+  VlanHandle = NetLibGetVlanHandle (Handle, (UINT16)VlanId);
   if (VlanHandle != NULL) {
     gBS->ConnectController (VlanHandle, NULL, NULL, TRUE);
   }
 
-  ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_SET_SUCCESS), mHiiHandle);
+  ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_SET_SUCCESS), mHiiHandle);
 
 Exit:
   if (VlanConfig != NULL) {
@@ -491,7 +488,7 @@ Exit:
 **/
 VOID
 DeleteVlan (
-  IN CHAR16 *ParamStr
+  IN CHAR16  *ParamStr
   )
 {
   CHAR16                    *Name;
@@ -507,13 +504,13 @@ DeleteVlan (
   VlanConfig = NULL;
 
   if (ParamStr == NULL) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_IF), mHiiHandle);
-    return ;
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_IF), mHiiHandle);
+    return;
   }
 
   StrPtr = AllocateCopyPool (StrSize (ParamStr), ParamStr);
   if (StrPtr == NULL) {
-    return ;
+    return;
   }
 
   Name      = StrPtr;
@@ -541,26 +538,26 @@ DeleteVlan (
   //
   // Check VLAN ID
   //
-  if (VlanIdStr == NULL || *VlanIdStr == 0) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_VID), mHiiHandle);
+  if ((VlanIdStr == NULL) || (*VlanIdStr == 0)) {
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_VID), mHiiHandle);
     goto Exit;
   }
 
   VlanId = StrToVlanId (VlanIdStr);
   if (VlanId > 4094) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_INVALID_VID), mHiiHandle, VlanIdStr);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_INVALID_VID), mHiiHandle, VlanIdStr);
     goto Exit;
   }
 
   //
   // Delete VLAN.
   //
-  Status = VlanConfig->Remove (VlanConfig, (UINT16) VlanId);
+  Status = VlanConfig->Remove (VlanConfig, (UINT16)VlanId);
   if (EFI_ERROR (Status)) {
     if (Status == EFI_NOT_FOUND) {
-      ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NOT_FOUND), mHiiHandle);
+      ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NOT_FOUND), mHiiHandle);
     } else {
-      ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_REMOVE_FAIL), mHiiHandle, Status);
+      ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_REMOVE_FAIL), mHiiHandle, Status);
     }
 
     goto Exit;
@@ -579,7 +576,7 @@ DeleteVlan (
     FreePool (VlanData);
   }
 
-  ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_REMOVE_SUCCESS), mHiiHandle);
+  ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_REMOVE_SUCCESS), mHiiHandle);
 
 Exit:
   if (VlanConfig != NULL) {
@@ -606,10 +603,10 @@ VlanConfigMain (
   IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
-  LIST_ENTRY    *List;
-  CONST CHAR16  *Str;
-  EFI_HII_PACKAGE_LIST_HEADER     *PackageList;
-  EFI_STATUS    Status;
+  LIST_ENTRY                   *List;
+  CONST CHAR16                 *Str;
+  EFI_HII_PACKAGE_LIST_HEADER  *PackageList;
+  EFI_STATUS                   Status;
 
   mImageHandle = ImageHandle;
 
@@ -619,7 +616,7 @@ VlanConfigMain (
   Status = gBS->OpenProtocol (
                   ImageHandle,
                   &gEfiHiiPackageListProtocolGuid,
-                  (VOID **) &PackageList,
+                  (VOID **)&PackageList,
                   ImageHandle,
                   NULL,
                   EFI_OPEN_PROTOCOL_GET_PROTOCOL
@@ -632,11 +629,11 @@ VlanConfigMain (
   // Publish HII package list to HII Database.
   //
   Status = gHiiDatabase->NewPackageList (
-                          gHiiDatabase,
-                          PackageList,
-                          NULL,
-                          &mHiiHandle
-                          );
+                           gHiiDatabase,
+                           PackageList,
+                           NULL,
+                           &mHiiHandle
+                           );
   if (EFI_ERROR (Status)) {
     return Status;
   }
@@ -648,32 +645,32 @@ VlanConfigMain (
   List = NULL;
   ShellCommandLineParseEx (mParamList, &List, NULL, FALSE, FALSE);
   if (List == NULL) {
-    ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_ARG), mHiiHandle);
+    ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_ARG), mHiiHandle);
     goto Exit;
   }
 
   if (ShellCommandLineGetFlag (List, L"-l")) {
     Str = ShellCommandLineGetValue (List, L"-l");
-    DisplayVlan ((CHAR16 *) Str);
+    DisplayVlan ((CHAR16 *)Str);
     goto Exit;
   }
 
   if (ShellCommandLineGetFlag (List, L"-a")) {
     Str = ShellCommandLineGetValue (List, L"-a");
-    AddVlan ((CHAR16 *) Str);
+    AddVlan ((CHAR16 *)Str);
     goto Exit;
   }
 
   if (ShellCommandLineGetFlag (List, L"-d")) {
     Str = ShellCommandLineGetValue (List, L"-d");
-    DeleteVlan ((CHAR16 *) Str);
+    DeleteVlan ((CHAR16 *)Str);
     goto Exit;
   }
 
   //
   // No valid argument till now.
   //
-  ShellPrintHiiEx (-1, -1, NULL, STRING_TOKEN (STR_VCONFIG_NO_ARG), mHiiHandle);
+  ShellPrintHiiDefaultEx (STRING_TOKEN (STR_VCONFIG_NO_ARG), mHiiHandle);
 
 Exit:
   if (List != NULL) {
