@@ -61,7 +61,7 @@ MapGcdMmioSpace (
     DEBUG ((
       DEBUG_ERROR,
       "%a: failed to add GCD memory space for region [0x%Lx+0x%Lx)\n",
-      __FUNCTION__,
+      __func__,
       Base,
       Size
       ));
@@ -73,7 +73,7 @@ MapGcdMmioSpace (
     DEBUG ((
       DEBUG_ERROR,
       "%a: failed to set memory space attributes for region [0x%Lx+0x%Lx)\n",
-      __FUNCTION__,
+      __func__,
       Base,
       Size
       ));
@@ -143,7 +143,7 @@ ProcessPciHost (
     DEBUG ((
       DEBUG_INFO,
       "%a: No 'pci-host-ecam-generic' compatible DT node found\n",
-      __FUNCTION__
+      __func__
       ));
     return EFI_NOT_FOUND;
   }
@@ -169,7 +169,7 @@ ProcessPciHost (
     DEBUG ((
       DEBUG_ERROR,
       "%a: 'reg' property not found or invalid\n",
-      __FUNCTION__
+      __func__
       ));
     return EFI_PROTOCOL_ERROR;
   }
@@ -194,7 +194,7 @@ ProcessPciHost (
     DEBUG ((
       DEBUG_ERROR,
       "%a: 'bus-range' not found or invalid\n",
-      __FUNCTION__
+      __func__
       ));
     return EFI_PROTOCOL_ERROR;
   }
@@ -212,7 +212,7 @@ ProcessPciHost (
     DEBUG ((
       DEBUG_ERROR,
       "%a: invalid 'bus-range' and/or 'reg'\n",
-      __FUNCTION__
+      __func__
       ));
     return EFI_PROTOCOL_ERROR;
   }
@@ -224,7 +224,7 @@ ProcessPciHost (
   if (EFI_ERROR (Status) || (Len == 0) ||
       (Len % sizeof (DTB_PCI_HOST_RANGE_RECORD) != 0))
   {
-    DEBUG ((DEBUG_ERROR, "%a: 'ranges' not found or invalid\n", __FUNCTION__));
+    DEBUG ((DEBUG_ERROR, "%a: 'ranges' not found or invalid\n", __func__));
     return EFI_PROTOCOL_ERROR;
   }
 
@@ -251,7 +251,7 @@ ProcessPciHost (
         if ((*Mmio32Base > MAX_UINT32) || (*Mmio32Size > MAX_UINT32) ||
             (*Mmio32Base + *Mmio32Size > SIZE_4GB))
         {
-          DEBUG ((DEBUG_ERROR, "%a: MMIO32 space invalid\n", __FUNCTION__));
+          DEBUG ((DEBUG_ERROR, "%a: MMIO32 space invalid\n", __func__));
           return EFI_PROTOCOL_ERROR;
         }
 
@@ -262,7 +262,7 @@ ProcessPciHost (
             DEBUG_ERROR,
             "%a: unsupported nonzero MMIO32 translation "
             "0x%Lx\n",
-            __FUNCTION__,
+            __func__,
             Mmio32Translation
             ));
           return EFI_UNSUPPORTED;
@@ -282,7 +282,7 @@ ProcessPciHost (
             DEBUG_ERROR,
             "%a: unsupported nonzero MMIO64 translation "
             "0x%Lx\n",
-            __FUNCTION__,
+            __func__,
             Mmio64Translation
             ));
           return EFI_UNSUPPORTED;
@@ -293,7 +293,7 @@ ProcessPciHost (
   }
 
   if (*Mmio32Size == 0) {
-    DEBUG ((DEBUG_ERROR, "%a: MMIO32 space empty\n", __FUNCTION__));
+    DEBUG ((DEBUG_ERROR, "%a: MMIO32 space empty\n", __func__));
     return EFI_PROTOCOL_ERROR;
   }
 
@@ -307,7 +307,7 @@ ProcessPciHost (
     DEBUG_INFO,
     "%a: Config[0x%Lx+0x%Lx) Bus[0x%x..0x%x] "
     "Io[0x%Lx+0x%Lx)@0x%Lx Mem32[0x%Lx+0x%Lx)@0x0 Mem64[0x%Lx+0x%Lx)@0x0\n",
-    __FUNCTION__,
+    __func__,
     ConfigBase,
     ConfigSize,
     *BusMin,
@@ -370,7 +370,7 @@ PciHostBridgeGetRootBridges (
   PCI_ROOT_BRIDGE_APERTURE  PMemAbove4G;
 
   if (PcdGet64 (PcdPciExpressBaseAddress) == 0) {
-    DEBUG ((DEBUG_INFO, "%a: PCI host bridge not present\n", __FUNCTION__));
+    DEBUG ((DEBUG_INFO, "%a: PCI host bridge not present\n", __func__));
 
     *Count = 0;
     return NULL;
@@ -390,7 +390,7 @@ PciHostBridgeGetRootBridges (
     DEBUG ((
       DEBUG_ERROR,
       "%a: failed to discover PCI host bridge: %r\n",
-      __FUNCTION__,
+      __func__,
       Status
       ));
     *Count = 0;
@@ -428,7 +428,7 @@ PciHostBridgeGetRootBridges (
   } else {
     //
     // UEFI mandates a 1:1 virtual-to-physical mapping, so on a 32-bit
-    // architecture such as ARM, we will not be able to access 64-bit MMIO
+    // architecture, we will not be able to access 64-bit MMIO
     // BARs unless they are allocated below 4 GB. So ignore the range above
     // 4 GB in this case.
     //
