@@ -4,13 +4,7 @@
   is responsible for early initialization of IDE controller.
 
   Copyright (c) 2008 - 2018, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -19,7 +13,7 @@
 ///
 ///  EFI_DRIVER_BINDING_PROTOCOL instance
 ///
-EFI_DRIVER_BINDING_PROTOCOL gIdeControllerDriverBinding = {
+EFI_DRIVER_BINDING_PROTOCOL  gIdeControllerDriverBinding = {
   IdeControllerSupported,
   IdeControllerStart,
   IdeControllerStop,
@@ -79,8 +73,8 @@ EFI_ATA_COLLECTIVE_MODE  gEfiAtaCollectiveModeTemplate = {
 EFI_STATUS
 EFIAPI
 InitializeIdeControllerDriver (
-  IN EFI_HANDLE       ImageHandle,
-  IN EFI_SYSTEM_TABLE *SystemTable
+  IN EFI_HANDLE        ImageHandle,
+  IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
   EFI_STATUS  Status;
@@ -115,15 +109,15 @@ InitializeIdeControllerDriver (
 EFI_STATUS
 EFIAPI
 IdeControllerSupported (
-  IN EFI_DRIVER_BINDING_PROTOCOL *This,
-  IN EFI_HANDLE                  Controller,
-  IN EFI_DEVICE_PATH_PROTOCOL    *RemainingDevicePath
+  IN EFI_DRIVER_BINDING_PROTOCOL  *This,
+  IN EFI_HANDLE                   Controller,
+  IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   )
 {
-  EFI_STATUS                Status;
-  EFI_PCI_IO_PROTOCOL       *PciIo;
-  UINT8                     PciClass;
-  UINT8                     PciSubClass;
+  EFI_STATUS           Status;
+  EFI_PCI_IO_PROTOCOL  *PciIo;
+  UINT8                PciClass;
+  UINT8                PciSubClass;
 
   //
   // Attempt to Open PCI I/O Protocol
@@ -131,7 +125,7 @@ IdeControllerSupported (
   Status = gBS->OpenProtocol (
                   Controller,
                   &gEfiPciIoProtocolGuid,
-                  (VOID **) &PciIo,
+                  (VOID **)&PciIo,
                   This->DriverBindingHandle,
                   Controller,
                   EFI_OPEN_PROTOCOL_BY_DRIVER
@@ -175,11 +169,11 @@ IdeControllerSupported (
 
 Done:
   gBS->CloseProtocol (
-        Controller,
-        &gEfiPciIoProtocolGuid,
-        This->DriverBindingHandle,
-        Controller
-        );
+         Controller,
+         &gEfiPciIoProtocolGuid,
+         This->DriverBindingHandle,
+         Controller
+         );
 
   return Status;
 }
@@ -200,9 +194,9 @@ Done:
 EFI_STATUS
 EFIAPI
 IdeControllerStart (
-  IN EFI_DRIVER_BINDING_PROTOCOL    *This,
-  IN EFI_HANDLE                     Controller,
-  IN EFI_DEVICE_PATH_PROTOCOL       *RemainingDevicePath
+  IN EFI_DRIVER_BINDING_PROTOCOL  *This,
+  IN EFI_HANDLE                   Controller,
+  IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   )
 {
   EFI_STATUS           Status;
@@ -214,7 +208,7 @@ IdeControllerStart (
   Status = gBS->OpenProtocol (
                   Controller,
                   &gEfiPciIoProtocolGuid,
-                  (VOID **) &PciIo,
+                  (VOID **)&PciIo,
                   This->DriverBindingHandle,
                   Controller,
                   EFI_OPEN_PROTOCOL_BY_DRIVER
@@ -236,7 +230,8 @@ IdeControllerStart (
   //
   return gBS->InstallMultipleProtocolInterfaces (
                 &Controller,
-                &gEfiIdeControllerInitProtocolGuid, &gEfiIdeControllerInit,
+                &gEfiIdeControllerInitProtocolGuid,
+                &gEfiIdeControllerInit,
                 NULL
                 );
 }
@@ -255,10 +250,10 @@ IdeControllerStart (
 EFI_STATUS
 EFIAPI
 IdeControllerStop (
-  IN  EFI_DRIVER_BINDING_PROTOCOL     *This,
-  IN  EFI_HANDLE                      Controller,
-  IN  UINTN                           NumberOfChildren,
-  IN  EFI_HANDLE                      *ChildHandleBuffer
+  IN  EFI_DRIVER_BINDING_PROTOCOL  *This,
+  IN  EFI_HANDLE                   Controller,
+  IN  UINTN                        NumberOfChildren,
+  IN  EFI_HANDLE                   *ChildHandleBuffer
   )
 {
   EFI_STATUS                        Status;
@@ -270,13 +265,13 @@ IdeControllerStop (
   Status = gBS->OpenProtocol (
                   Controller,
                   &gEfiIdeControllerInitProtocolGuid,
-                  (VOID **) &IdeControllerInit,
+                  (VOID **)&IdeControllerInit,
                   This->DriverBindingHandle,
                   Controller,
                   EFI_OPEN_PROTOCOL_GET_PROTOCOL
                   );
   if (EFI_ERROR (Status)) {
-     return EFI_UNSUPPORTED;
+    return EFI_UNSUPPORTED;
   }
 
   //
@@ -291,7 +286,8 @@ IdeControllerStop (
   //
   Status = gBS->UninstallMultipleProtocolInterfaces (
                   Controller,
-                  &gEfiIdeControllerInitProtocolGuid, &gEfiIdeControllerInit,
+                  &gEfiIdeControllerInitProtocolGuid,
+                  &gEfiIdeControllerInit,
                   NULL
                   );
   if (EFI_ERROR (Status)) {
@@ -312,6 +308,7 @@ IdeControllerStop (
 //
 // Interface functions of IDE_CONTROLLER_INIT protocol
 //
+
 /**
   Returns the information about the specified IDE channel.
 
@@ -351,10 +348,10 @@ IdeControllerStop (
 EFI_STATUS
 EFIAPI
 IdeInitGetChannelInfo (
-  IN   EFI_IDE_CONTROLLER_INIT_PROTOCOL *This,
-  IN   UINT8                            Channel,
-  OUT  BOOLEAN                          *Enabled,
-  OUT  UINT8                            *MaxDevices
+  IN   EFI_IDE_CONTROLLER_INIT_PROTOCOL  *This,
+  IN   UINT8                             Channel,
+  OUT  BOOLEAN                           *Enabled,
+  OUT  UINT8                             *MaxDevices
   )
 {
   //
@@ -397,9 +394,9 @@ IdeInitGetChannelInfo (
 EFI_STATUS
 EFIAPI
 IdeInitNotifyPhase (
-  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL   *This,
-  IN  EFI_IDE_CONTROLLER_ENUM_PHASE      Phase,
-  IN  UINT8                              Channel
+  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL  *This,
+  IN  EFI_IDE_CONTROLLER_ENUM_PHASE     Phase,
+  IN  UINT8                             Channel
   )
 {
   return EFI_SUCCESS;
@@ -447,10 +444,10 @@ IdeInitNotifyPhase (
 EFI_STATUS
 EFIAPI
 IdeInitSubmitData (
-  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL    *This,
-  IN  UINT8                               Channel,
-  IN  UINT8                               Device,
-  IN  EFI_IDENTIFY_DATA                   *IdentifyData
+  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL  *This,
+  IN  UINT8                             Channel,
+  IN  UINT8                             Device,
+  IN  EFI_IDENTIFY_DATA                 *IdentifyData
   )
 {
   return EFI_SUCCESS;
@@ -499,10 +496,10 @@ IdeInitSubmitData (
 EFI_STATUS
 EFIAPI
 IdeInitDisqualifyMode (
-  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL    *This,
-  IN  UINT8                               Channel,
-  IN  UINT8                               Device,
-  IN  EFI_ATA_COLLECTIVE_MODE             *BadModes
+  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL  *This,
+  IN  UINT8                             Channel,
+  IN  UINT8                             Device,
+  IN  EFI_ATA_COLLECTIVE_MODE           *BadModes
   )
 {
   return EFI_SUCCESS;
@@ -565,13 +562,13 @@ IdeInitDisqualifyMode (
 EFI_STATUS
 EFIAPI
 IdeInitCalculateMode (
-  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL       *This,
-  IN  UINT8                                  Channel,
-  IN  UINT8                                  Device,
-  OUT EFI_ATA_COLLECTIVE_MODE                **SupportedModes
+  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL  *This,
+  IN  UINT8                             Channel,
+  IN  UINT8                             Device,
+  OUT EFI_ATA_COLLECTIVE_MODE           **SupportedModes
   )
 {
-  if (Channel >= ICH_IDE_MAX_CHANNEL || Device >= ICH_IDE_MAX_DEVICES) {
+  if ((Channel >= ICH_IDE_MAX_CHANNEL) || (Device >= ICH_IDE_MAX_DEVICES)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -609,10 +606,10 @@ IdeInitCalculateMode (
 EFI_STATUS
 EFIAPI
 IdeInitSetTiming (
-  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL    *This,
-  IN  UINT8                               Channel,
-  IN  UINT8                               Device,
-  IN  EFI_ATA_COLLECTIVE_MODE             *Modes
+  IN  EFI_IDE_CONTROLLER_INIT_PROTOCOL  *This,
+  IN  UINT8                             Channel,
+  IN  UINT8                             Device,
+  IN  EFI_ATA_COLLECTIVE_MODE           *Modes
   )
 {
   return EFI_SUCCESS;
