@@ -3,6 +3,7 @@
   Common Platform Runtime Mechanism (PRM) definitions.
 
   Copyright (c) Microsoft Corporation
+  Copyright (c) 2022, Arm Limited. All rights reserved.<BR>
   SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
@@ -13,10 +14,15 @@
 #include <Uefi.h>
 #include <PrmContextBuffer.h>
 
-#if defined (_MSC_VER)
-#define PRM_EXPORT_API  __declspec(dllexport)
+#if defined (_MSC_EXTENSIONS)
+#define PRM_EXPORT_API         __declspec(dllexport)
+#define PRM_EXPORT_DESCRIPTOR  __declspec(dllexport)
+#elif defined (__GNUC__) || defined (__clang__)
+#define PRM_EXPORT_API
+#define PRM_EXPORT_DESCRIPTOR  __attribute__((used)) __attribute__((section(".prmexportdescriptor")))
 #else
 #define PRM_EXPORT_API
+#define PRM_EXPORT_DESCRIPTOR
 #endif
 
 #define PRM_HANDLER_NAME_MAXIMUM_LENGTH  128
