@@ -6,10 +6,14 @@
 
   Copyright (c) 2019, Intel Corporation. All rights reserved.<BR>
   (C) Copyright 2020 Hewlett Packard Enterprise Development LP<BR>
+  Copyright (C) 2022 Advanced Micro Devices, Inc. All rights reserved.<BR>
+  Copyright (c) 2023 - 2025, NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+  Copyright (c) 2023, Ampere Computing LLC. All rights reserved.<BR>
 
   SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
+#include <Base.h>
 #include <Uefi.h>
 #include <Library/BaseLib.h>
 #include <Library/BaseMemoryLib.h>
@@ -21,6 +25,9 @@
 #include <Library/UefiBootServicesTableLib.h>
 #include <Library/UefiRuntimeServicesTableLib.h>
 
+static EFI_EVENT  mPlatformHostInterfaceReadylEvent        = NULL;
+static VOID       *mPlatformHostInterfaceReadyRegistration = NULL;
+
 /**
   Create SMBIOS type 42 record for Redfish host interface.
 
@@ -47,18 +54,24 @@ RedfishCreateSmbiosTable42 (
   SMBIOS_TABLE_TYPE42                *Type42Record;
   EFI_SMBIOS_PROTOCOL                *Smbios;
   EFI_SMBIOS_HANDLE                  MemArrayMappedAddrSmbiosHandle;
+  EFI_HANDLE                         Handle;
+  CHAR8                              *SerialNumber;
+  UINTN                              SerialNumStrLen;
 
+  Handle          = NULL;
+  SerialNumStrLen = 0;
+  SerialNumber    = NULL;
   //
   // Get platform Redfish host interface device type descriptor data.
   //
   Status = RedfishPlatformHostInterfaceDeviceDescriptor (&DeviceType, &DeviceDescriptor);
   if (EFI_ERROR (Status)) {
     if (Status == EFI_NOT_FOUND) {
-      DEBUG ((DEBUG_ERROR, "%a: No Redfish host interface descriptor is provided on this platform.", __FUNCTION__));
+      DEBUG ((DEBUG_ERROR, "%a: No Redfish host interface descriptor is provided on this platform.\n", __func__));
       return EFI_NOT_FOUND;
     }
 
-    DEBUG ((DEBUG_ERROR, "%a: Fail to get device descriptor, %r.", __FUNCTION__, Status));
+    DEBUG ((DEBUG_ERROR, "%a: Fail to get device descriptor, %r.", __func__, Status));
     return Status;
   }
 
@@ -66,7 +79,7 @@ RedfishCreateSmbiosTable42 (
       (DeviceType != REDFISH_HOST_INTERFACE_DEVICE_TYPE_PCI_PCIE_V2)
       )
   {
-    DEBUG ((DEBUG_ERROR, "%a: Only support either protocol type 04h or 05h as Redfish host interface.", __FUNCTION__));
+    DEBUG ((DEBUG_ERROR, "%a: Only support either protocol type 04h or 05h as Redfish host interface.", __func__));
     return EFI_UNSUPPORTED;
   }
 
@@ -74,6 +87,16 @@ RedfishCreateSmbiosTable42 (
     DeviceDataLength = DeviceDescriptor->DeviceDescriptor.PciPcieDeviceV2.Length;
   } else {
     DeviceDataLength = DeviceDescriptor->DeviceDescriptor.UsbDeviceV2.Length;
+    Status           = RedfishPlatformHostInterfaceSerialNumber (&SerialNumber);
+    if (EFI_ERROR (Status)) {
+      DEBUG ((DEBUG_ERROR, "%a: Fail to get redfish host interface serial number, %r.", __func__, Status));
+      DeviceDescriptor->DeviceDescriptor.UsbDeviceV2.SerialNumberStr = 0;
+    } else {
+      if (SerialNumber != NULL) {
+        SerialNumStrLen                                                = (UINTN)AsciiStrLen (SerialNumber);
+        DeviceDescriptor->DeviceDescriptor.UsbDeviceV2.SerialNumberStr = 1;
+      }
+    }
   }
 
   //
@@ -93,7 +116,7 @@ RedfishCreateSmbiosTable42 (
     }
 
     if (EFI_ERROR (Status)) {
-      DEBUG ((DEBUG_ERROR, "%a: Fail to get Redfish host interafce protocol type data.", __FUNCTION__));
+      DEBUG ((DEBUG_ERROR, "%a: Fail to get Redfish host interafce protocol type data.", __func__));
       if (ProtocolRecords != NULL) {
         FreePool (ProtocolRecords);
       }
@@ -119,7 +142,7 @@ RedfishCreateSmbiosTable42 (
     } else {
       NewProtocolRecords = ReallocatePool (CurrentProtocolsDataLength, NewProtocolsDataLength, (VOID *)ProtocolRecords);
       if (NewProtocolRecords == NULL) {
-        DEBUG ((DEBUG_ERROR, "%a: Fail to allocate memory for Redfish host interface protocol data.", __FUNCTION__));
+        DEBUG ((DEBUG_ERROR, "%a: Fail to allocate memory for Redfish host interface protocol data.", __func__));
         FreePool (ProtocolRecords);
         FreePool (ProtocolRecord);
         return EFI_OUT_OF_RESOURCES;
@@ -159,6 +182,7 @@ RedfishCreateSmbiosTable42 (
                                           + DeviceDataLength
                                           + 1  /// For Protocol Record Count
                                           + CurrentProtocolsDataLength
+                                          + SerialNumStrLen
                                           + 2  /// Double NULL terminator/
                                           );
   if (Type42Record == NULL) {
@@ -200,6 +224,13 @@ RedfishCreateSmbiosTable42 (
     CurrentProtocolsDataLength
     );
 
+  //
+  // Fill in Serial Number string at the end of SMBIOS table 42
+  //
+  if (SerialNumStrLen) {
+    CopyMem (Type42Record->InterfaceTypeSpecificData + DeviceDataLength + 1 + CurrentProtocolsDataLength, SerialNumber, SerialNumStrLen);
+  }
+
   //
   // 5. Add Redfish interface data record to SMBIOS table 42
   //
@@ -215,11 +246,27 @@ RedfishCreateSmbiosTable42 (
                                              &MemArrayMappedAddrSmbiosHandle,
                                              (EFI_SMBIOS_TABLE_HEADER *)Type42Record
                                              );
-  DEBUG ((DEBUG_INFO, "RedfishPlatformDxe: Smbios->Add() - %r\n", Status));
+  DEBUG ((DEBUG_MANAGEABILITY, "RedfishPlatformDxe: Smbios->Add() - %r\n", Status));
   if (EFI_ERROR (Status)) {
     goto ON_EXIT;
   }
 
+  //
+  // Install Redfish Host Interface ready protocol.
+  //
+  Status = gBS->InstallProtocolInterface (
+                  &Handle,
+                  &gEdkIIRedfishHostInterfaceReadyProtocolGuid,
+                  EFI_NATIVE_INTERFACE,
+                  (VOID *)NULL
+                  );
+  if (EFI_ERROR (Status)) {
+    DEBUG ((DEBUG_ERROR, "Failed to install gEdkIIRedfishHostInterfaceReadyProtocolGuid.\n"));
+    DEBUG ((DEBUG_ERROR, "PlatformConfigHandler driver may not be triggered to acquire Redfish service.\n"));
+  }
+
+  // Set Status to EFI_SUCCESS that indicates SMBIOS 42 record was installed
+  // on the platform sucessfully.
   Status = EFI_SUCCESS;
 
 ON_EXIT:
@@ -235,9 +282,41 @@ ON_EXIT:
     FreePool (Type42Record);
   }
 
+  if (SerialNumber != NULL) {
+    FreePool (SerialNumber);
+  }
+
   return Status;
 }
 
+/**
+  Notification event of platform Redfish Host Interface readiness.
+
+  @param[in]  Event     Event whose notification function is being invoked.
+  @param[in]  Context   The pointer to the notification function's context,
+                        which is implementation-dependent.
+
+**/
+VOID
+EFIAPI
+PlatformHostInterfaceInformationReady (
+  IN  EFI_EVENT  Event,
+  IN  VOID       *Context
+  )
+{
+  DEBUG ((DEBUG_MANAGEABILITY, "%a: Platform Redfish Host Interface informtion is ready\n", __func__));
+
+  RedfishCreateSmbiosTable42 ();
+
+  //
+  // Close event so we don't create multiple type 42 records
+  //
+  gBS->CloseEvent (Event);
+  mPlatformHostInterfaceReadylEvent = NULL;
+
+  return;
+}
+
 /**
   Main entry for this driver.
 
@@ -254,8 +333,52 @@ RedfishHostInterfaceDxeEntryPoint (
   IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
+  EFI_STATUS  Status;
+  EFI_GUID    *ReadyGuid;
+
+  DEBUG ((DEBUG_MANAGEABILITY, "%a: Entry\n.", __func__));
+
   //
-  // Create SMBIOS type 42 record.
+  // Check if the Redfish Host Interface depends on
+  // the specific protocol installation.
   //
-  return RedfishCreateSmbiosTable42 ();
+  Status = RedfishPlatformHostInterfaceNotification (&ReadyGuid);
+  if (Status == EFI_SUCCESS) {
+    DEBUG ((DEBUG_MANAGEABILITY, "    Create protocol install notification to know the installation of platform Redfish host interface readiness\n"));
+    DEBUG ((DEBUG_MANAGEABILITY, "    Protocol GUID: %g\n", ReadyGuid));
+    //
+    // Register event for ReadyGuid protocol installed by
+    // platform Redfish host interface library.
+    //
+    Status = gBS->CreateEvent (
+                    EVT_NOTIFY_SIGNAL,
+                    TPL_CALLBACK,
+                    PlatformHostInterfaceInformationReady,
+                    NULL,
+                    &mPlatformHostInterfaceReadylEvent
+                    );
+    if (EFI_ERROR (Status)) {
+      DEBUG ((DEBUG_ERROR, "    Fail to create event for the installation of platform Redfish host interface readiness.\n"));
+      return Status;
+    }
+
+    Status = gBS->RegisterProtocolNotify (
+                    ReadyGuid,
+                    mPlatformHostInterfaceReadylEvent,
+                    &mPlatformHostInterfaceReadyRegistration
+                    );
+    if (EFI_ERROR (Status)) {
+      DEBUG ((DEBUG_ERROR, "    Fail to register event for the installation of platform Redfish host interface readiness.\n"));
+      return Status;
+    }
+
+    return EFI_SUCCESS;
+  }
+
+  if ((Status == EFI_UNSUPPORTED) || (Status == EFI_ALREADY_STARTED)) {
+    Status = RedfishCreateSmbiosTable42 ();
+  }
+
+  // Return other erros.
+  return Status;
 }
