@@ -14,17 +14,17 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #include <Library/DebugLib.h>
 
 typedef struct {
-  TPMI_ALG_HASH              HashAlgo;
-  UINT16                     HashSize;
-  UINT32                     HashMask;
+  TPMI_ALG_HASH    HashAlgo;
+  UINT16           HashSize;
+  UINT32           HashMask;
 } INTERNAL_HASH_INFO;
 
-STATIC INTERNAL_HASH_INFO mHashInfo[] = {
-  {TPM_ALG_SHA1,          SHA1_DIGEST_SIZE,     HASH_ALG_SHA1},
-  {TPM_ALG_SHA256,        SHA256_DIGEST_SIZE,   HASH_ALG_SHA256},
-  {TPM_ALG_SM3_256,       SM3_256_DIGEST_SIZE,  HASH_ALG_SM3_256},
-  {TPM_ALG_SHA384,        SHA384_DIGEST_SIZE,   HASH_ALG_SHA384},
-  {TPM_ALG_SHA512,        SHA512_DIGEST_SIZE,   HASH_ALG_SHA512},
+STATIC INTERNAL_HASH_INFO  mHashInfo[] = {
+  { TPM_ALG_SHA1,    SHA1_DIGEST_SIZE,    HASH_ALG_SHA1    },
+  { TPM_ALG_SHA256,  SHA256_DIGEST_SIZE,  HASH_ALG_SHA256  },
+  { TPM_ALG_SM3_256, SM3_256_DIGEST_SIZE, HASH_ALG_SM3_256 },
+  { TPM_ALG_SHA384,  SHA384_DIGEST_SIZE,  HASH_ALG_SHA384  },
+  { TPM_ALG_SHA512,  SHA512_DIGEST_SIZE,  HASH_ALG_SHA512  },
 };
 
 /**
@@ -37,16 +37,17 @@ STATIC INTERNAL_HASH_INFO mHashInfo[] = {
 UINT16
 EFIAPI
 GetHashSizeFromAlgo (
-  IN TPMI_ALG_HASH    HashAlgo
+  IN TPMI_ALG_HASH  HashAlgo
   )
 {
   UINTN  Index;
 
-  for (Index = 0; Index < sizeof(mHashInfo)/sizeof(mHashInfo[0]); Index++) {
+  for (Index = 0; Index < sizeof (mHashInfo)/sizeof (mHashInfo[0]); Index++) {
     if (mHashInfo[Index].HashAlgo == HashAlgo) {
       return mHashInfo[Index].HashSize;
     }
   }
+
   return 0;
 }
 
@@ -60,16 +61,17 @@ GetHashSizeFromAlgo (
 UINT32
 EFIAPI
 GetHashMaskFromAlgo (
-  IN TPMI_ALG_HASH     HashAlgo
+  IN TPMI_ALG_HASH  HashAlgo
   )
 {
   UINTN  Index;
 
-  for (Index = 0; Index < sizeof(mHashInfo)/sizeof(mHashInfo[0]); Index++) {
+  for (Index = 0; Index < sizeof (mHashInfo)/sizeof (mHashInfo[0]); Index++) {
     if (mHashInfo[Index].HashAlgo == HashAlgo) {
       return mHashInfo[Index].HashMask;
     }
   }
+
   return 0;
 }
 
@@ -84,8 +86,8 @@ GetHashMaskFromAlgo (
 UINT32
 EFIAPI
 CopyAuthSessionCommand (
-  IN      TPMS_AUTH_COMMAND         *AuthSessionIn, OPTIONAL
-  OUT     UINT8                     *AuthSessionOut
+  IN      TPMS_AUTH_COMMAND  *AuthSessionIn  OPTIONAL,
+  OUT     UINT8              *AuthSessionOut
   )
 {
   UINT8  *Buffer;
@@ -97,12 +99,12 @@ CopyAuthSessionCommand (
   //
   if (AuthSessionIn != NULL) {
     //  sessionHandle
-    WriteUnaligned32 ((UINT32 *)Buffer, SwapBytes32(AuthSessionIn->sessionHandle));
-    Buffer += sizeof(UINT32);
+    WriteUnaligned32 ((UINT32 *)Buffer, SwapBytes32 (AuthSessionIn->sessionHandle));
+    Buffer += sizeof (UINT32);
 
     // nonce
     WriteUnaligned16 ((UINT16 *)Buffer, SwapBytes16 (AuthSessionIn->nonce.size));
-    Buffer += sizeof(UINT16);
+    Buffer += sizeof (UINT16);
 
     CopyMem (Buffer, AuthSessionIn->nonce.buffer, AuthSessionIn->nonce.size);
     Buffer += AuthSessionIn->nonce.size;
@@ -113,26 +115,26 @@ CopyAuthSessionCommand (
 
     // hmac
     WriteUnaligned16 ((UINT16 *)Buffer, SwapBytes16 (AuthSessionIn->hmac.size));
-    Buffer += sizeof(UINT16);
+    Buffer += sizeof (UINT16);
 
     CopyMem (Buffer, AuthSessionIn->hmac.buffer, AuthSessionIn->hmac.size);
     Buffer += AuthSessionIn->hmac.size;
   } else {
     //  sessionHandle
-    WriteUnaligned32 ((UINT32 *)Buffer, SwapBytes32(TPM_RS_PW));
-    Buffer += sizeof(UINT32);
+    WriteUnaligned32 ((UINT32 *)Buffer, SwapBytes32 (TPM_RS_PW));
+    Buffer += sizeof (UINT32);
 
     // nonce = nullNonce
-    WriteUnaligned16 ((UINT16 *)Buffer, SwapBytes16(0));
-    Buffer += sizeof(UINT16);
+    WriteUnaligned16 ((UINT16 *)Buffer, SwapBytes16 (0));
+    Buffer += sizeof (UINT16);
 
     // sessionAttributes = 0
     *(UINT8 *)Buffer = 0x00;
     Buffer++;
 
     // hmac = nullAuth
-    WriteUnaligned16 ((UINT16 *)Buffer, SwapBytes16(0));
-    Buffer += sizeof(UINT16);
+    WriteUnaligned16 ((UINT16 *)Buffer, SwapBytes16 (0));
+    Buffer += sizeof (UINT16);
   }
 
   return (UINT32)((UINTN)Buffer - (UINTN)AuthSessionOut);
@@ -150,12 +152,12 @@ CopyAuthSessionCommand (
 UINT32
 EFIAPI
 CopyAuthSessionResponse (
-  IN      UINT8                      *AuthSessionIn,
-  OUT     TPMS_AUTH_RESPONSE         *AuthSessionOut OPTIONAL
+  IN      UINT8               *AuthSessionIn,
+  OUT     TPMS_AUTH_RESPONSE  *AuthSessionOut OPTIONAL
   )
 {
-  UINT8                      *Buffer;
-  TPMS_AUTH_RESPONSE         LocalAuthSessionOut;
+  UINT8               *Buffer;
+  TPMS_AUTH_RESPONSE  LocalAuthSessionOut;
 
   if (AuthSessionOut == NULL) {
     AuthSessionOut = &LocalAuthSessionOut;
@@ -165,8 +167,8 @@ CopyAuthSessionResponse (
 
   // nonce
   AuthSessionOut->nonce.size = SwapBytes16 (ReadUnaligned16 ((UINT16 *)Buffer));
-  Buffer += sizeof(UINT16);
-  if (AuthSessionOut->nonce.size > sizeof(TPMU_HA)) {
+  Buffer                    += sizeof (UINT16);
+  if (AuthSessionOut->nonce.size > sizeof (TPMU_HA)) {
     DEBUG ((DEBUG_ERROR, "CopyAuthSessionResponse - nonce.size error %x\n", AuthSessionOut->nonce.size));
     return 0;
   }
@@ -175,13 +177,13 @@ CopyAuthSessionResponse (
   Buffer += AuthSessionOut->nonce.size;
 
   // sessionAttributes
-  *(UINT8 *)&AuthSessionOut->sessionAttributes = *(UINT8 *)Buffer;
+  *(UINT8 *) &AuthSessionOut->sessionAttributes = *(UINT8 *)Buffer;
   Buffer++;
 
   // hmac
   AuthSessionOut->hmac.size = SwapBytes16 (ReadUnaligned16 ((UINT16 *)Buffer));
-  Buffer += sizeof(UINT16);
-  if (AuthSessionOut->hmac.size > sizeof(TPMU_HA)) {
+  Buffer                   += sizeof (UINT16);
+  if (AuthSessionOut->hmac.size > sizeof (TPMU_HA)) {
     DEBUG ((DEBUG_ERROR, "CopyAuthSessionResponse - hmac.size error %x\n", AuthSessionOut->hmac.size));
     return 0;
   }
@@ -203,37 +205,42 @@ CopyAuthSessionResponse (
 **/
 BOOLEAN
 EFIAPI
-IsHashAlgSupportedInHashAlgorithmMask(
+IsHashAlgSupportedInHashAlgorithmMask (
   IN TPMI_ALG_HASH  HashAlg,
   IN UINT32         HashAlgorithmMask
   )
 {
   switch (HashAlg) {
-  case TPM_ALG_SHA1:
-    if ((HashAlgorithmMask & HASH_ALG_SHA1) != 0) {
-      return TRUE;
-    }
-    break;
-  case TPM_ALG_SHA256:
-    if ((HashAlgorithmMask & HASH_ALG_SHA256) != 0) {
-      return TRUE;
-    }
-    break;
-  case TPM_ALG_SHA384:
-    if ((HashAlgorithmMask & HASH_ALG_SHA384) != 0) {
-      return TRUE;
-    }
-    break;
-  case TPM_ALG_SHA512:
-    if ((HashAlgorithmMask & HASH_ALG_SHA512) != 0) {
-      return TRUE;
-    }
-    break;
-  case TPM_ALG_SM3_256:
-    if ((HashAlgorithmMask & HASH_ALG_SM3_256) != 0) {
-      return TRUE;
-    }
-    break;
+    case TPM_ALG_SHA1:
+      if ((HashAlgorithmMask & HASH_ALG_SHA1) != 0) {
+        return TRUE;
+      }
+
+      break;
+    case TPM_ALG_SHA256:
+      if ((HashAlgorithmMask & HASH_ALG_SHA256) != 0) {
+        return TRUE;
+      }
+
+      break;
+    case TPM_ALG_SHA384:
+      if ((HashAlgorithmMask & HASH_ALG_SHA384) != 0) {
+        return TRUE;
+      }
+
+      break;
+    case TPM_ALG_SHA512:
+      if ((HashAlgorithmMask & HASH_ALG_SHA512) != 0) {
+        return TRUE;
+      }
+
+      break;
+    case TPM_ALG_SM3_256:
+      if ((HashAlgorithmMask & HASH_ALG_SM3_256) != 0) {
+        return TRUE;
+      }
+
+      break;
   }
 
   return FALSE;
@@ -251,36 +258,99 @@ IsHashAlgSupportedInHashAlgorithmMask(
 VOID *
 EFIAPI
 CopyDigestListToBuffer (
-  IN OUT VOID                       *Buffer,
-  IN TPML_DIGEST_VALUES             *DigestList,
-  IN UINT32                         HashAlgorithmMask
+  IN OUT VOID            *Buffer,
+  IN TPML_DIGEST_VALUES  *DigestList,
+  IN UINT32              HashAlgorithmMask
   )
 {
-  UINTN  Index;
-  UINT16 DigestSize;
-  UINT32 DigestListCount;
-  UINT32 *DigestListCountPtr;
+  UINTN   Index;
+  UINT16  DigestSize;
+  UINT32  DigestListCount;
+  UINT32  *DigestListCountPtr;
 
-  DigestListCountPtr = (UINT32 *) Buffer;
-  DigestListCount = 0;
-  Buffer = (UINT8 *)Buffer + sizeof(DigestList->count);
+  DigestListCountPtr = (UINT32 *)Buffer;
+  DigestListCount    = 0;
+  Buffer             = (UINT8 *)Buffer + sizeof (DigestList->count);
   for (Index = 0; Index < DigestList->count; Index++) {
-    if (!IsHashAlgSupportedInHashAlgorithmMask(DigestList->digests[Index].hashAlg, HashAlgorithmMask)) {
-      DEBUG ((EFI_D_ERROR, "WARNING: TPM2 Event log has HashAlg unsupported by PCR bank (0x%x)\n", DigestList->digests[Index].hashAlg));
+    if (!IsHashAlgSupportedInHashAlgorithmMask (DigestList->digests[Index].hashAlg, HashAlgorithmMask)) {
+      DEBUG ((DEBUG_ERROR, "WARNING: TPM2 Event log has HashAlg unsupported by PCR bank (0x%x)\n", DigestList->digests[Index].hashAlg));
       continue;
     }
-    CopyMem (Buffer, &DigestList->digests[Index].hashAlg, sizeof(DigestList->digests[Index].hashAlg));
-    Buffer = (UINT8 *)Buffer + sizeof(DigestList->digests[Index].hashAlg);
+
+    CopyMem (Buffer, &DigestList->digests[Index].hashAlg, sizeof (DigestList->digests[Index].hashAlg));
+    Buffer     = (UINT8 *)Buffer + sizeof (DigestList->digests[Index].hashAlg);
     DigestSize = GetHashSizeFromAlgo (DigestList->digests[Index].hashAlg);
     CopyMem (Buffer, &DigestList->digests[Index].digest, DigestSize);
     Buffer = (UINT8 *)Buffer + DigestSize;
     DigestListCount++;
   }
+
   WriteUnaligned32 (DigestListCountPtr, DigestListCount);
 
   return Buffer;
 }
 
+/**
+  Copy a buffer into a TPML_DIGEST_VALUES structure.
+
+  @param[in]     Buffer             Buffer to hold TPML_DIGEST_VALUES compact binary.
+  @param[in]     BufferSize         Size of Buffer.
+  @param[out]    DigestList         TPML_DIGEST_VALUES.
+
+  @retval EFI_SUCCESS               Buffer was succesfully copied to DigestList.
+  @retval EFI_BAD_BUFFER_SIZE       A bad buffer size passed to the function.
+  @retval EFI_INVALID_PARAMETER     An invalid parameter passed to the function: NULL pointer or
+                                    BufferSize bigger than TPML_DIGEST_VALUES.
+**/
+EFI_STATUS
+EFIAPI
+CopyBufferToDigestList (
+  IN CONST  VOID                *Buffer,
+  IN        UINTN               BufferSize,
+  OUT       TPML_DIGEST_VALUES  *DigestList
+  )
+{
+  EFI_STATUS   Status;
+  UINTN        Index;
+  UINT16       DigestSize;
+  CONST UINT8  *BufferPtr;
+
+  Status = EFI_INVALID_PARAMETER;
+
+  if ((Buffer == NULL) || (DigestList == NULL) || (BufferSize > sizeof (TPML_DIGEST_VALUES))) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  DigestList->count = SwapBytes32 (ReadUnaligned32 ((CONST UINT32 *)Buffer));
+  if (DigestList->count > HASH_COUNT) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  BufferPtr = (CONST UINT8 *)Buffer +  sizeof (UINT32);
+  for (Index = 0; Index < DigestList->count; Index++) {
+    if (BufferPtr - (CONST UINT8 *)Buffer + sizeof (UINT16) > BufferSize) {
+      Status = EFI_BAD_BUFFER_SIZE;
+      break;
+    } else {
+      DigestList->digests[Index].hashAlg = SwapBytes16 (ReadUnaligned16 ((CONST UINT16 *)BufferPtr));
+    }
+
+    BufferPtr += sizeof (UINT16);
+    DigestSize = GetHashSizeFromAlgo (DigestList->digests[Index].hashAlg);
+    if (BufferPtr - (CONST UINT8 *)Buffer + (UINTN)DigestSize > BufferSize) {
+      Status = EFI_BAD_BUFFER_SIZE;
+      break;
+    } else {
+      CopyMem (&DigestList->digests[Index].digest, BufferPtr, DigestSize);
+    }
+
+    BufferPtr += DigestSize;
+    Status     = EFI_SUCCESS;
+  }
+
+  return Status;
+}
+
 /**
   Get TPML_DIGEST_VALUES data size.
 
@@ -291,17 +361,43 @@ CopyDigestListToBuffer (
 UINT32
 EFIAPI
 GetDigestListSize (
-  IN TPML_DIGEST_VALUES             *DigestList
+  IN TPML_DIGEST_VALUES  *DigestList
   )
 {
-  UINTN  Index;
-  UINT16 DigestSize;
-  UINT32 TotalSize;
+  UINTN   Index;
+  UINT16  DigestSize;
+  UINT32  TotalSize;
 
-  TotalSize = sizeof(DigestList->count);
+  TotalSize = sizeof (DigestList->count);
   for (Index = 0; Index < DigestList->count; Index++) {
     DigestSize = GetHashSizeFromAlgo (DigestList->digests[Index].hashAlg);
-    TotalSize += sizeof(DigestList->digests[Index].hashAlg) + DigestSize;
+    TotalSize += sizeof (DigestList->digests[Index].hashAlg) + DigestSize;
+  }
+
+  return TotalSize;
+}
+
+/**
+  Get the total digest size from a hash algorithm mask.
+
+  @param[in]     HashAlgorithmMask.
+
+  @return Digest size in bytes.
+**/
+UINT32
+EFIAPI
+GetDigestListSizeFromHashAlgorithmMask (
+  IN UINT32  HashAlgorithmMask
+  )
+{
+  UINTN   Index;
+  UINT32  TotalSize;
+
+  TotalSize = sizeof (UINT32);
+  for (Index = 0; Index < ARRAY_SIZE (mHashInfo); Index++) {
+    if ((mHashInfo[Index].HashMask & HashAlgorithmMask) != 0) {
+      TotalSize += sizeof (TPMI_ALG_HASH) + mHashInfo[Index].HashSize;
+    }
   }
 
   return TotalSize;
@@ -320,13 +416,13 @@ GetDigestListSize (
 EFI_STATUS
 EFIAPI
 GetDigestFromDigestList (
-  IN TPMI_ALG_HASH      HashAlg,
-  IN TPML_DIGEST_VALUES *DigestList,
-  OUT VOID              *Digest
+  IN TPMI_ALG_HASH       HashAlg,
+  IN TPML_DIGEST_VALUES  *DigestList,
+  OUT VOID               *Digest
   )
 {
-  UINTN  Index;
-  UINT16 DigestSize;
+  UINTN   Index;
+  UINT16  DigestSize;
 
   DigestSize = GetHashSizeFromAlgo (HashAlg);
   for (Index = 0; Index < DigestList->count; Index++) {
