@@ -5,27 +5,21 @@
   Copyright (c) 2015 - 2018, Intel Corporation. All rights reserved. <BR>
   (C) Copyright 2015 Hewlett Packard Enterprise Development LP<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 **/
 
 #include "Tftp.h"
 
-#define IP4_CONFIG2_INTERFACE_INFO_NAME_LENGTH 32
-EFI_HANDLE   mTftpHiiHandle;
+#define IP4_CONFIG2_INTERFACE_INFO_NAME_LENGTH  32
+EFI_HII_HANDLE  mTftpHiiHandle;
 
 /*
    Constant strings and definitions related to the message indicating the amount of
-   progress in the dowloading of a TFTP file.
+   progress in the downloading of a TFTP file.
 */
 
 // Frame for the progression slider
-STATIC CONST CHAR16 mTftpProgressFrame[] = L"[                                        ]";
+STATIC CONST CHAR16  mTftpProgressFrame[] = L"[                                        ]";
 
 // Number of steps in the progression slider
 #define TFTP_PROGRESS_SLIDER_STEPS  ((sizeof (mTftpProgressFrame) / sizeof (CHAR16)) - 3)
@@ -39,7 +33,13 @@ STATIC CONST CHAR16 mTftpProgressFrame[] = L"[
 
 // String to delete the TFTP progress message to be able to update it :
 // (TFTP_PROGRESS_MESSAGE_SIZE-1) '\b'
-STATIC CONST CHAR16 mTftpProgressDelete[] = L"\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b";
+STATIC CONST CHAR16  mTftpProgressDelete[] = L"\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b";
+
+// Local File Handle
+SHELL_FILE_HANDLE  mFileHandle;
+
+// Path of the local file, Unicode encoded
+CONST CHAR16  *mLocalFilePath;
 
 /**
   Check and convert the UINT16 option values of the 'tftp' command
@@ -48,7 +48,7 @@ STATIC CONST CHAR16 mTftpProgressDelete[] = L"\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b\b
   @param[out] Value     UINT16 value
 
   @return     TRUE      The value was returned.
-  @return     FALSE     A parsing error occured.
+  @return     FALSE     A parsing error occurred.
 **/
 STATIC
 BOOLEAN
@@ -166,9 +166,6 @@ GetFileSize (
   @param[in]   FileSize       Size of the file in number of bytes
   @param[in]   BlockSize      Value of the TFTP blksize option
   @param[in]   WindowSize     Value of the TFTP window size option
-  @param[out]  Data           Address where to store the address of the buffer
-                              where the data of the file were downloaded in
-                              case of success.
 
   @retval  EFI_SUCCESS           The file was downloaded.
   @retval  EFI_OUT_OF_RESOURCES  A memory allocation failed.
@@ -184,8 +181,7 @@ DownloadFile (
   IN   CONST CHAR8          *AsciiFilePath,
   IN   UINTN                FileSize,
   IN   UINT16               BlockSize,
-  IN   UINT16               WindowSize,
-  OUT  VOID                 **Data
+  IN   UINT16               WindowSize
   );
 
 /**
@@ -210,49 +206,57 @@ CheckPacket (
   IN EFI_MTFTP4_PACKET    *Packet
   );
 
-EFI_MTFTP4_CONFIG_DATA DefaultMtftp4ConfigData = {
+EFI_MTFTP4_CONFIG_DATA  DefaultMtftp4ConfigData = {
   TRUE,                             // Use default setting
-  { { 0, 0, 0, 0 } },               // StationIp         - Not relevant as UseDefaultSetting=TRUE
-  { { 0, 0, 0, 0 } },               // SubnetMask        - Not relevant as UseDefaultSetting=TRUE
+  {
+    { 0, 0, 0, 0 }
+  },                                // StationIp         - Not relevant as UseDefaultSetting=TRUE
+  {
+    { 0, 0, 0, 0 }
+  },                                // SubnetMask        - Not relevant as UseDefaultSetting=TRUE
   0,                                // LocalPort         - Automatically assigned port number.
-  { { 0, 0, 0, 0 } },               // GatewayIp         - Not relevant as UseDefaultSetting=TRUE
-  { { 0, 0, 0, 0 } },               // ServerIp          - Not known yet
+  {
+    { 0, 0, 0, 0 }
+  },                                // GatewayIp         - Not relevant as UseDefaultSetting=TRUE
+  {
+    { 0, 0, 0, 0 }
+  },                                // ServerIp          - Not known yet
   69,                               // InitialServerPort - Standard TFTP server port
   6,                                // TryCount          - The number of times to transmit request packets and wait for a response.
   4                                 // TimeoutValue      - Retransmission timeout in seconds.
 };
 
-STATIC CONST SHELL_PARAM_ITEM ParamList[] = {
-  {L"-i", TypeValue},
-  {L"-l", TypeValue},
-  {L"-r", TypeValue},
-  {L"-c", TypeValue},
-  {L"-t", TypeValue},
-  {L"-s", TypeValue},
-  {L"-w", TypeValue},
-  {NULL , TypeMax}
-  };
+STATIC CONST SHELL_PARAM_ITEM  ParamList[] = {
+  { L"-i", TypeValue },
+  { L"-l", TypeValue },
+  { L"-r", TypeValue },
+  { L"-c", TypeValue },
+  { L"-t", TypeValue },
+  { L"-s", TypeValue },
+  { L"-w", TypeValue },
+  { NULL,  TypeMax   }
+};
 
 ///
 /// The default block size (512) of tftp is defined in the RFC1350.
 ///
-#define MTFTP_DEFAULT_BLKSIZE      512
+#define MTFTP_DEFAULT_BLKSIZE  512
 ///
 /// The valid range of block size option is defined in the RFC2348.
 ///
-#define MTFTP_MIN_BLKSIZE          8
-#define MTFTP_MAX_BLKSIZE          65464
+#define MTFTP_MIN_BLKSIZE  8
+#define MTFTP_MAX_BLKSIZE  65464
 ///
 /// The default windowsize (1) of tftp.
 ///
-#define MTFTP_DEFAULT_WINDOWSIZE   1
+#define MTFTP_DEFAULT_WINDOWSIZE  1
 ///
 /// The valid range of window size option.
 /// Note that: RFC 7440 does not mention max window size value, but for the
 /// stability reason, the value is limited to 64.
 ///
-#define MTFTP_MIN_WINDOWSIZE       1
-#define MTFTP_MAX_WINDOWSIZE       64
+#define MTFTP_MIN_WINDOWSIZE  1
+#define MTFTP_MAX_WINDOWSIZE  64
 
 /**
   Function for 'tftp' command.
@@ -287,7 +291,6 @@ RunTftp (
   CHAR8                   *AsciiRemoteFilePath;
   UINTN                   FilePathSize;
   CONST CHAR16            *Walker;
-  CONST CHAR16            *LocalFilePath;
   EFI_MTFTP4_CONFIG_DATA  Mtftp4ConfigData;
   EFI_HANDLE              *Handles;
   UINTN                   HandleCount;
@@ -297,9 +300,6 @@ RunTftp (
   EFI_HANDLE              Mtftp4ChildHandle;
   EFI_MTFTP4_PROTOCOL     *Mtftp4;
   UINTN                   FileSize;
-  UINTN                   DataSize;
-  VOID                    *Data;
-  SHELL_FILE_HANDLE       FileHandle;
   UINT16                  BlockSize;
   UINT16                  WindowSize;
 
@@ -309,7 +309,6 @@ RunTftp (
   AsciiRemoteFilePath = NULL;
   Handles             = NULL;
   FileSize            = 0;
-  DataSize            = 0;
   BlockSize           = MTFTP_DEFAULT_BLKSIZE;
   WindowSize          = MTFTP_DEFAULT_WINDOWSIZE;
 
@@ -328,15 +327,19 @@ RunTftp (
   Status = ShellCommandLineParse (ParamList, &CheckPackage, &ProblemParam, TRUE);
   if (EFI_ERROR (Status)) {
     if ((Status == EFI_VOLUME_CORRUPTED) &&
-        (ProblemParam != NULL) ) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_GEN_PROBLEM), mTftpHiiHandle,
-        L"tftp", ProblemParam
+        (ProblemParam != NULL))
+    {
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_GEN_PROBLEM),
+        mTftpHiiHandle,
+        L"tftp",
+        ProblemParam
         );
       FreePool (ProblemParam);
     } else {
       ASSERT (FALSE);
     }
+
     goto Error;
   }
 
@@ -345,16 +348,19 @@ RunTftp (
   //
   ParamCount = ShellCommandLineGetCount (CheckPackage);
   if (ParamCount > 4) {
-    ShellPrintHiiEx (
-      -1, -1, NULL, STRING_TOKEN (STR_GEN_TOO_MANY),
-      mTftpHiiHandle, L"tftp"
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_GEN_TOO_MANY),
+      mTftpHiiHandle,
+      L"tftp"
       );
     goto Error;
   }
+
   if (ParamCount < 3) {
-    ShellPrintHiiEx (
-      -1, -1, NULL, STRING_TOKEN (STR_GEN_TOO_FEW),
-      mTftpHiiHandle, L"tftp"
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_GEN_TOO_FEW),
+      mTftpHiiHandle,
+      L"tftp"
       );
     goto Error;
   }
@@ -365,36 +371,45 @@ RunTftp (
   // Check the host IPv4 address
   //
   ValueStr = ShellCommandLineGetRawValue (CheckPackage, 1);
-  Status = NetLibStrToIp4 (ValueStr, &Mtftp4ConfigData.ServerIp);
+  Status   = NetLibStrToIp4 (ValueStr, &Mtftp4ConfigData.ServerIp);
   if (EFI_ERROR (Status)) {
-    ShellPrintHiiEx (
-      -1, -1, NULL, STRING_TOKEN (STR_GEN_PARAM_INV),
-      mTftpHiiHandle, L"tftp", ValueStr
-    );
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_GEN_PARAM_INV),
+      mTftpHiiHandle,
+      L"tftp",
+      ValueStr
+      );
     goto Error;
   }
 
   RemoteFilePath = ShellCommandLineGetRawValue (CheckPackage, 2);
-  ASSERT(RemoteFilePath != NULL);
-  FilePathSize = StrLen (RemoteFilePath) + 1;
+  if (RemoteFilePath == NULL) {
+    ASSERT (RemoteFilePath != NULL);
+    goto Error;
+  }
+
+  FilePathSize        = StrLen (RemoteFilePath) + 1;
   AsciiRemoteFilePath = AllocatePool (FilePathSize);
   if (AsciiRemoteFilePath == NULL) {
     ShellStatus = SHELL_OUT_OF_RESOURCES;
     goto Error;
   }
+
   UnicodeStrToAsciiStrS (RemoteFilePath, AsciiRemoteFilePath, FilePathSize);
 
   if (ParamCount == 4) {
-    LocalFilePath = ShellCommandLineGetRawValue (CheckPackage, 3);
+    mLocalFilePath = ShellCommandLineGetRawValue (CheckPackage, 3);
   } else {
     Walker = RemoteFilePath + StrLen (RemoteFilePath);
     while ((--Walker) >= RemoteFilePath) {
       if ((*Walker == L'\\') ||
-          (*Walker == L'/' )    ) {
+          (*Walker == L'/'))
+      {
         break;
       }
     }
-    LocalFilePath = Walker + 1;
+
+    mLocalFilePath = Walker + 1;
   }
 
   //
@@ -432,11 +447,14 @@ RunTftp (
     if (!StringToUint16 (ValueStr, &Mtftp4ConfigData.TimeoutValue)) {
       goto Error;
     }
+
     if (Mtftp4ConfigData.TimeoutValue == 0) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_GEN_PARAM_INV),
-        mTftpHiiHandle, L"tftp", ValueStr
-      );
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_GEN_PARAM_INV),
+        mTftpHiiHandle,
+        L"tftp",
+        ValueStr
+        );
       goto Error;
     }
   }
@@ -446,11 +464,14 @@ RunTftp (
     if (!StringToUint16 (ValueStr, &BlockSize)) {
       goto Error;
     }
-    if (BlockSize < MTFTP_MIN_BLKSIZE || BlockSize > MTFTP_MAX_BLKSIZE) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_GEN_PARAM_INV),
-        mTftpHiiHandle, L"tftp", ValueStr
-      );
+
+    if ((BlockSize < MTFTP_MIN_BLKSIZE) || (BlockSize > MTFTP_MAX_BLKSIZE)) {
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_GEN_PARAM_INV),
+        mTftpHiiHandle,
+        L"tftp",
+        ValueStr
+        );
       goto Error;
     }
   }
@@ -460,11 +481,14 @@ RunTftp (
     if (!StringToUint16 (ValueStr, &WindowSize)) {
       goto Error;
     }
-    if (WindowSize < MTFTP_MIN_WINDOWSIZE || WindowSize > MTFTP_MAX_WINDOWSIZE) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_GEN_PARAM_INV),
-        mTftpHiiHandle, L"tftp", ValueStr
-      );
+
+    if ((WindowSize < MTFTP_MIN_WINDOWSIZE) || (WindowSize > MTFTP_MAX_WINDOWSIZE)) {
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_GEN_PARAM_INV),
+        mTftpHiiHandle,
+        L"tftp",
+        ValueStr
+        );
       goto Error;
     }
   }
@@ -473,33 +497,35 @@ RunTftp (
   // Locate all MTFTP4 Service Binding protocols
   //
   ShellStatus = SHELL_NOT_FOUND;
-  Status = gBS->LocateHandleBuffer (
-                 ByProtocol,
-                 &gEfiManagedNetworkServiceBindingProtocolGuid,
-                 NULL,
-                 &HandleCount,
-                 &Handles
-                 );
+  Status      = gBS->LocateHandleBuffer (
+                       ByProtocol,
+                       &gEfiManagedNetworkServiceBindingProtocolGuid,
+                       NULL,
+                       &HandleCount,
+                       &Handles
+                       );
   if (EFI_ERROR (Status) || (HandleCount == 0)) {
-    ShellPrintHiiEx (
-      -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_NO_NIC),
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_TFTP_ERR_NO_NIC),
       mTftpHiiHandle
-    );
+      );
     goto Error;
   }
 
   for (NicNumber = 0;
        (NicNumber < HandleCount) && (ShellStatus != SHELL_SUCCESS);
-       NicNumber++) {
+       NicNumber++)
+  {
     ControllerHandle = Handles[NicNumber];
-    Data = NULL;
 
     Status = GetNicName (ControllerHandle, NicNumber, NicName);
     if (EFI_ERROR (Status)) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_NIC_NAME),
-        mTftpHiiHandle, NicNumber, Status
-      );
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_TFTP_ERR_NIC_NAME),
+        mTftpHiiHandle,
+        NicNumber,
+        Status
+        );
       continue;
     }
 
@@ -507,6 +533,7 @@ RunTftp (
       if (StrCmp (NicName, UserNicName) != 0) {
         continue;
       }
+
       NicFound = TRUE;
     }
 
@@ -515,81 +542,56 @@ RunTftp (
                &gEfiMtftp4ServiceBindingProtocolGuid,
                &gEfiMtftp4ProtocolGuid,
                &Mtftp4ChildHandle,
-               (VOID**)&Mtftp4
+               (VOID **)&Mtftp4
                );
     if (EFI_ERROR (Status)) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_OPEN_PROTOCOL),
-        mTftpHiiHandle, NicName, Status
-      );
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_TFTP_ERR_OPEN_PROTOCOL),
+        mTftpHiiHandle,
+        NicName,
+        Status
+        );
       continue;
     }
 
     Status = Mtftp4->Configure (Mtftp4, &Mtftp4ConfigData);
     if (EFI_ERROR (Status)) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_CONFIGURE),
-        mTftpHiiHandle, NicName, Status
-      );
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_TFTP_ERR_CONFIGURE),
+        mTftpHiiHandle,
+        NicName,
+        Status
+        );
       goto NextHandle;
     }
 
     Status = GetFileSize (Mtftp4, AsciiRemoteFilePath, &FileSize);
     if (EFI_ERROR (Status)) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_FILE_SIZE),
-        mTftpHiiHandle, RemoteFilePath, NicName, Status
-      );
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_TFTP_ERR_FILE_SIZE),
+        mTftpHiiHandle,
+        RemoteFilePath,
+        NicName,
+        Status
+        );
       goto NextHandle;
     }
 
-    Status = DownloadFile (Mtftp4, RemoteFilePath, AsciiRemoteFilePath, FileSize, BlockSize, WindowSize, &Data);
+    Status = DownloadFile (Mtftp4, RemoteFilePath, AsciiRemoteFilePath, FileSize, BlockSize, WindowSize);
     if (EFI_ERROR (Status)) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_DOWNLOAD),
-        mTftpHiiHandle, RemoteFilePath, NicName, Status
-      );
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_TFTP_ERR_DOWNLOAD),
+        mTftpHiiHandle,
+        RemoteFilePath,
+        NicName,
+        Status
+        );
       goto NextHandle;
     }
 
-    DataSize = FileSize;
+    ShellStatus = SHELL_SUCCESS;
 
-    if (!EFI_ERROR (ShellFileExists (LocalFilePath))) {
-      ShellDeleteFileByName (LocalFilePath);
-    }
-
-    Status = ShellOpenFileByName (
-               LocalFilePath,
-               &FileHandle,
-               EFI_FILE_MODE_CREATE |
-               EFI_FILE_MODE_WRITE  |
-               EFI_FILE_MODE_READ,
-               0
-               );
-    if (EFI_ERROR (Status)) {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_GEN_FILE_OPEN_FAIL),
-        mTftpHiiHandle, L"tftp", LocalFilePath
-      );
-      goto NextHandle;
-    }
-
-    Status = ShellWriteFile (FileHandle, &FileSize, Data);
-    if (!EFI_ERROR (Status)) {
-      ShellStatus = SHELL_SUCCESS;
-    } else {
-      ShellPrintHiiEx (
-        -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_WRITE),
-        mTftpHiiHandle, LocalFilePath, Status
-      );
-    }
-    ShellCloseFile (&FileHandle);
-
-    NextHandle:
-
-    if (Data != NULL) {
-      gBS->FreePages ((EFI_PHYSICAL_ADDRESS)(UINTN)Data, EFI_SIZE_TO_PAGES (DataSize));
-    }
+NextHandle:
 
     CloseProtocolAndDestroyServiceChild (
       ControllerHandle,
@@ -600,22 +602,28 @@ RunTftp (
   }
 
   if ((UserNicName != NULL) && (!NicFound)) {
-    ShellPrintHiiEx (
-      -1, -1, NULL, STRING_TOKEN (STR_TFTP_ERR_NIC_NOT_FOUND),
-      mTftpHiiHandle, UserNicName
-    );
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_TFTP_ERR_NIC_NOT_FOUND),
+      mTftpHiiHandle,
+      UserNicName
+      );
   }
 
-  Error:
+Error:
 
   ShellCommandLineFreeVarList (CheckPackage);
   if (AsciiRemoteFilePath != NULL) {
     FreePool (AsciiRemoteFilePath);
   }
+
   if (Handles != NULL) {
     FreePool (Handles);
   }
 
+  if ((ShellStatus != SHELL_SUCCESS) && (EFI_ERROR (Status))) {
+    ShellStatus = Status & ~MAX_BIT;
+  }
+
   return ShellStatus;
 }
 
@@ -626,7 +634,7 @@ RunTftp (
   @param[out] Value     UINT16 value
 
   @return     TRUE      The value was returned.
-  @return     FALSE     A parsing error occured.
+  @return     FALSE     A parsing error occurred.
 **/
 STATIC
 BOOLEAN
@@ -639,10 +647,12 @@ StringToUint16 (
 
   Val = ShellStrToUintn (ValueStr);
   if (Val > MAX_UINT16) {
-    ShellPrintHiiEx (
-      -1, -1, NULL, STRING_TOKEN (STR_GEN_PARAM_INV),
-      mTftpHiiHandle, L"tftp", ValueStr
-    );
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_GEN_PARAM_INV),
+      mTftpHiiHandle,
+      L"tftp",
+      ValueStr
+      );
     return FALSE;
   }
 
@@ -686,7 +696,7 @@ GetNicName (
              &gEfiManagedNetworkServiceBindingProtocolGuid,
              &gEfiManagedNetworkProtocolGuid,
              &MnpHandle,
-             (VOID**)&Mnp
+             (VOID **)&Mnp
              );
   if (EFI_ERROR (Status)) {
     goto Error;
@@ -702,7 +712,7 @@ GetNicName (
     IP4_CONFIG2_INTERFACE_INFO_NAME_LENGTH,
     SnpMode.IfType == NET_IFTYPE_ETHERNET ?
     L"eth%d" :
-    L"unk%d" ,
+    L"unk%d",
     NicNumber
     );
 
@@ -754,12 +764,12 @@ CreateServiceChildAndOpenProtocol (
   EFI_STATUS  Status;
 
   *ChildHandle = NULL;
-  Status = NetLibCreateServiceChild (
-             ControllerHandle,
-             gImageHandle,
-             ServiceBindingProtocolGuid,
-             ChildHandle
-             );
+  Status       = NetLibCreateServiceChild (
+                   ControllerHandle,
+                   gImageHandle,
+                   ServiceBindingProtocolGuid,
+                   ChildHandle
+                   );
   if (!EFI_ERROR (Status)) {
     Status = gBS->OpenProtocol (
                     *ChildHandle,
@@ -851,21 +861,21 @@ GetFileSize (
   UINT32             OptCnt;
   UINT8              OptBuf[128];
 
-  ReqOpt[0].OptionStr = (UINT8*)"tsize";
-  OptBuf[0] = '0';
-  OptBuf[1] = 0;
-  ReqOpt[0].ValueStr = OptBuf;
+  ReqOpt[0].OptionStr = (UINT8 *)"tsize";
+  OptBuf[0]           = '0';
+  OptBuf[1]           = 0;
+  ReqOpt[0].ValueStr  = OptBuf;
 
   Status = Mtftp4->GetInfo (
-             Mtftp4,
-             NULL,
-             (UINT8*)FilePath,
-             NULL,
-             1,
-             ReqOpt,
-             &PktLen,
-             &Packet
-             );
+                     Mtftp4,
+                     NULL,
+                     (UINT8 *)FilePath,
+                     NULL,
+                     1,
+                     ReqOpt,
+                     &PktLen,
+                     &Packet
+                     );
 
   if (EFI_ERROR (Status)) {
     goto Error;
@@ -875,7 +885,7 @@ GetFileSize (
                      Mtftp4,
                      PktLen,
                      Packet,
-                     (UINT32 *) &OptCnt,
+                     (UINT32 *)&OptCnt,
                      &TableOfOptions
                      );
   if (EFI_ERROR (Status)) {
@@ -888,16 +898,18 @@ GetFileSize (
       *FileSize = AsciiStrDecimalToUintn ((CHAR8 *)Option->ValueStr);
       break;
     }
+
     OptCnt--;
     Option++;
   }
+
   FreePool (TableOfOptions);
 
   if (OptCnt == 0) {
     Status = EFI_UNSUPPORTED;
   }
 
-Error :
+Error:
 
   return Status;
 }
@@ -912,9 +924,6 @@ Error :
   @param[in]   FileSize       Size of the file in number of bytes
   @param[in]   BlockSize      Value of the TFTP blksize option
   @param[in]   WindowSize     Value of the TFTP window size option
-  @param[out]  Data           Address where to store the address of the buffer
-                              where the data of the file were downloaded in
-                              case of success.
 
   @retval  EFI_SUCCESS           The file was downloaded.
   @retval  EFI_OUT_OF_RESOURCES  A memory allocation failed.
@@ -930,50 +939,30 @@ DownloadFile (
   IN   CONST CHAR8          *AsciiFilePath,
   IN   UINTN                FileSize,
   IN   UINT16               BlockSize,
-  IN   UINT16               WindowSize,
-  OUT  VOID                 **Data
+  IN   UINT16               WindowSize
   )
 {
-  EFI_STATUS            Status;
-  EFI_PHYSICAL_ADDRESS  PagesAddress;
-  VOID                  *Buffer;
-  DOWNLOAD_CONTEXT      *TftpContext;
-  EFI_MTFTP4_TOKEN      Mtftp4Token;
-  UINT8                 BlksizeBuf[10];
-  UINT8                 WindowsizeBuf[10];
+  EFI_STATUS        Status;
+  DOWNLOAD_CONTEXT  *TftpContext;
+  EFI_MTFTP4_TOKEN  Mtftp4Token;
+  UINT8             BlksizeBuf[10];
+  UINT8             WindowsizeBuf[10];
 
   ZeroMem (&Mtftp4Token, sizeof (EFI_MTFTP4_TOKEN));
 
-  // Downloaded file can be large. BS.AllocatePages() is more faster
-  // than AllocatePool() and avoid fragmentation.
-  // The downloaded file could be an EFI application. Marking the
-  // allocated page as EfiBootServicesCode would allow to execute a
-  // potential downloaded EFI application.
-  Status = gBS->AllocatePages (
-                   AllocateAnyPages,
-                   EfiBootServicesCode,
-                   EFI_SIZE_TO_PAGES (FileSize),
-                   &PagesAddress
-                   );
-  if (EFI_ERROR (Status)) {
-    return Status;
-  }
-
-  Buffer = (VOID*)(UINTN)PagesAddress;
   TftpContext = AllocatePool (sizeof (DOWNLOAD_CONTEXT));
   if (TftpContext == NULL) {
     Status = EFI_OUT_OF_RESOURCES;
     goto Error;
   }
-  TftpContext->FileSize = FileSize;
+
+  TftpContext->FileSize              = FileSize;
   TftpContext->DownloadedNbOfBytes   = 0;
   TftpContext->LastReportedNbOfBytes = 0;
 
-  Mtftp4Token.Filename    = (UINT8*)AsciiFilePath;
-  Mtftp4Token.BufferSize  = FileSize;
-  Mtftp4Token.Buffer      = Buffer;
+  Mtftp4Token.Filename    = (UINT8 *)AsciiFilePath;
   Mtftp4Token.CheckPacket = CheckPacket;
-  Mtftp4Token.Context     = (VOID*)TftpContext;
+  Mtftp4Token.Context     = (VOID *)TftpContext;
   Mtftp4Token.OptionCount = 0;
   Mtftp4Token.OptionList  = AllocatePool (sizeof (EFI_MTFTP4_OPTION) * 2);
   if (Mtftp4Token.OptionList == NULL) {
@@ -982,32 +971,62 @@ DownloadFile (
   }
 
   if (BlockSize != MTFTP_DEFAULT_BLKSIZE) {
-    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].OptionStr = (UINT8 *) "blksize";
-    AsciiSPrint ((CHAR8 *) BlksizeBuf, sizeof (BlksizeBuf), "%d", BlockSize);
-    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].ValueStr  = BlksizeBuf;
-    Mtftp4Token.OptionCount ++;
+    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].OptionStr = (UINT8 *)"blksize";
+    AsciiSPrint ((CHAR8 *)BlksizeBuf, sizeof (BlksizeBuf), "%d", BlockSize);
+    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].ValueStr = BlksizeBuf;
+    Mtftp4Token.OptionCount++;
   }
 
   if (WindowSize != MTFTP_DEFAULT_WINDOWSIZE) {
-    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].OptionStr = (UINT8 *) "windowsize";
-    AsciiSPrint ((CHAR8 *) WindowsizeBuf, sizeof (WindowsizeBuf), "%d", WindowSize);
-    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].ValueStr  = WindowsizeBuf;
-    Mtftp4Token.OptionCount ++;
+    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].OptionStr = (UINT8 *)"windowsize";
+    AsciiSPrint ((CHAR8 *)WindowsizeBuf, sizeof (WindowsizeBuf), "%d", WindowSize);
+    Mtftp4Token.OptionList[Mtftp4Token.OptionCount].ValueStr = WindowsizeBuf;
+    Mtftp4Token.OptionCount++;
   }
 
-  ShellPrintHiiEx (
-    -1, -1, NULL, STRING_TOKEN (STR_TFTP_DOWNLOADING),
-    mTftpHiiHandle, FilePath
+  ShellPrintHiiDefaultEx (
+    STRING_TOKEN (STR_TFTP_DOWNLOADING),
+    mTftpHiiHandle,
+    FilePath
     );
 
+  //
+  // OPEN FILE
+  //
+  if (!EFI_ERROR (ShellFileExists (mLocalFilePath))) {
+    ShellDeleteFileByName (mLocalFilePath);
+  }
+
+  Status = ShellOpenFileByName (
+             mLocalFilePath,
+             &mFileHandle,
+             EFI_FILE_MODE_CREATE |
+             EFI_FILE_MODE_WRITE  |
+             EFI_FILE_MODE_READ,
+             0
+             );
+  if (EFI_ERROR (Status)) {
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_GEN_FILE_OPEN_FAIL),
+      mTftpHiiHandle,
+      L"tftp",
+      mLocalFilePath
+      );
+    goto Error;
+  }
+
   Status = Mtftp4->ReadFile (Mtftp4, &Mtftp4Token);
-  ShellPrintHiiEx (
-    -1, -1, NULL, STRING_TOKEN (STR_GEN_CRLF),
+  ShellPrintHiiDefaultEx (
+    STRING_TOKEN (STR_GEN_CRLF),
     mTftpHiiHandle
     );
 
-Error :
+  //
+  // CLOSE FILE
+  //
+  ShellCloseFile (&mFileHandle);
 
+Error:
   if (TftpContext != NULL) {
     FreePool (TftpContext);
   }
@@ -1016,14 +1035,7 @@ Error :
     FreePool (Mtftp4Token.OptionList);
   }
 
-  if (EFI_ERROR (Status)) {
-    gBS->FreePages (PagesAddress, EFI_SIZE_TO_PAGES (FileSize));
-    return Status;
-  }
-
-  *Data = Buffer;
-
-  return EFI_SUCCESS;
+  return Status;
 }
 
 /**
@@ -1054,43 +1066,67 @@ CheckPacket (
   UINTN             Index;
   UINTN             LastStep;
   UINTN             Step;
+  UINTN             DownloadLen;
   EFI_STATUS        Status;
 
   if ((NTOHS (Packet->OpCode)) != EFI_MTFTP4_OPCODE_DATA) {
     return EFI_SUCCESS;
   }
 
-  Context = (DOWNLOAD_CONTEXT*)Token->Context;
-  if (Context->DownloadedNbOfBytes == 0) {
-    ShellPrintEx (-1, -1, L"%s       0 Kb", mTftpProgressFrame);
-  }
+  Context = (DOWNLOAD_CONTEXT *)Token->Context;
 
   //
   // The data in the packet are prepended with two UINT16 :
   // . OpCode = EFI_MTFTP4_OPCODE_DATA
   // . Block  = the number of this block of data
   //
-  Context->DownloadedNbOfBytes += PacketLen - sizeof (Packet->OpCode)
-                                            - sizeof (Packet->Data.Block);
-  NbOfKb = Context->DownloadedNbOfBytes / 1024;
+  DownloadLen = (UINTN)PacketLen - sizeof (Packet->OpCode) - sizeof (Packet->Data.Block);
+
+  ShellSetFilePosition (mFileHandle, Context->DownloadedNbOfBytes);
+  Status = ShellWriteFile (mFileHandle, &DownloadLen, Packet->Data.Data);
+  if (EFI_ERROR (Status)) {
+    if (Context->DownloadedNbOfBytes > 0) {
+      ShellPrintHiiDefaultEx (
+        STRING_TOKEN (STR_GEN_CRLF),
+        mTftpHiiHandle
+        );
+    }
+
+    ShellPrintHiiDefaultEx (
+      STRING_TOKEN (STR_TFTP_ERR_WRITE),
+      mTftpHiiHandle,
+      mLocalFilePath,
+      Status
+      );
+    return Status;
+  }
+
+  if (Context->DownloadedNbOfBytes == 0) {
+    ShellPrintDefaultEx (L"%s       0 Kb", mTftpProgressFrame);
+  }
+
+  Context->DownloadedNbOfBytes += DownloadLen;
+  NbOfKb                        = Context->DownloadedNbOfBytes / 1024;
 
   Progress[0] = L'\0';
-  LastStep  = (Context->LastReportedNbOfBytes * TFTP_PROGRESS_SLIDER_STEPS) / Context->FileSize;
-  Step      = (Context->DownloadedNbOfBytes * TFTP_PROGRESS_SLIDER_STEPS) / Context->FileSize;
+  LastStep    = (Context->LastReportedNbOfBytes * TFTP_PROGRESS_SLIDER_STEPS) / Context->FileSize;
+  Step        = (Context->DownloadedNbOfBytes * TFTP_PROGRESS_SLIDER_STEPS) / Context->FileSize;
 
   if (Step <= LastStep) {
     return EFI_SUCCESS;
   }
 
-  ShellPrintEx (-1, -1, L"%s", mTftpProgressDelete);
+  ShellPrintDefaultEx (L"%s", mTftpProgressDelete);
 
   Status = StrCpyS (Progress, TFTP_PROGRESS_MESSAGE_SIZE, mTftpProgressFrame);
-  if (EFI_ERROR(Status)) {
+  if (EFI_ERROR (Status)) {
     return Status;
   }
+
   for (Index = 1; Index < Step; Index++) {
     Progress[Index] = L'=';
   }
+
   Progress[Step] = L'>';
 
   UnicodeSPrint (
@@ -1101,26 +1137,26 @@ CheckPacket (
     );
   Context->LastReportedNbOfBytes = Context->DownloadedNbOfBytes;
 
-  ShellPrintEx (-1, -1, L"%s", Progress);
+  ShellPrintDefaultEx (L"%s", Progress);
 
   return EFI_SUCCESS;
 }
 
 /**
-  Retrive HII package list from ImageHandle and publish to HII database.
+  Retrieve HII package list from ImageHandle and publish to HII database.
 
   @param ImageHandle            The image handle of the process.
 
   @return HII handle.
 **/
-EFI_HANDLE
+EFI_HII_HANDLE
 InitializeHiiPackage (
-  EFI_HANDLE                  ImageHandle
+  EFI_HANDLE  ImageHandle
   )
 {
-  EFI_STATUS                  Status;
-  EFI_HII_PACKAGE_LIST_HEADER *PackageList;
-  EFI_HANDLE                  HiiHandle;
+  EFI_STATUS                   Status;
+  EFI_HII_PACKAGE_LIST_HEADER  *PackageList;
+  EFI_HII_HANDLE               HiiHandle;
 
   //
   // Retrieve HII package list from ImageHandle
@@ -1151,5 +1187,6 @@ InitializeHiiPackage (
   if (EFI_ERROR (Status)) {
     return NULL;
   }
+
   return HiiHandle;
 }
