@@ -16,8 +16,11 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #include <Library/BaseMemoryLib.h>
 #include <Library/IoLib.h>
 #include <Library/HobLib.h>
+#include <Library/MemoryAllocationLib.h>
 
+#include <Guid/SystemResourceTable.h>
 #include <Guid/AcpiBoardInfoGuid.h>
+#include <Guid/FirmwareInfoGuid.h>
 #include <Guid/GraphicsInfoHob.h>
 
 EFI_STATUS
